(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    233434,       4371]
NotebookOptionsPosition[    230855,       4282]
NotebookOutlinePosition[    231193,       4297]
CellTagsIndexPosition[    231150,       4294]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.568136876164297*^9, 3.568136877026876*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "RandFile`"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package RandFile version \"\>", 
   "\[InvisibleSpace]", "\<\"0.0.17\"\>", 
   "\[InvisibleSpace]", "\<\" (last modification: \"\>", 
   "\[InvisibleSpace]", "\<\"25/01/2013\"\>", 
   "\[InvisibleSpace]", "\<\").\"\>"}],
  SequenceForm[
  "Package RandFile version ", "0.0.17", " (last modification: ", 
   "25/01/2013", ")."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.568136517333255*^9, 3.568136882294683*^9, 3.5681380257548943`*^9, 
   3.5682229156435013`*^9, 3.568437419036264*^9, 3.570863048757831*^9, 
   3.570863171953074*^9, {3.570863396124007*^9, 3.570863418235736*^9}}],

Cell[BoxData["\<\"Usage notes:\"\>"], "Print",
 CellChangeTimes->{
  3.568136517333255*^9, 3.568136882294683*^9, 3.5681380257548943`*^9, 
   3.5682229156435013`*^9, 3.568437419036264*^9, 3.570863048757831*^9, 
   3.570863171953074*^9, {3.570863396124007*^9, 3.570863418237015*^9}}],

Cell[BoxData["\<\"1) Almost all provided functions require to set a global \
variable pointing to file with random data! This can be done by using \
\\!\\(\\*\\nStyleBox[\\\"SetTrueRandomDataFile\\\",\\nFontWeight->\\\"Bold\\\"\
]\\) function. For example \
\\!\\(\\*\\nStyleBox[\\\"SetTrueRandomDataFile\\\",\\nFontWeight->\\\"Bold\\\"\
]\\)[\\\"/home/user/data/random_file.bin\\\"]. Please mind that it is advised \
to use this function only once during session.\"\>"], "Print",
 CellChangeTimes->{
  3.568136517333255*^9, 3.568136882294683*^9, 3.5681380257548943`*^9, 
   3.5682229156435013`*^9, 3.568437419036264*^9, 3.570863048757831*^9, 
   3.570863171953074*^9, {3.570863396124007*^9, 3.570863418239211*^9}}],

Cell[BoxData["\<\"2) If you intend to use \
\\!\\(\\*\\nStyleBox[\\\"TrueRandomSequence\\\",\\nFontWeight->\\\"Bold\\\"]\\\
) function you must use \
\\!\\(\\*\\nStyleBox[\\\"SetMaxTrueRandomSequenceLength\\\",\\nFontWeight->\\\
\"Bold\\\"]\\) and declare at least one sequence. Currently declared \
sequences can be displayed by calling \
\\!\\(\\*\\nStyleBox[\\\"GetTrueRandomDataMarkers\\\",\\nFontWeight->\\\"Bold\
\\\"]\\)[]. Once defined, the used maximal length cannot be changed during \
the session.\"\>"], "Print",
 CellChangeTimes->{
  3.568136517333255*^9, 3.568136882294683*^9, 3.5681380257548943`*^9, 
   3.5682229156435013`*^9, 3.568437419036264*^9, 3.570863048757831*^9, 
   3.570863171953074*^9, {3.570863396124007*^9, 3.5708634182414207`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5681365394492064`*^9, 3.5681365464211884`*^9}, {
  3.5708630497744226`*^9, 3.570863050454672*^9}}],

Cell[BoxData["\<\"/home/jam/Kuweta/notatki/programming/mathematica/rand_file/\
usage_examples\"\>"], "Output",
 CellChangeTimes->{
  3.568136546911701*^9, 3.568136882623197*^9, 3.568138026054018*^9, 
   3.568222916068866*^9, 3.568437419546535*^9, 3.570863050926756*^9, 
   3.570863173057763*^9, {3.570863397269651*^9, 3.570863418567452*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TrueRandomPi", "[", "dataFile_String", "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"samplePoints", "=", "5000"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SetTrueRandomDataFile", "[", "dataFile", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"data", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"TrueRandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "samplePoints"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CloseTrueRandomDataFile", "[", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dataCircle", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"data", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.5", "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.5", "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}]}], 
           "\[LessEqual]", 
           RowBox[{
            RowBox[{"(", "0.5", ")"}], "^", "2"}]}], "&"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"complement", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"data", ",", "dataCircle"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "complement", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"complement", "=", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "}"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"4", "*", 
       RowBox[{
        RowBox[{"Length", "[", "dataCircle", "]"}], "/", 
        "samplePoints"}]}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5681364917917223`*^9, 3.568136515569837*^9}, 
   3.56813655114618*^9, {3.568136899567951*^9, 3.5681368998047*^9}, 
   3.568137030521978*^9, {3.568137118149805*^9, 3.568137245851241*^9}, {
   3.568437423648705*^9, 3.5684374242138243`*^9}, {3.568437456253335*^9, 
   3.5684374563978233`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", "7", "]"}], "=", 
   RowBox[{"2", "/", "10"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]", "[", "k_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"i", "-", "1"}], ")"}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"k", "-", "1"}]}], "}"}]}], "]"}], "/", "10"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.568137315101995*^9, 3.568137315103622*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"entropyTheory", "[", "k_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "p1", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p1", "=", 
      RowBox[{"(", 
       RowBox[{"0.3", "+", 
        RowBox[{"\[Alpha]", "[", "k", "]"}]}], ")"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Log", "[", 
         RowBox[{"2", ",", "p1"}], "]"}]}], " ", "p1"}], " ", "-", " ", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"2", ",", 
         RowBox[{"1", "-", "p1"}]}], "]"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", "p1"}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.568137322626792*^9, 3.568137404903716*^9}, {
  3.5681375302260036`*^9, 3.5681375578107433`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "this", " ", "was", " ", "calculated", " ", "during", " ", "the", " ", 
    "sample", " ", "generation", " ", "in", " ", 
    RowBox[{"RandFile_FileGenerator", ".", "nb"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"tabQuality", "=", 
   RowBox[{"Map", "[", 
    RowBox[{"Flatten", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.699105", ",", "0.882383"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.600255", ",", "0.970801"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.549744", ",", "0.992848"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.524911", ",", "0.998209"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.513581", ",", "0.999468"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.506958", ",", "0.99986"}], "}"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.500608", ",", "0.999999"}], "}"}], "}"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.568218353164669*^9, 3.5682183987990303`*^9}, {
  3.568218429927891*^9, 3.5682184321346827`*^9}, {3.5708631001765003`*^9, 
  3.5708631002663116`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.699105`", ",", "0.882383`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.600255`", ",", "0.970801`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.549744`", ",", "0.992848`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.524911`", ",", "0.998209`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.513581`", ",", "0.999468`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.506958`", ",", "0.99986`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.500608`", ",", "0.999999`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.568218402005241*^9, 3.568218432629757*^9, 3.568222920907935*^9, 
   3.568437442216914*^9, 3.5708630558697777`*^9, {3.5708630916752768`*^9, 
   3.57086310112178*^9}, 3.570863176901931*^9, {3.57086340324515*^9, 
   3.57086342036167*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tabEntReal", "=", 
  RowBox[{
   RowBox[{"tabQuality", "\[Transpose]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.56821848009201*^9, 3.5682184889761*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.882383`", ",", "0.970801`", ",", "0.992848`", ",", "0.998209`", ",", 
   "0.999468`", ",", "0.99986`", ",", "0.999999`"}], "}"}]], "Output",
 CellChangeTimes->{{3.568218481343655*^9, 3.568218489416277*^9}, 
   3.568222922315325*^9, 3.568437445001397*^9, 3.570863057383305*^9, {
   3.570863095019053*^9, 3.57086310220829*^9}, 3.570863177593521*^9, {
   3.570863404956233*^9, 3.5708634210395327`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tabPi", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TrueRandomPi", "[", 
      RowBox[{"\"\<piSample\>\"", "<>", 
       RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<.bin\>\""}], "]"}], "//",
      "N"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "7"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5681380321408653`*^9, 3.568138139122534*^9}, {
   3.5708630421026278`*^9, 3.570863042729087*^9}, 3.570863122520728*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Using file \\\"piSample1.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.5708634217584743`*^9}}],

Cell[BoxData["\<\"Using file \\\"piSample2.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.570863422378003*^9}}],

Cell[BoxData["\<\"Using file \\\"piSample3.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.5708634229926023`*^9}}],

Cell[BoxData["\<\"Using file \\\"piSample4.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.570863423606153*^9}}],

Cell[BoxData["\<\"Using file \\\"piSample5.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.570863424218252*^9}}],

Cell[BoxData["\<\"Using file \\\"piSample6.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.5708634248586903`*^9}}],

Cell[BoxData["\<\"Using file \\\"piSample7.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.5708632315031567`*^9, 3.570863238074613*^9}, {
  3.5708634098374863`*^9, 3.5708634254774323`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.4168`", ",", "2.9792`", ",", "3.0864`", ",", "3.112`", ",", "3.156`", 
   ",", "3.1384`", ",", "3.1416`"}], "}"}]], "Output",
 CellChangeTimes->{{3.568138048746531*^9, 3.568138060751371*^9}, {
   3.568138121403368*^9, 3.568138147381771*^9}, 3.5682229422841682`*^9, {
   3.568437448213111*^9, 3.568437468524061*^9}, 3.5708630589564323`*^9, {
   3.570863104204458*^9, 3.570863141306044*^9}, {3.570863235127878*^9, 
   3.570863242332007*^9}, {3.570863411045594*^9, 3.5708634260653353`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tabPiPlot", "=", 
   RowBox[{"tabPi", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "7"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabEntRealPlot", "=", 
   RowBox[{"tabEntReal", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "7"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabPiInset", "=", 
   RowBox[{"tabPi", "[", 
    RowBox[{"[", 
     RowBox[{"3", ";;", "7"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabEntRealInset", "=", 
   RowBox[{"tabEntReal", "[", 
    RowBox[{"[", 
     RowBox[{"3", ";;", "7"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5682187446879387`*^9, 3.568218768476884*^9}, {
  3.568218834555458*^9, 3.5682188532129927`*^9}, {3.5682189397133007`*^9, 
  3.568218945513764*^9}, {3.568222971864958*^9, 3.568222989074695*^9}, {
  3.5682230795721197`*^9, 3.568223090834672*^9}, {3.568437474013068*^9, 
  3.568437480133102*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotRelativeErrPIvsEntropy", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tabEntRealPlot", ",", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"tabPiPlot", "-", "\[Pi]"}], "]"}], "/", "\[Pi]"}]}], "}"}], 
     "\[Transpose]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "7"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "Dashed"}], "]"}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "12", "]"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Min", "[", "tabEntRealPlot", "]"}], "-", "0.01"}], ",", 
         RowBox[{
          RowBox[{"Max", "[", "tabEntRealPlot", "]"}], "+", "0.01"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Min", "[", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"tabPiPlot", "-", "\[Pi]"}], "]"}], "/", "\[Pi]"}], 
           "]"}], "-", "0.02"}], ",", 
         RowBox[{
          RowBox[{"Max", "[", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"tabPiPlot", "-", "\[Pi]"}], "]"}], "/", "\[Pi]"}], 
           "]"}], "+", "0.01"}]}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.568138179340912*^9, 3.568138605534052*^9}, {
   3.568138637971389*^9, 3.5681386427953777`*^9}, {3.568213736456312*^9, 
   3.568214158161049*^9}, {3.5682145277936697`*^9, 3.568214579585905*^9}, {
   3.568218239948667*^9, 3.5682182713049994`*^9}, 3.5682184987933407`*^9, {
   3.56821862632436*^9, 3.568218735656665*^9}, {3.568218774992467*^9, 
   3.568218779404703*^9}, 3.568218810915263*^9, {3.5682188736690807`*^9, 
   3.568218885117943*^9}, 3.5682191716848793`*^9, {3.568220050154626*^9, 
   3.56822005027153*^9}, {3.568220094405126*^9, 3.56822009450695*^9}, {
   3.568437481488866*^9, 3.568437482224427*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   GraphicsComplexBox[{{0.882383, 0.23070866707101473`}, {0.970801, 
    0.051691187081250776`}, {0.992848, 0.017568367282348493`}, {0.998209, 
    0.00941963419604336}, {0.999468, 0.004586000796043443}, {0.99986, 
    0.0010162532007913633`}, {0.999999, 2.3384349967961744`*^-6}}, {{{}, {}, 
      {RGBColor[1, 0, 0], Dashing[{Small, Small}], 
       LineBox[{1, 2, 3, 4, 5, 6, 7}]}}, {
      {RGBColor[1, 0, 0], Dashing[{Small, Small}], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 1], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 2], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 3], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 4], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 5], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 6], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 7]}, {}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.88, 0},
  Frame->True,
  FrameLabel->{None, None},
  FrameStyle->Directive[12],
  Method->{},
  PlotRange->{{0.872383, 1.0099989999999999`}, {-0.019997661565003204`, 
   0.24070866707101474`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5708634284487886`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotRelativeErrPIvsEntropyInset", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tabEntRealInset", ",", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"tabPiInset", "-", "\[Pi]"}], "]"}], "/", "\[Pi]"}]}], "}"}],
      "\[Transpose]"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "7"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Directive", "[", 
       RowBox[{"Red", ",", "Dashed"}], "]"}], "}"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "8", "]"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Min", "[", "tabEntRealInset", "]"}], "-", "0.001"}], ",", 
         RowBox[{
          RowBox[{"Max", "[", "tabEntRealInset", "]"}], "+", "0.001"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.001"}], ",", 
         RowBox[{
          RowBox[{"Max", "[", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{"tabPiInset", "-", "\[Pi]"}], "]"}], "/", "\[Pi]"}], 
           "]"}], "+", "0.005"}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.018", ",", "0.009", ",", "0.000"}], "}"}], ",", 
         "Automatic"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.993", ",", "0.998", ",", "1"}], "}"}], ",", 
         "Automatic"}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.568218819260639*^9, 3.568218976713358*^9}, {
  3.5682193797790003`*^9, 3.5682195036651373`*^9}, {3.568219537891596*^9, 
  3.568219713378221*^9}, {3.5682197462074747`*^9, 3.568219833393372*^9}, {
  3.56822001693034*^9, 3.568220017134095*^9}, {3.568220087575548*^9, 
  3.568220090372127*^9}, {3.5682201389838037`*^9, 3.568220139597866*^9}, {
  3.568223014600967*^9, 3.568223055592169*^9}, {3.568437626533712*^9, 
  3.5684376454939833`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   GraphicsComplexBox[{{0.992848, 0.017568367282348493`}, {0.998209, 
    0.00941963419604336}, {0.999468, 0.004586000796043443}, {0.99986, 
    0.0010162532007913633`}, {0.999999, 2.3384349967961744`*^-6}}, {{{}, {}, 
      {RGBColor[1, 0, 0], Dashing[{Small, Small}], 
       LineBox[{1, 2, 3, 4, 5}]}}, {
      {RGBColor[1, 0, 0], Dashing[{Small, Small}], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 1], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 2], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 3], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 4], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->7], 5]}, {}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.992, 0},
  Frame->True,
  FrameLabel->{None, None},
  FrameStyle->Directive[8],
  FrameTicks->{{{{0.018, 
       FormBox["0.018`", TraditionalForm]}, {0.009, 
       FormBox["0.009`", TraditionalForm]}, {0., 
       FormBox["0.`", TraditionalForm]}}, Automatic}, {{{0.993, 
       FormBox["0.993`", TraditionalForm]}, {0.998, 
       FormBox["0.998`", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}}, Automatic}},
  Method->{},
  PlotRange->{{0.991848, 1.000999}, {-0.001, 0.022568367282348494`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.5708632662387867`*^9, 3.5708632753831472`*^9}, 
   3.5708634293264713`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotRelativeErrPIvsEntropyWithInset", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"First", "[", "plotRelativeErrPIvsEntropy", "]"}], ",", 
      RowBox[{"Inset", "[", 
       RowBox[{"plotRelativeErrPIvsEntropyInset", ",", 
        RowBox[{"{", 
         RowBox[{"0.967", ",", "0.175"}], "}"}], ",", "Automatic", ",", 
        RowBox[{"Scaled", "[", ".5", "]"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.25"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AbsoluteOptions", "[", "plotRelativeErrPIvsEntropy", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.568219110193519*^9, 3.5682193585040216`*^9}, {
  3.568219867605454*^9, 3.568219948298201*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    GraphicsComplexBox[{{0.882383, 0.23070866707101473`}, {0.970801, 
     0.051691187081250776`}, {0.992848, 0.017568367282348493`}, {0.998209, 
     0.00941963419604336}, {0.999468, 0.004586000796043443}, {0.99986, 
     0.0010162532007913633`}, {0.999999, 
     2.3384349967961744`*^-6}}, {{{}, {}, 
       {RGBColor[1, 0, 0], Dashing[{Small, Small}], 
        LineBox[{1, 2, 3, 4, 5, 6, 7}]}}, {
       {RGBColor[1, 0, 0], Dashing[{Small, Small}], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 1], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 2], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 3], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 4], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 5], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 6], InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->7], 7]}, {}}}], {}}, InsetBox[
    GraphicsBox[{{}, 
      GraphicsComplexBox[{{0.992848, 0.017568367282348493`}, {0.998209, 
       0.00941963419604336}, {0.999468, 0.004586000796043443}, {0.99986, 
       0.0010162532007913633`}, {0.999999, 
       2.3384349967961744`*^-6}}, {{{}, {}, 
         {RGBColor[1, 0, 0], Dashing[{Small, Small}], 
          LineBox[{1, 2, 3, 4, 5}]}}, {
         {RGBColor[1, 0, 0], Dashing[{Small, Small}], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->7], 1], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->7], 2], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->7], 3], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->7], 4], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->7], 5]}, {}}}], {}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0.992, 0},
     Frame->True,
     FrameLabel->{None, None},
     FrameStyle->Directive[8],
     FrameTicks->{{{{0.018, 
          FormBox["0.018`", TraditionalForm]}, {0.009, 
          FormBox["0.009`", TraditionalForm]}, {0., 
          FormBox["0.`", TraditionalForm]}}, Automatic}, {{{0.993, 
          FormBox["0.993`", TraditionalForm]}, {0.998, 
          FormBox["0.998`", TraditionalForm]}, {1, 
          FormBox["1", TraditionalForm]}}, Automatic}},
     Method->{},
     PlotRange->{{0.991848, 1.000999}, {-0.001, 0.022568367282348494`}},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], {0.967, 0.175}, Automatic, 
    Scaled[0.5]]},
  AlignmentPoint->Center,
  AspectRatio->0.6180339887498948,
  Axes->{True, True},
  AxesLabel->None,
  AxesOrigin->{0.88, 0.},
  AxesStyle->{{
     GrayLevel[0.], 
     AbsoluteThickness[0.25]}, {
     GrayLevel[0.], 
     AbsoluteThickness[0.25]}},
  Background->None,
  BaseStyle->{},
  BaselinePosition->Automatic,
  ColorOutput->Automatic,
  ContentSelectable->Automatic,
  CoordinatesToolOptions:>Automatic,
  DisplayFunction->Identity,
  Epilog->{},
  FormatType->TraditionalForm,
  Frame->{True, True, True, True},
  FrameLabel->{None, None},
  FrameStyle->{{
     GrayLevel[0.], 
     AbsoluteThickness[0.25]}, {
     GrayLevel[0.], 
     AbsoluteThickness[0.25]}, {
     GrayLevel[0.], 
     AbsoluteThickness[0.25]}, {
     GrayLevel[0.], 
     AbsoluteThickness[0.25]}},
  FrameTicks->{{{0.88, 
      FormBox["0.88`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.9, 
      FormBox["0.9`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.92, 
      FormBox["0.92`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.9400000000000001, 
      FormBox["0.9400000000000001`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.96, 
      FormBox["0.96`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.98, 
      FormBox["0.98`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {1., 
      FormBox["1.`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.885, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.89, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.895, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.91, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.925, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.93, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.935, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.9450000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.9500000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.9550000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.965, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.97, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.975, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.985, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.99, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.995, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.875, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {1.005, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}}, {{0., 
      FormBox["0.`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.05, 
      FormBox["0.05`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.1, 
      FormBox["0.1`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.15000000000000002`, 
      FormBox["0.15000000000000002`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.2, 
      FormBox["0.2`", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.010000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.020000000000000004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.030000000000000006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.04000000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.060000000000000005`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.07, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.08000000000000002, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.09000000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.11000000000000001`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.12000000000000001`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.13, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.14, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.16000000000000003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.17000000000000004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.18000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.19000000000000003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {-0.010000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.21000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.22000000000000003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.23000000000000004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.24000000000000005`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}}, {{0.88, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.9, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.92, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.9400000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.96, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.98, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {1., 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.885, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.89, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.895, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.91, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.925, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.93, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.935, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.9450000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.9500000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.9550000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.965, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.97, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.975, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.985, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.99, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.995, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.875, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {1.005, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}}, {{0., 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.05, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.1, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.15000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.2, 
      FormBox["\"\"", TraditionalForm], {0.00625, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.25]}}, {0.010000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.020000000000000004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.030000000000000006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.04000000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.060000000000000005`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.07, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.08000000000000002, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.09000000000000001, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.11000000000000001`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.12000000000000001`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.13, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.14, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.16000000000000003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.17000000000000004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.18000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.19000000000000003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {-0.010000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.21000000000000002`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.22000000000000003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.23000000000000004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}, {0.24000000000000005`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       GrayLevel[0.], 
       AbsoluteThickness[0.125]}}}},
  FrameTicksStyle->{},
  GridLines->{{}, {}},
  GridLinesStyle->{},
  ImageMargins->0.,
  ImagePadding->All,
  ImageSize->Automatic,
  ImageSizeRaw->Automatic,
  LabelStyle->{},
  Method->{},
  PlotLabel->None,
  PlotRange->{Automatic, {0, 0.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  PlotRegion->Automatic,
  PreserveImageOptions->Automatic,
  Prolog->{},
  RotateLabel->True,
  Ticks->{{}, {}},
  TicksStyle->{}]], "Output",
 CellChangeTimes->{{3.570863272326193*^9, 3.570863276236258*^9}, 
   3.570863432030761*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{
  "\"\<plotEntropyPiErr.pdf\>\"", ",", 
   "plotRelativeErrPIvsEntropyWithInset"}], "]"}]], "Input",
 CellChangeTimes->{{3.5682141644527283`*^9, 3.568214169804892*^9}, {
  3.568219953141796*^9, 3.5682199541410933`*^9}, {3.5684381414855824`*^9, 
  3.568438142629187*^9}}],

Cell[BoxData["\<\"plotEntropyPiErr.pdf\"\>"], "Output",
 CellChangeTimes->{3.5708632798487043`*^9, 3.570863437769886*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Samples in the squre", "Subsubtitle",
 CellChangeTimes->{{3.5682224301561337`*^9, 3.568222440770177*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"CloseTrueRandomDataFile", "[", "]"}], "*)"}]], "Input",
 CellChangeTimes->{3.5708634407657013`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TrueRandomPiIlustrated", "[", "dataFile_String", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "=", "5000"}], ",", 
       RowBox[{"c", "=", "1"}], ",", 
       RowBox[{"b", "=", "3"}], ",", "j", ",", "data", ",", "p1", ",", "p2", 
       ",", "p3", ",", "app"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SetTrueRandomDataFile", "[", "dataFile", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"data", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"TrueRandomReal", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CloseTrueRandomDataFile", "[", "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"dataCircle", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"data", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.5", "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "^", "2"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.5", "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}]}], 
           "\[LessEqual]", 
           RowBox[{
            RowBox[{"(", "0.5", ")"}], "^", "2"}]}], "&"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"complement", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"data", ",", "dataCircle"}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "complement", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"complement", "=", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "}"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"p1", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"PointSize", "[", "0.005", "]"}], ",", 
           RowBox[{"Point", "[", "dataCircle", "]"}]}], "}"}], ",", 
         RowBox[{"Background", "\[Rule]", "Green"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p2", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Blue", ",", 
           RowBox[{"PointSize", "[", "0.005", "]"}], ",", 
           RowBox[{"Point", "[", "complement", "]"}]}], "}"}], ",", 
         RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p3", "=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1", "/", "2"}], ",", 
              RowBox[{"1", "/", "2"}]}], "}"}], ",", 
            RowBox[{"1", "/", "2"}]}], "]"}], ",", 
          RowBox[{"EdgeForm", "[", "Thin", "]"}], ",", 
          RowBox[{"Opacity", "[", "0", "]"}], ",", 
          RowBox[{"Rectangle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"app", "=", 
       RowBox[{"4", "*", 
        RowBox[{
         RowBox[{"Length", "[", "dataCircle", "]"}], "/", "a"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Column", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Rasterize", "[", 
            RowBox[{"Show", "[", 
             RowBox[{"p2", ",", "p1", ",", 
              RowBox[{"ImageSize", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"350", ",", "350"}], "}"}]}]}], "]"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Text", "@", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Row", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<\[Pi] \[TildeTilde] \>\"", ",", 
                 RowBox[{"N", "[", 
                  RowBox[{"app", ",", "6"}], "]"}]}], "}"}], "]"}], ",", 
              "20"}], "]"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
         "\[IndentingNewLine]", "Center"}], "]"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Rasterize", "[", 
       RowBox[{"Show", "[", 
        RowBox[{"p2", ",", "p1", ",", "p3", ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"350", ",", "350"}], "}"}]}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.568222550607925*^9, 3.568222594216773*^9}, {
   3.568222742919191*^9, 3.568222758608891*^9}, 3.56822285490317*^9, {
   3.5682231313135*^9, 3.568223131845058*^9}, {3.5682231876645*^9, 
   3.568223221673366*^9}, {3.568223255027245*^9, 3.56822326971317*^9}, {
   3.5682233902381496`*^9, 3.568223428225349*^9}, {3.568223460878846*^9, 
   3.5682235530638933`*^9}, {3.568223642450768*^9, 3.568223751424952*^9}, {
   3.568224661610943*^9, 3.568224670946809*^9}, {3.568224757995968*^9, 
   3.568224761596692*^9}, {3.568224917392281*^9, 3.568224924564464*^9}, {
   3.568225017330216*^9, 3.568225046409362*^9}, {3.568437825612216*^9, 
   3.568437836251256*^9}, {3.5684378669735193`*^9, 3.568437981316986*^9}, {
   3.568438043263435*^9, 3.568438043977404*^9}, {3.568438377203952*^9, 
   3.5684383781665773`*^9}, {3.570863330848208*^9, 3.570863372017247*^9}, {
   3.5708634489300537`*^9, 3.570863452196515*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"plotHitsSample", "[", "i", "]"}], "=", 
    RowBox[{"TrueRandomPiIlustrated", "[", 
     RowBox[{"\"\<piSample\>\"", "<>", 
      RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<.bin\>\""}], "]"}]}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"Range", "[", "7", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.568222763882183*^9, 3.5682227729316177`*^9}, {
  3.5682228177769833`*^9, 3.5682228340469522`*^9}, {3.568222870624563*^9, 
  3.56822287076635*^9}, {3.568223159189419*^9, 3.568223159264462*^9}, {
  3.568223306074232*^9, 3.568223307711749*^9}, {3.5682235607890053`*^9, 
  3.568223607337523*^9}, {3.568223778850876*^9, 3.568223843096609*^9}, {
  3.568224065162561*^9, 3.568224097557283*^9}, {3.568224326133057*^9, 
  3.568224370309957*^9}, {3.56822504832976*^9, 3.5682250490987663`*^9}, {
  3.5684378064784393`*^9, 3.568437806552946*^9}, {3.568438019622608*^9, 
  3.5684380197450657`*^9}, {3.570863306982904*^9, 3.570863309577179*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Using file \\\"piSample1.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.570863453701579*^9}],

Cell[BoxData["\<\"Using file \\\"piSample2.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.570863454475287*^9}],

Cell[BoxData["\<\"Using file \\\"piSample3.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.570863455257925*^9}],

Cell[BoxData["\<\"Using file \\\"piSample4.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.570863456024205*^9}],

Cell[BoxData["\<\"Using file \\\"piSample5.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.5708634567938213`*^9}],

Cell[BoxData["\<\"Using file \\\"piSample6.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.570863457558793*^9}],

Cell[BoxData["\<\"Using file \\\"piSample7.bin\\\" which contains 80000 bytes \
of data.\"\>"], "Print",
 CellChangeTimes->{{3.568224098190865*^9, 3.568224115926785*^9}, 
   3.568224327323184*^9, {3.568224371093461*^9, 3.568224381764394*^9}, 
   3.568224673877598*^9, 3.568224765151465*^9, 3.568224927978468*^9, {
   3.568225025226715*^9, 3.568225051604691*^9}, 3.568437809670244*^9, {
   3.568437845119792*^9, 3.568437871675686*^9}, {3.56843790958672*^9, 
   3.56843798291278*^9}, {3.5684380205295687`*^9, 3.568438045509305*^9}, 
   3.568438379758313*^9, {3.570863310868125*^9, 3.570863373103113*^9}, 
   3.570863458314795*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT9MI8vybj89iQjWyUFEyHoB2uCKu8G9WDc4crRytCJ4OstNLg/pJyEi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     "], {{0, 0}, {350, 350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT9MJEvSZ55OwoLBWYSFWmegMVZ9Y9yB1nhqa9TWCOPTDussN9InISyE
1RoLtMZTWyMshDWDNWgs9Kw2McHExMRsF7PNvqRqYKorMyPjX2ZVM/3T7Num
KjMiMjLiF5nVVdX/67+P/uu//6cx5v/9j/J/T5+nCyywwAILLLDAAgsssMAC
CyywwAILLLDAAgsssMACTcMssMACvxPwzJCUeRZIhMfHx7u7u+/fv3/+/Hl3
d7ff73e73Y2NjaUCf/vb3+yfvV5vp4Bt8KnAUYH/FLAdyz8PDg7sKdumbGx7
bW5uWgk2NpaXl63Mra0tK9+2GQ6HX79+tXqt9qYdsAAHC2ZoM6zLSV6fTCYP
Dw/X19enp6c2i23m2rS1OWtz36azzdbLy8vRaGQT1jazjRVNtQwwHo9vbm6s
9vPzc0smlh+s3tXV1bW1NWuJJZYvX75Y7ff39+64qCP9TZDTLTVdC2ZoM+DA
MGZszPXLYsCW75WVFVu4yzQ8OzuzSWqzNaO9flgbSrKyVtkVhbXQmCVjusbs
2AWJXVpYPjHm8RXHFzvBJcxA7btgBgClc9o8UFuabdm16wFbjsv8elkM2Fqs
uwxIgsK/1k5j7oy5ellavHnzxjLbYDC4urp6fRuQRoKKpNS3ikvFDC1PMS8Y
zKA+TFegzSNbc20S2cXA0tKS/a+lAntEU2s2BPxlx2j3OCcnJ3ZRYcdoueL4
+NhyYB6uazBWMaozmLdghihSM0O0fdmgZAPLAC9sYOupPTIHqwIxqEwIuBQ5
O0lj1Sv85WB+ZqhKA1232E3MIDWhAfLLjDBmaExvbW1te3u7ZIPXt7rGw/rE
7i8sS9hVhGWJnZ0dyxJ2dVFto8UMiaZezgzp7FkwQxsAzML9/b3dbm8Y0zGG
s9du7fpM1bAqS6yvrx8eHlq/aQmfijfmGZTmxIIZ5GAvWR8eHmwFtHFeXnx7
aOQSdlIkM8xywsnJSafTsa6zPrSeTKEFQGtdroW2MYPQ4fL5YkjwXb2BhNja
d35+brfPdstgC9/NzQ3HUAmQFzu0pLEbI2ApYnd3d3V1td/vX15etv86zLxQ
SgZmyBk4eZiBl1g2aEejkQ1jSwh2v5w1jGsGwX96j+CFKzZGw3rS+tP6tvgm
95P9rK5CC1rXNNJfEGsXM8wFqCMqLyPYrfH29va3b98i1xDgK1Y8RC/SvZYZ
MmZizPnLBk33QoQiFsyQFC2P6OJ+nqExTw8pEKI0BTOQ1LXcrThUL0Scnp7+
zt/v8DCnzKC1JEuEh4cHSwV212DMvjHFF/GttdXFHJmKwM3Njd1lLC0tHR4e
tuFe8WkyB+uKnTtm8HJCe2LZlqr9/f3l5WX735kL5i3YjL8SsOa+3NBZfqjP
SxPIxgwSRXPKDJiD6dR5UV4kX1lZsbVJGnt4rQ1ySFOqBVXBzkuxiluJ8sPr
4GbqKKo1d+6YITMwvi05wdYju4NQXq/yvgVhtGFgPpOnsPrx5OTE7vXsKiLE
D7zBqbiEIURrKhbM8AKhS+/u7iwnbGxsDIdD/jWuymQkuRg4nymcGpPJ5PT0
dH193c6g/CsMxQtfGZgBV08WzMDpeHNzs7Ozs7m5eXZ25rktgXdV4TdMYcWY
rp5Cc2x511mn0+n3+6PRiGBJQLlsay+iF2RHWEV71gxty4boLvb6+npra8ty
AnSrkmAv/HuBvROGLzYRV18v/NDtdiX8ENOD6puIGZDclZ8ZQva0LWmAnC6v
J1hO+P79u0hoTiDjAH+WVJnw4K2yoh0pYi0/XFxcWH7Y29urXn/QnT2htGj3
UADj9T6zU8PMkKKXRI63ZVlTlpeXDw8P239n/i9EK1CDzKC1rNJjhhJ2fgeD
wdLS0unpaUiGJJiF9vL8ylqXtfo6QxuYwW4fbB15//5949+Dk5G6PknQtsXi
LOz6sN/v2/Wh940x6cpcCq9wrW01M6QG7DRLBXZhWV5SyGiUAFqFeIEC5cWH
/f39zDdPtmHeFswAbB/W1tZsVCTZPiSa+zaE1OuCnX27hVxdXbXxADRr1bUI
JRt+a2aY+mbh7u6u2+3+8ccfT9sHYJIk89eGuU+B+R0XaLndXPR6ve3t7dvb
W3rvTGDYAEb3a2MGyRw9Pj7++9//Xl9f//r1a1xc/mjIf9mlPZJ1wbqqaJcN
NjbsMpJ3V1vqSsLYSr608fnjd2EG2FHl9mFzc5M97zmQ53r+q0ECVrexYSPE
8gPj0lPmNSapixYzzGNkATbbXUO5Vqy9lLh5wI6ex2lQBzX9qU7ztb+5udna
2rIx4y0iTU2L9rWO188MsLWj0cguFY6PjzNahEYKRzMWpgwJ2UBN/+opmSvK
xy7ceybZ3GMQNzywLOVJe227CRchj9kdhCWETqeT+/eeqMEZ6ptOOxyjeBuA
fSzGPDaQQhjmzTa+vb218WPMscRkLWbQRVPMIPSAJLeeez0Y02vm/qVmmSEq
jZcv3va6zKBOL655XoNr0mbb2A2FMX1jttt5z4NgBfJqmQGQb1eAxmxaqmeq
f91oyXJWIl8+BGKEhXYWVLXqXdg+e8W7Ca9PIjsIuHYsMI8AVjLRlhSUO4vD
w8OmtlBIIEf/ipnBRfkdBLSDeK3M8DpGwUMuZpgW32n2+087C7tX5clLMVGh
zVDtyBwxg65j/d9BtGcBnFT+62AG/Ba00fHancXq6ipvZ5GBGeAGlZKYiRny
8GdoB2HXeJ4dhPBiB9ugtsnXFZKsIs8LM0yLGx7KnUWDNpSAV0y+pcIcMIMK
PDuIOdoppCshgWiIrDujYoFe7fe2BM7oyp3F9vZ2ui+/MNOFZAbfNprJDHMx
z3d3d+VvJc8cVTfdu0+TaEzKXYCpEmYQ9moheMQ4i/I7C/m9tXDWRwMwKvC3
Yga70VtbW/Nv9zQmvd4AwwwtXAzjiYIk8BVAaSA/fvxYXV1lkINb3DEt8ZJj
QZ31CmS2qLGEsLy8HLy5EZnsyMZ4pB4/qXi4S0lvA13btOTMFf/YOLRF6urq
itQLvwhlr0nBNvPEDMjudgnX6XTiPyIAZ0TbinvUjGime7tM6XGWZy0RnR22
5/Mw4SzsmsGuHC4uLlRUeWdMxXz5bkJFe4qO5Y1MqMs+8ghpSVWlRkatfTTO
hCWKh3T8E513fLWmwJYqG5nlVS+MKiqojO4tJnPKDDDKt/7+/e9/n79XuZbQ
KiTIEIGbAcygAq0i5xXLbu/1DHU9FsZ4PH737t3+/j7bXgDIKa3NamhYbb7T
iQRLCx8+fHj//n1b3ruSp7C2SjVJL4ma0oHKDGLY+PzHP/7x8eNHuagaABuj
y0Nfl9fADJYW3hdQfpurJBgaZIamwGAG4AheWoq6m27ujJkYk7mKRRnDd2o+
mAEYgt07vH37Nsn9Zq3N7hTb1NSgboMVJePbZ/Dns4q9vT27s4iSA9IiOaXV
JMw7M1ha6HQ6rXgjkzyoGFUyWzbJ0R4Sa40lg8HAFjX4spgWM+CvQrSEGSR7
zfIWxz///JPcMwXklQsjQWtcbdjjN4U2ja58HzX+PihhKaDs9uaVGSzTQj8+
qz77LRGYJ6rblDse8EiV1zg9Li4ujFkvH9yOIpvtDGZog1/H47HdRHz58iWf
SsXN7LygtUMQMkP7YMy5MW+pFySTDnqOmOFF72QysbuzVNcWasNrdiOvteYP
tYQHK7yktQAFg8EAuCDpnYfqwegM0yvbfFyBnD4PzdJCr9dL+OR70uxgLHqF
zFC7rgTLb08tznM5JTWI2vf29v744w+GJCBSkMzgNpsjZpg+385kkVVrUmYA
cjP1qgNPLPnxGzJD0fjjx4+WH5BLPJ6esPLah5Yyg3ew+/v7ntuZ2r/ixadn
+8fScsyvAwvLbWzbPYUx+96g0F1yxrrPDTMcHx/btdZje1a8eABL+qbQKmPk
YG+nScKz4PHx0ZJD9XVDvIUkNeJqQdpaZqihfLDa/7P1wCa6cUh2B0mHkNM/
uroY0y00IHsslV+9vTyyXbUi3dZ2XpihavZoNFpfXye8Cn7Kms1WlRt2ECB7
vTJmgNuoGEDVK1N6f3+/urpafdmL+ozBTmo/M5RvZ4q/hmXK9V2ihWhTdQro
OFsSIs0kNuQBZgh51HnbiG24u7tbW1tL+vvsoAvVmCHFbNzc3FjnpP1F2pDd
bV6CSjgQGd66K1dYF699y4mLh9lB2cjHv0OSMWNAl2aZAe5S3v9MfXueSCWv
ZU7gc5ZdUrPRQtSSUHt4ScNzTkum23G+MT+MCW+lnU5aOajFDMKFvHtwMpls
b2+fnZ3pCEWelbdnSCapwI8OKK9IjZlXTVpWYZLEdX6rmHCGGey/U5sLYH0n
kAPaMU0yAyBqf3+feUcTrxxIChCjF6b2MZB5FNTuKqStwgy8xnK4dI1TXfxc
5iHGf0BBCJkQENLGK5B2B2H3EWpvvJEwA0+XkLjZvXRzWT1folGbSFf0lDdh
tdTBXXBzanOh0+kYMyIp4cVLa5nBbqnW1tZubm7yqFOGbtVOIaRB+U3pIqnO
xgyY7hX2uDVmdXVVq1wiSEOTGeSzXT4w9XR5IcMaOyckNrTB/t8BmXcWrt7Q
qecPw+Fwe3tbUSfYoF3McHh4+P79ex1ZL5j3zEq6DlngBXJmSLRJrKDf75+c
nJBV0A1pFTOMRiO7meKvl5pdscvLDbX7ghnahhQzMivTZofdU/h/rVUk+NeR
bNcZkN4aj8cbGxucX6KcXXHxjEQpwnSU8MNcZHr64M+klIrZgoq1R265I+H2
9vblggMj4qLpwmaGFJWtvLxwenrKkSJPSapGbzNdgmotUiSFN+l4mZgOEmbQ
tt9uKMoLDhJmAI5MWbuJFLN0fHz88/ICG40zQ2rM0VIEE6/wWtbboG0QUh9P
1DMULzi0lhlmLi+0Px5qeN3MEMpT0p/Vg0DiY4Sw7ddqXFugMkjMpU2ARcMc
a/PlzZs3tQsOQp/NGiVlBqEx9csLc8cMWoBjI7NStwGDClw56us6WB38AegV
lSzMAS8zeOWA6m5vb9fX1y1FMCgKJu+pxncTkqmeTCZ2UTTzFmjFyOGJqnk5
G1NFpwrZhdSs2dEJW5KEUJOHQdR4mmU3mG1W/P9xr9cj9YPjunJWxAzCaby4
uNja2tKUyBAV4n+MB1PAW02iLZEC2ZYkBX7I2dAIMxB7lWdsBhlzQWUGQHAG
ZoDP2lVQ2hdTqCQOmxlU8lGFGdjdE7E0UNC9vdR5QyIkP4mFKtczXvYUQsHO
WeluAqnaNWNvby/hz0Z4VeYUol0gpPZERQELJJIN3rO8hIKZAV7URcVSjam1
x1TfFPDp2i+Abh45q7JmwKNmA5vo/OISIYOWWEXwNMa3Z1iSbpVFEosRwmaG
qZPggCVa1pKEE1HeGGlzKqoNUw2EzBAaX0hRFZPJpNvtil7W9CqZgbpg8NZT
QEiijMYAOTR2KRfag0kYhnw27WDkzDY7N6Z271NVVVVMgAfcxhxmAIzFMMP5
+XnoV7oSIg+ZUAGnAymXJcwgzwUYUfltoILan4mYIYWcokGv17OZFWWGqmBA
iYQZeBiPx2tra6h3QesCyWWtIpBsxmSo18hlQyKk056/YwB3d3fwCxwyMINX
l/unFzs7O4PBgCCl2WoCtGS3wfTSKjpUk4RKkX29zVSSF153CSc3Kh8pKjq5
3CmwmWXMHuBaQG2zzHB9fb2xsVGnNTwzMDxG7RKdL2T0ekkZr7QaPLVJxXuD
QS9CRkKmPCOb2G2E8aNig7cBnKLUKStQ3A+5bkz9gWUMMzj6RcxAwmQyefv2
bfDCI4ZCG2EGfGiFWuKZGmgAMwPASBhrawepjA+30cp6kgS2wzFaeMw2DUQF
lfBBmT9sopq3mLZAAyEz0Ilt+PRAJWPKkJUoEfCKUhAXMrsZ5KnFDN7wZqjG
AxMPiZghJATpf5gZlOjRmF71B3Nd/ZhUy8gMD8YUFx61Mjo1M2RjHgkSGUkK
VC1SoprH69XmsFGyzWbZ2traeDzm6WGvGXjmJ31/nSYYcf5a8co8IOGTecNg
MNjZ2eH1zckMo9Foc3NzkpSxtQpW2yIhhT1tG2ObMZ++mkwmnU5H8oOwea5A
9nq9pwuP7WeGFobBa2KGFrrXRbY9USJRz7i8vLR5x1abgRkscXW7XV7f3JiL
0J1f5HRvSFfUhtfCDIXUjjHQLzp5L72wdxNUWOL6+vWr36YFWos2rO5SaPEe
bzwavcmpIPXcmH5UYSPMUN7aFLFsgSraUFiTmtHCqW/cpDTMYLG+vu59BUqA
Dap0kZYZ+v0+55fuf2c0xQzNZodce+PZ3QjcUc8eOT09xXxJkZkZLFl57oVe
gIEMYZ+sbBG0vyhlaG8PM8CWkOykXhVxrhpMJpPV1dXom9PcEpGUGSxZ/fnn
n9ReaSGJn6b6yrt7pWldiFPsXuWHlqR5CaQ9GH4jXeig+sHX/uTkZHd3Fy8y
NTNAz4Q2OO+SKcjJDEldlCH1UvuqkSUNtRneSPUFW0VC+canh4cHpOzUzPDp
06fgTY9tqwjT9pmUwh4tmW3wVU4bGLsD4ZZBzo2zq5fBYHBwcIC156eABMxQ
PCMBv0RCByrh0YY4z4MFM/DkwwU9BTMgu6CZYTwe23wEnqTwCUjCDPvG1F/P
ogh4Hwe0Vz8raawF9pKV2v03wWxOBRtIhMtlIrcEFRwWoASLPjPYHc3a2pra
goG31mK3l+z4VJiKCqG0BTPUkNQhUWZgrx9iKsq3LBrz2CAz2NWC5g9JZA7d
DGm7SMYFQohuE0JdQn9WYLMS/7yzOjOUvzxF2tHMMeiLugVoyHk9oUG4lzWQ
BYVif3n9r1zMIyJXmRmGwyFhMzPvgPekwD4okYuie2SkBC1L8G0wPkzhNPle
VdeM2gxGh09jBvvvkzGnboz43KDMDN1u93a+mEFubVJmYFzoyMYMQGPMSKlZ
r2Ub3IXtQ3fIjFn2MkM0jUPSHFxfXxuzjSEYXWa4vb3d3NxECqxJb4xMUpdv
oQ1AmCV1mlaqpiNerV5uGka7w+XbK1ACKlGASjc2NsqbpWExusxwcHDg/7KS
wXIhrzbIISQICxzvCEO1xCSenEQSouwa5V6kLi3OZ4C3hJiFzdCjo6NpmG+e
P6sxw2QyCV57ZPinJczAqB0Z9Gr1FdJXq+At99Wg1zKeyiTqSmV6bYaur69P
Aw6bJmCG0WgUfbvU/KEpZoA1aunVizeU/DxIl7mu8xMRTvSsTO/29nZxwQFa
cioyw+7u7rdv36hGihBa8ba5tIVAWjMnGuPrYAY5YjmjMKhQ6EokRBs/ty/e
9fQJlqfCDIXMR837HpGAmSFpEgE2pJOTU1dSM1rOGKF1dgoVeSTUmWFszJrd
/gPy9JgB9eqYrJgvZsipKxEzRMW6pN1yNG5kspVkv98/Pz8HNGjtJnq93mg0
wkjJ5OrG51RoRlL7E3Emnhncxi2ZrxLtMQbpJfqEXl1dWXIARSowQ/kIFVKK
x44UE4F3VOoVY+PMwC7xOdEqogC0ZzBMrh3XrPZcdordxHA4FD1zncjbPDeq
p2QeJoya0VR3pATFWXD74qVRN0Q8LTwbFEdR4ODg4PT0dFqJU11mmEwmT3dE
394i5bQdumnbBmYQ6s3DDHJQcxY4yKCykECSBIxtJEVgy+KLy25tuBUlUmaw
8pl3RCdC4yVSC+qW4AviPIKazuxFe+q1gaIBYMvi5IYxt7XmWsxg1yT1h76b
DTDk7DcIpFV54tOVKbdN0ZgUMvELA7ZhSf2jtDgpDs+8H3I2dUTM4L8juj35
2B5LqlCxKtHQVKqquiVJJQuJAqNC2AzTizRZz0de7pR22wqZ4fb2dm5+zTYp
2rOFySCKoSI/ReNXXCmYAQkvR1F7kfpOp7XBbmxsXF9fu2KEzPD0rUQbXJqt
byKZjTBDuJRE5KgwQ+pkFO7FGgkwydx5TyE4xO4mbBa754XM0DPm6jdnBji/
dJHC8lAgsRcMpMKXlB8k5EYiFnzpR7JxVIIeM1xd2QzuueZLmGEymSzj30Wb
Gdn4an6ZgSczGr3UZE9H8tkmgkqGIVEYtowyNpFVxuOxecLEactnhtFo1N6L
DJjJ0ip/rwC1uBIuHhqk5USiVBThY5IRltyAL4713EsNEmY4OTlJ+HMzYTsy
BcPUx+fzBbzNDGZgaFFEtLbyBE4FeUdtzKBcZMfQh8CKxZhDYz7XxEiYwS4Y
qlSTCXniEF715QFyVVlrI2czai/d9qS0Yq9bAB6QTzRDdXU4VDIHJMN0N31h
hmu7bHDOMJnh8fFxaWmp/kIGHrW2sBwD04fpqJIsrhxMLCErDrU+Ks4RXPK0
ogJ2C66YkocQPQvoAiLHazyJQmufZ9WVuey8roHJDC9PcUJDQNrcQmZ4AZIZ
3MmVM4N7nBrAsKkkgRnmyMt7clGhI5j2PG9E4wQ4CDdgRFeUGX6e6RUrh2pb
JjN4borODJU00TUG1t5mAnyBMCV1zWi8u7or2EzO7o6TP3zaU3xWYYbmn69s
ITPI2zQFSfixx0Wtrdmgu1yh9o0uFHVRyL9+Yobe7GEyMxSSxnZjomWVgpzG
0Z6B8FYvjeQCb4WvBbw0kiWKzJAxqApVM5cauMxwpfPWx/YkVAmePdUJzTac
kC72vqb9c6FoISkBGZaomKrOP2CvXq92VwNnN3FwcHB2dkY2zJHYwHYgmlBz
wQywLq2waRtXaKHmvRRzlyBz4y1JfOVw43A4/Py5elcDhxm63W7503gitIEZ
2Cu31EVB0rElzNBaYvHyQCgwcoKkVDhfDjPYBUP1l6QYzDAej7Hvg2WDMS9U
5ve2F5I2FS3JHXgdpS42XUdF6BKFYrTUir6iwOm0elcDgxkstxAel0i9rKp1
Yad2iiVlHsgTMBEzsJFiRSSESoEWNo4yA2/dWxFrzP825uY5KMjMcHZ29unT
J7J2UnsevH2RAueOE5xpZUrwfsD3TYdQ5GvxmJb31EGN2NoHaq7NMMOuMZds
Zjg6Oqq96gE7BEZjEjECsYRH1ICWwDs0IQnXQqXZwk0dnbBiZphlCfEiwz6q
wh1sxQPVi5AMZtjZ2bm6ukL2kkI9+KldhAbg2zMKN1tXqLGbLO1kRQxSxwlD
CH6K5VEHSw4ww+WlXTDssNcMGxsb9/f3ce3pEJLvPa5uTJuZQRcNWiJXnd94
6pJAMZCUViN3d3flL1BM6cwwmUzcx7L4dvKQlBnak5jpwKhZWpIzy0kKoZH5
mSFGR8ZMivc7lZ9pzGBXC3bNgOwyl1CZL93AxjMhdX0SOpWHGUgM30LkWaPi
DWBMa/VI8bn4bZqH8iPaiqeWV1fo+6IzuAijopEFjIrS6P4CyQyMbE3hMTyP
ycmZzZly5Fw1UZkBOP487/1+35gRgxkIP26bbt6BU15fCWeKIUGFshLFWNQn
2ZghneSkzJCHZJxqriYzVDuKf0dHR88/g0tjBoUnJhSZIdpYt3brgjf1WkSX
nxlIkLNxOpdG13LqQCpC1hrX/spxm93GHDDWDNvb2zc3NyhjVOomzrLmI1kI
/Nom20ojKaJhwyj6JGaAaRlpAM/V6WKeGkI+Vxc/kN1jMEP9VywbZIb81A3Y
0B5R8mrLa89b2uHTTXeWYRrhUZOwTcgncm9T7Hl4eCguQtKYIcezVHhEmSFU
fVLYQDolEUvtiyy13gJKSlIJMzBIPjSzDdbxkBxkkMDMAJhHpSPQyOL/l8qv
LyMyf3U1dh9hdxPI9sqIpj9wil0QkWlFPUWyQQjqEEjDZ9vgasnGDEkrBV5j
NTjhKEWexSV+tEHx/1s200nM8PXrV8KzVCEbeCDVL7Y9GCfjkT8IQ2jWEmq+
67ZkdMzgrhoZsksMkhmiZswcKJ+rIjDD58+fv3z5glVKNTLUvSUFlKcrc4B5
T3nP/s6ITk1m1zGWTOqqZ44Ni/dIE5hhd3f3+/fv+exnMIOubUIqzkBoSGbg
Cc8JOQlT26denNR0Ies+tXipGzOdXl5e2q0BiRl+vkOyJbFUQrHKK0rWXevy
pCHjvyWzKSnT2dKcIYSa725775884ChoNBoVd0ISmGFzczPylKUQjFFH66lK
WmVeJsnbTHHMgKllQjMYYK9/GJJTCJFrAZhBV6wPd3d3W1tbJGao38ygDt1g
kzNDIsMYBiBPqWip1S+GhQyl8KkWLn7yTBAs3Bul0SmDPVw8T2XXACRm0Pn1
mdRoyfJYCHgGk5IDkhlIMpFncctdjlJqM6ociVhSXxIzuJ5EMMOkyHQSM6ys
rGDtbxBIMkfObLqVLQ9JmYEdovhTeMmJ/NwUMzSyxqB68rkxlRkafjMDsPQl
1QtvQdRiBmRBxIBE9W4bjCK3RuNZIkVNT8oG7rxnK/Sk9kLPywdVXDcgMQPn
Bkg6X9GoVZJuKQCkJ5x9MAWFzsLSeMzgZU45FJmBl5XVcYXCJnV4wACC2bUf
loBX5zvY7XZJzNAn+Q2Zs94pezXA0zs1SlUKB6C08YlA1gienaFhZhs+nP5A
ewwzVD8jG88e7PV6JGbYYTADrxl7XlpVBUKqk5pEim1v9ZRTtMoA1dcPmFoc
aqw+ZRncy2OGAjs7OyRmoD00IQG7IGKYQXGWeXZiSh6bMN3igueH2p9wR8Cx
bneqz+VzhJx3JJFKaiI1kXldvAZw04HMDA3W31lTRGakiwH3eDTFQmnIZgZM
lxA1kYITtpnNDHhCA+yBJZAIltHAO3akQDkzhGjZlewa9vx5d3dXkxl4CSuZ
ghQAwpshhBoSigA4wf3ntUTRKiozILvAMY/pxTYYSeYhjcCfQvMArnDD0nt8
OqU+N3F0dMS0VtIrMzPIVVN7SQZIipCpLyS8Z6e4+MQbxiAcKjOQ5GSjYmRj
DDN4aTBE77BSoDoUUGYGLZCqRmbV+HDNA11djPwNtQyRzzTGTkjVPPPgXg3W
oJABUcYAmAFmfm+D5+NHLz9Ig7La/Oc//0E2hdIKw/DNMgPAqPDckbTAB2Ff
YYgrm/fwRap6MBrSAHWEJE99meKeCh3XIkMkMLGEl+k6BGCSmCgFZiBpxzMD
qUtUCK8vMmCiyYj0DxDhobRiGIMZBXzQbcBjBlc+PsddIaE/geFgusAD9x5k
0EvIISFd0VBBxkB4Iv6TiBkUgZcfcg5P45QS9tEjSGLxngoxA7ILPm2pqTSN
uSg6IzAzwI2Bs8jUUAmS2hEvR+GNZzBDKDzgBrDN06nN9CS7iUYg54SqHK2W
0TZAGDPGImEGpHB8x5zMEGopjwekMXBKUj2MbwZYAvwZk/b5M+1tb2RmSDQv
rw9a6bMABnhCaz+07JyVc3R0lPa7iXTuna/piwJT2aMtSWIZHX8Hb09ZoaXo
Gap29sISPJicGdLhlTFDIswpM8zdtGrtg6ZZAhshnHo/w8HBgboNTEgkz13g
ZQZ1d5zOgKagmOmM9kmBM4bKDOQnqn5zZuApCvXSNRuzf9FaqTaCdBHSnjFG
4a5AQp9nQWWG3d1dqakZ0J6Jm1NmkIttwxQ0vSBvBULMEGN+6rOWtr2Ctakx
L7P2ijGPU5DtkiNmtaYlMNQ41p7KDP1+H2tAmzGPcRuF+qBavufSkhAqoI1s
hDMwAw7UdzptbW2RdTSehq4BSRfSoeOIzV0S7SoCVYTjd0kqRRApJM/eLSkk
14Wmvomm/96EbS/Sy4NQQuO1T4sZEtUaSfow1Om2BBrDQqgjiraXT7E8MHiz
6WOGjY2NOfglGq3UzlwFhEwOCCSdigpM55M2l13qMqNxZlB0JkIU9fcmbPvJ
ZCK2rCGQGFWxRDaVII0nJsYDjRtZRbaqzbAknaNeAv5Z/uPj48rKCvV3LW2v
JOaBihuo9U2Fa97SkAnzwgxs6DJD5gh0mOHh4YG6m+h2u2l/Czug+DUEDxK/
1WC1kPkySGobgJ0OWwVwbcFpZnN8e3ubxAy9Xu/m5oZpG0IBYG0OdYwlnK5t
vyEtqCwnkGHPtoTXnbF7jXoj1IwaqKE/iw/GXPf7feqdTldXV8j2ZCyYgRRL
LQTDMDkzUGct2wKDUqZpJoWGzE6fSpvi43fq3dGfP38eDofI9khLFviFDMyA
jxN52U1tJ0+LLjOo28k2L2QSXeBJARIzfPv2TednqrSY4ZUxTIZUSsoMPJPU
+6aWxpOcwvPexuLB2hz/+vUriRmur697vZ5E6YsskfE1ekSuJ6k8L58jxnGG
6moXYfwrZlAebsmwysJAJVS8p9TjBBZSfO52u3d3dyRmeHx8fPPmjdSSqR4z
hKSFjswFM4ToDhYCMySVPIXA05Qw8luS8vhRIOPQrX2wLryj4EgoPq+urtpM
JzGD/e/KykoDtzTIkTqEFOEyA4Ze4IChFiMhJIGaSGODYiXM4DZTZ4ZZjMfj
tbW16XO+Y1C23N7eTvjF5QJeZKC1pEsIV5T6iOaI+QGkczih38iY3pTODJ8+
ffr27RtD4wIcZAv4zMzQuJx0kFiouLRDLkg8J8+MOZjSmWE4HH7+/JlspxAt
2U7m1565tupGdQq0f7GhKzCFV0H+sbRgzJcpnRmurq4aeLMTzz/4Xq1lhsy6
FJmh/cW9xMvGfy6shQEs/IDZmT37cjcjlRnu7u6aeUsDA/jLMirSeGIzyGkE
rTWeum+iDqTBgYcWA0hmKI5sbGw8PDxM6cxQfiA/i624gVIExoaXNurMoEtc
jPZ5RLUNqb2a33VCWqswg83rl3ewMJjhhVVEkDtwTje2sGTF9TxSmroZJEX5
xeaZUK3qgGkpHFGle3GDU/eZJ8jM0O/3Ez5XVdGHLamvqcDpjsVdRgIaU7sx
MzMw1OmlGDaRo0v90EHdCvJ88Pv378bssJnh6OhI57kqxzDPEXbVywnF4NRS
zWiQripFBaZYKWGGU2vGDjl8R8BgVxosIQEzHBtzcnLyfIDMDGdnZz+fq8LY
z7aW5O0UwKt+HcwgbEOCkBng6sxmBmT3kP1sEkZyhasLSeboKf5kjM3u5wNk
Zvj1XJUiM6h35wmh+jORGSmga4OEtBkdGUzCruCk7jyZ8rB0mcGlOziSfXTU
fXpty82zGDIzjMdjneeqACObkpzIknYygyRDm2IGOOm0/CwUxSAlueVU2nE8
ZszEmDVjHtnMMC2+nri7u6NZHjUyM9qQrc1CXruRLRVTIB0zMIosWz5SI08s
o3vxz5inLyYqZzjMcHBwcH5+zrenWejWl2YBj0JlncAzJhEzILVTzwINqLWY
bQDcMdTXDWaGwUXL4XA4GAwqx2jMUGr79u0b/xUu7DniNQt11Fq8ZevIkBZl
Brg4Uk3NnPWYsQBnJWGmRRcYqDADws7i+8qrSg8OM4zH4/X1deav0mRjhmz1
UdgxWq10EQ0YTNhnyIiarigzwMfZzACY5P2At1ClNoUIgThYm8vViwxT7m7C
otvtXl9fo4ynQitTXF9lC2YSeOMVUlMoeJCFJj8zhI6rpHytC5WLQqeirkba
A7RRYgaby+Xdj5UeTGY4ODiI3+/ULDPUOmqxtCKQAqlRWm2AzykSM1CtTdGd
NK3RpK6K4qVzSAu+l/uBNARYPmiDzWVjBirMMBqNUJcaEhUXeV1gCNRiGFgp
uwgiC98UPRC8T0JH2NOE7xUtkdHBwvlIMkzIpRj6YugFwuz51Pb2du2RBzYz
jMdj1EOX6tlUFTulzIVWDAsjHylfklO1fwwJ1T9Dzdz2rvEkTmPMachOWFpq
bqe2wVjIthlRHWwWu+93ZTODhV0zxC81wObJIZEst6qF4yIxQyivYRuiScdm
JEVn8uqvnJQYbRJxl+tV93Pxz7v+lzDDYDBo4M1v84h0SwuhrnTM1jjgoUUr
aTpk8zmacGwWV+9keG7LZwa1H6Z59WAEA6PQuMfbULup2rVaqiy6FAEstIDG
EkXoNt7vGSXMYLG0tMS8qwGtlZkgqfWqyGcUNYYWhlXzyAwSSnTlpGMG9cbR
vuCR8Xhss7h4aGLmjJAZCJcaeGghM+juAdl9F6gBZgbdBUlOOXL5YMurqytj
+lU6VGEG/kvmmw1vCeE0npiNGzCPyO+06MImhXw6Dg4OjBmqMwP/UgNy2zWn
mwUVzIWRrwnqqzjJ0oUN4nWGbrdbPGXpNhExg8Xq6qrdqiCFeOXGmSEbdWTb
vHg3s/CfijYk2kq7KprqzpOTgRnUgScf327LmAdj1ryt5MxgVyOnp6dIIWRE
Y/gVMANy+TTVy+gMXiWVyxS1NQP7MaBuD96rvj+LfcSgel6RGeyGYnt7GymE
DN1c0GqmqBQYHZAvqcM+hbu8jdNxFMM/idY5vmKtrNorLcQMlbN2K/HyA9ZO
cykz2BMb3o0KG/iE0pXJEAt3YSQOQPLexoD8DCyHV8HOiJxF3/WqnPqQQkJK
qW6vDsFbVir/bo0Bfm9OhRkGxhxpkS2S6iUBoxVsuoWbHZNe7ykaRrUH6J4t
x3lgMwOe0vFm1D4jraIUi4ODg+Pj41ATNjNUlZQvckHK8YpmsjRVuK6KdJJJ
ogBmaBXyV392S6qptfxNMVJ4QUJXN5lM1tbW3O8OdJlhWjzFqXbLk3Ba2dLk
aE8+tmrBkFnsdDZfKGVUalj+AIgyQ+Bs9C0KCruJAufn5z9/noYB9mKsPZkI
IOnSQhHsNWoKjby+bu0WauGZoStNa28yK2d3d/fbt29gPxozhMy0yxL3EW8s
8sckBiTVpMUeY1AYIVohhJeWlDGiUcFIInWDXVPldMculEjhRbbarUQoW58b
cpjBa2y/39d/1Xx0scSQlrOxivEAvWjFJKAUydtyS2oaU9SLDIsfuQp35YMR
iLHhWdrQmJ2dHVgSbzfh1Xx1daX8UDbJMySB1C5CdcgIr4UEbAPeOWw3Yjp6
bcb3UrETL1wiQb1LtBfJG15eDVST7eJtLTHlOtcZSrx58wZ1pzSDBrUA06mu
DVrMEO0Ld6yZgUwc6hzJmUELpAEC9pO0pGCGaBuvz4FRFEceHh7sViIkuOIP
HWYoBT7dKS0cbDaozCxDkUovFUpBRBGtbCUFlbtClteGT3IdRr4ESE7znkIH
TPWOaKChIjPY/10b06FyLwNIX7GF4Pumo0FJzcUErdsmWlUZiEpADsQrBLYf
ZgbkoKKW80I91FhuVc22Ggc+fZwYs2nMbUiSOjO8CN3Y2Li9vcUOgQcVZlAx
IF3VUMlHjCLgCFUjYImcGdg21M7qMoP3T4bz8WfxDXxDLqr3ZqjhNBEzFBgY
c5AhN9lQ4fZ0lqTjHIz2lkhLoT3FeBOVJzxxwRJ8Bz99+gTcET17UJkZxsYs
GfN0HVJlLhhChIQs1I5H+7OpKWkq2lMkl5ZwoXZS98rn4m0MS87vSoSWe8rM
YHFYgLC+0qXf1Eu1dJCozm92dH7dg3mMJO0X1LsDMqMHUxTTGWbYd6895mQG
zx1WkmwNm54kzKhiFalGEpN4M1QY2z3rym8DMwRyJN49hUnRg5ip4cZb+WVl
NStrTnK8pc8M02LZ4G5nmMjDDLwowrRUpxpMdyAOa4nDyH24McAMUbPhI1Sw
57QpsJkBMbSTk5OnlXy4k0MUSZjBEtTq6uoTQaWeDq34mbsoqsKNqOiIorQA
a1Fv39QCI2pGNqUS1bXujiibid5nrgErhMwAjOZf//rXcDhsgBnUA1gokFSX
o2eBkuFtCdQg79l084WUzDMglFlUpbxg4KV2TSkgASMZnGtjTozZJ9imxwyu
7ff39+vr65MUtUCSawwzEjGDw9HxQh+SFiIBfLxJmEHX4WwD8JwpUZqCGZDC
uZhMbBauGXNP6qV7d3QNOzs7ntdKRx2C521JsKWjF15fN7rY4eoKUcy1qHZq
ezipGQKF5kl0ySV7YwAODDhmipuhjfkYKjuh0SS6zlDi9vb2adkQ/eFLKjNU
myUtQ/Jm+KAlTVtq8IogSbirC26mrrdBISGxAAlwmWFSvMC5eB0sVIt87k/I
DNPihy89L21oao7yB5uQGdKZlyfrWyKKKjB/aAGrApnZdtHe7/fxmitHOMyA
N/b6+rrjW+FoTnrSGc8G3brpLQbIeJOsFrw1zjUpxUTwZAKOIrkuXUgD7nJd
Out8u1y3i/baC1q9svMzg8WWMT/kdCpp0CyQ5snjTSt6VTJXyAxaVRupKFq8
akmnYhuveyixXWYw5vxpH1F/mRLADLOS0u4mpsVbat+q83nozxZCmN2KzAD0
yuZDITtRTQXyCBYbUoQxwNWi4mFMOlQOTox5Wzxc6RXjinRMTs4MFl1jrhgR
jokNSai0oT3QHRnDwFlSGJNsw4M9X2xmCMUPiRlIpoZUSEbKaDbb4PLysvaz
kiHGaoQZSl1XV1dv376Nf0lR7TMVZxks3PtntL1cINI8uGZhKhopOKNa2NKi
aYgZC0OjkPF4qa3lIh4qcmyudTodY0YhagxprrTJwQzT4s3ST7dEwo1yAh88
cBuS8XieAYItBTPUvIGJIUA13CXEDIxMDB0n0bXXUbrTCrf3/inLiJOTkw8f
PgCcB6hNxAyhMT0Ys1K8nZLQRwheRsMJomhSNO+Q6cmQGTKMlFBRyUB3r508
HsMYHLUEQ1YAgSCDJBRXPGYI672/v19eXvbnWliJY1QmZpgWt27PfLXKCAkS
kJk1DQcA0jAJBQFtgFzDDIphqqQxCUjSiErged4rx3uExwzAbHqZIWq2t2NY
SLk+xyhxB5qOGQCUe5/RaDRj3DRlBE5xScQwAJ/X0ayPRjhSJs9CN+q8EthA
2gyYwRBI4g1vXpMGjvFbSGyIiGBTw/l8aUy32y2elYhPKcA0OZlhWt741Olg
L0WC1uQLWoYB+LAkaSfZGYr2cCjoeLWmvUFmQFroKhX6AZngruqQDVHiej5S
vhj6V/FFkJYbCM/HszLDtHjM6uTkRCpFlxnUdSmmmApgZqi2qXURamwcKqyr
NRYSCbOUDgaDvb09rn01/bmZoXwXHHx5pF2QBEZLEgQDXWZoCvhRJFqqIZGg
Kt3d3UVfzwJoaHzNYDEcDpV/AROJbNGOXEJraWmkezvBy3dgkd0sYBsqZ+0O
vd/vf/nyBSPDO/Q2MIPF27dv//rrL6RitVpGqiB5lgokLSFXhISg48pzfB5X
SsAkRqc+MzNghCN3HEWbi4uLbreLFAOT4vPxZpjh+vp6fX299ur7kOIcq1xd
ZiApZTMD+zjSqt+ZGVIDE9Vo9rB5tLGx8fJMpVJMNcMMFnt7e4PB7Nvv27B+
UwSS8xs0QKXLa4IsQ5X1oiUfHh5WLzzyloq1sw0yw3g8Xl1dvb+vvJ4uXVjm
WXjASvNDnRna7DeV3GyKGQBRsWXP3d2dMat24YC0CD6ehxmi3jo/P097KTLk
VeQ8Jk2EbLsVxe5sgSRRiZgBznq8UkW3IOWHj08mE5tBxnzF8xnyeAZmgN22
tbX18y2yKTIl3RpPjqhr2GYwot3bOF0d1BUe1QUcbyEzYDQ+HxwOh3/88YdQ
kvdUht0E7LanH9Uy5g6fJlGJjYBhUpU3X/rC0ZvOGG+vVvmZGh68VWI7EYiK
a2PW19dJtwZhIu65QWPXGV4wMqZTXF/9ZVbMFKhNIzFAisPa9ESZQWjM6wA1
MF4TM1TxPJDxeLy5uTkajUiOmS9mmBYXV//5z3/+MksCObfIoc5dpBWyCuQL
lfzJGNX4CvihGEJ5X1P51R6GAknjbhUzWLx7927mZ2u0JlHiqfbEdh5mAEoL
vm/1Ty2b0wVD2yIB53mbKaHLC/Ki1DZmKH/F++7u7kVfcAySiCUhczyoaGSV
B78ZkmUAafoarPVI+kpkgDvvCGa4Ln5cxnt5IRpHeN8nYgaeI3/8+NHpdOI3
RjIqGgZ5ggGjOp2omusAT+KZQYvNkMVMotGlwWYXNvQR2ezYrL3eUSRvPphh
Wlxw+PjxY1odSIEZmKGpUugdaeggW5fQYOAITFDI5Yp6fWFkI1H7ZDL58OGD
zRGvPDlZzh5PuJtgWDsx5p0xnt/JnVNgKng2vaTlBEky2ySt9u5CiAet9U+0
gdfUWN/y8oL74iP86CnslZwZaM62GyhjZi44pEaikqcoXEsgtaoCDRhm6Loi
0QKPNzp3KcKTD/a9vr6uvtiEF3H4ipHtTidSb+wFh6hW3ZZA+0SBGpLMUIeM
XmT5gZ0gYR5SG5V1AiAc35IUbKS5KPB0eWFz8+rqyneSaU7NeTWL8nw3wZg3
wgUHrzJ2BLoHhWmIP+VthslBfEpGB6LIDN6+QFJUx4KZF1cj0s5oG0Z2kVAb
aWhSnj+/XF6IhjaSeOBmOZmBAeuN+h0Oz3YoZC7QMipfCN2QI40dzwxRaZK+
sD2SHGfYiWyTAmi9L5cXoszgymBPVGuZYVrc4bDq/iBmKJwaQYOqa9Dyg0QI
ta9uSqYu9EjteGbGCSm+onx6OIJX8dgs0R5m8Jp9Z8zP561CHZrNTRJ9Z7Ck
PUyFQVPMEFLH82G1F54ZgLFXThWPRSwbcx+yjuRCEjO1nBmmxR1fbyw5uF9V
aGVB0mxqITPw6hqbA5FZIwfPQkVm0Dr1jNvb27W1tZd3uNXsBYwNjSnKKqmZ
Qcj6Li4uLtbX16mvy5ZqbUoRPN+YBCSZgSlC3uPejrFoi9gGa8SPwts43UTz
0h+0x24fal9GUHp7TMAww2z7OWCGafH2p3fv3om+xwRUvgJmIKkQdgE6YhKB
5Afk2Wbdoh1Ctgh2Oh3vK+LTaXY4pPndBDJkBoOBPjnkZAYqoobxLGesK1QA
THPtVBtmRMIM0fUV2L38Vu74+JiqGT+x3i7OIFrEDFHs7e29f/+e1jNpmFEn
hic8FHghjXBkajktZblqmBmoqxrvBOF9XjlracFGuPtkBF4nxuQaDQdaZmIG
rdn+8OHDrxdoY1YboWDDGxQVThVI1SVhBnyuUe2PtsfMDiCwQX4APEZJLar9
5R1NM7UvLBXwFilgQ6xMYgbJRFEJLYRyrbW/v0+THmUG1Smu98V3J1GNbr4j
yZMadlNfCPLsYYM0ENjO2qnoiADVzim7VLC0IP+leCCIkMxQ/MvEDDgVqHB4
fHy05DAcDpkKQlqpWYzXmIgZSM0Y0GKG2pGkYYS3mcQM0QRj2DN7yphjY/4v
5jIasmJE/e0dBI8ZkC0zoLx4e3FxQeuWnxmooBqAt5knmdQAziZdwHmN787z
XnTsRJwWL0k25gGQ7TUZmfhRuEkwp8wwLX6a582bN9+/fxdJ8XlEyUANMNIT
bikvqQzV8l617vKZojKDq51xKoC//vprvXj5QM00vGz8Z+Tg2sYMVCa25LC6
uhpfOUSJVeJQtmpkX5WS4O1Vy448lMhW5CVwXsVnmxElJToznJ6erq9bYrgn
EXz0lLfiVTtGKbbx7ybgXIxO4P39vd1WRK45YMIg5DshYCGwRjyhyW3LxgwY
Y6axKA/1goWrTy5D1Gzj4+NjG72V9YKONi9xRpnBcbMCM5CsZfSFMR6PPd9W
TAMOgtukmCEGM0SF6yYyyUiJCqorvN4QkoO39kgGyAgbYybGDAaDv//9796H
KIXBGBorvldOZsBbyMDTtxXG7Hn961UA5yBAtSSjeRMsjNVo4rgq4DHmYYZQ
F7cviRmiOYM0DO8KREtLCx+Mef/+feibCJK3agpdt0XnOSAn93UGd9QqoVf3
NjJgQtYgvemVyThLbYaU4KUaapDjlXoDlKoUEA4b6W0DHCRRTW2AyASrNTM/
Vws2Su1/7EdYBhJexwMzj1SqyAyk2Pf5DGkIpHpvb+/p2Qq8DipPYULUe4Q6
QkZwAMfh9Al1VGQG2E6kYcipwYvyDjM6dhI5zB4fF69GB97bRnV8tVdICCkM
K31zMwOpL/J49U+7fXvrvabDsI9HYXA+knKTbaewJRygKRgPryuU/phT0ZZR
ezDWBjo+PDx0Op3qo1KhjCbZEmrgMl9NPsxLursJBt1hBFKPn5+fr4feBIVU
CUQOwEqhhEKmkiTjogIBsbEQiduJj2YqMXqD25WDJI3o6EhTHzLb18ZG46Yx
f/75J8ai6KRFvesVFfKlt/2cMkO0/Q9jVr1vgkKKALRGmYENXd95BZKYAWkS
L4lIMqNOJqlTYQaKxtFotDb7RlMGM2CUA0JCqkMHW3Wn01Q1OZ6mY23N/ldH
3AJyqMwuQwgvW5TMsBG4vLwsj0N8vcLwRlT4K2aGaXGTpCUH6W/hwY6G22QA
o4a6lTFF3Qf0ZhbiTQnv9GHmGo3iPfDnxnQy/OAaHIzRVUc7mUEeL4CEh4eH
d+/e/fOf/+S/DErCDNGxRWcIYxs+wmu9MEtYLWhJ0yJkgAw1SNLSgo06Y/5P
+ZwU3pwU6YA54ghpOzNgHAVHsZ2jw8PDTqeg7gwp4ArHN+AxQ7Q7wB6kBOEZ
KemVQSZcTVkG3N7ebm5u7u/v41+2oMgMIcnwcefP5pkhphflqGizHz9+PO0s
MjNDS0CNfDlZtwrIFRTc3tvGaWmp4Pz8fGVlRfoUcFgzo693cG5QVBu3nxkU
Ue4sPn78iLpPck7R+KAaN8A1oxb30drsLRaIBLNx9eHDhz/++OPlF6vVh8Lo
CI+j1vL3ZIapd2fRknFpleloy9RD1lrkqZuBZwaSec8yr6+v7Q6iuL9xkjqm
JD72rh99SwsFZmhqktn4ubM4PU1rOkk4L1CBaVaxyttXxWnApMrlUyXIVFsi
sLtUG1FXV1eK1Sa6qJFLbooZ0rlILtm/s9AKTkkG0atVvSNQLr1/4g1gjIs6
HMA8tijvB2T7GModxPv378sdBDtw2EHOKBoOCXj/JdxNJIogLfh3FoAH8ZD3
dT/DLUn2eM1jZAfGS4r0iGQzmC2jLSlmv+wgkJYyRgD3BdzvnXD339TxTQZm
AEwNndUiB7yoXzsLiRQqhPWAKocqCkmMQv6MGhBtRu2L6YXrbsuKjRlLC7Vf
pIVNQHoLHiLPT0ApCPzZFmbwNqAGncuHGF12Hbi1tbW9va1zSRkzcxmYAUPE
1LO8BESCMXMpgJB/f3/f6/VedhAkGXCQ43kjSmOk0HMd3/h3E3AuU4sSvrHb
7Pz83C4eZu5O4RVEEjNI8hdvRuhsiqEJzRNapS5nFhNj9o158+bN169fSZKQ
KYzJ+lrKIIce6uIef/4sYgY5f8Nj1NKCxOPj4+7ubqfTuby8nDFOHcD0h7KP
ZAm+9mD+5DmBFKAky1UUheSEM+1r8SS1ZQZ4bQmkHt4KVw7cIDpdLp/M8oDb
UpkZkB7IluwM3N7eWnLo9/uozYVihLsdveUkFDrexoAKDDNg6AtWEdJbkwwb
wwYpJ0N6i3e+23iwtHAdFoWfFqotcIiF/sHS4OmdynYTmPgKSyNTqJZADMp7
XO3m4qS8bSWaZcLj+OiJMgNGDj6vhRJCBxks1xBsJAwGg5WVlbOzs9op18ao
maHkxeQ+LDMqPNrMGZEyMwCW84AMzxTh82DMTvGzYiO29Jj3PbMVahMSCAv3
ao/mI3JqkajFIpW7QtbC6kJ/1kwC1E2ndlNZzP+ed/WID79QqnqPUCc/5F1v
AxhazBCSiT/lNiNFYgo2cBWMRiPC5sInIX7WnV0eM7jCMczgkgnDrd6+3nEh
A9RNFWokhXrBTi4+39/f7+zsbG5ulmVBiCg5wfaGxuSaH/IQyXPPnwnMgGdF
RjNS7OAls9mj2tEuKY+Pj+2S8uTkhK+bztp8dyBVTH1+5ykFmAFpACwq1DH0
GckMjq7yRoXl5eXhcCj/wfoQkN4KJQWQLLBMPP+oMEOUskJ2AkfwaQS3V2GG
EnbN8HQZanOz/oAtiRl48+RtD+ulWuVNLsww4bPI2A2N0dsRNhgYoCut8s/y
gJ1Zuz788OEDcn3IjjokCQAh4I7be8TNEdeFgfac3QQpwGNi+RkNZ0CtDU+F
C7u52Czw85tNEkKxjTRFhRmopgJHMGeRzOD+GWUGpAGIs+UFZzun3W6X9F4F
RmhhJg1wmOsDzETBkt2wmhJ3E9HRtQH4iJaMwvJDr9f7tX6gysrjQXVykPfF
y6RSE8uwkhOKn53dNuZKKhyhM5TRADNEZeJPIW2bcpmhVYBLkERUtPWtMTs7
O53iNaDJn8l/VkqojK1lhhTEGJU5q/rlwQe7QzTmRsVzUTqspT9m4YOxhEEm
XoJSYYYE/K0pRHdm4db3xuwWP28BXbNCxq3QxFrAtXZtR+I3FZnTX86xc2Rn
amNjY29vr3yrs2R54vo7Ws1J5R7Do6TYQfKSkBmEcUeSkK6xCu7v73d3d5eW
lgaDwXg8hgziTX9IGv4UVWZTxKK4rpiV82DMoHjFyv7+vp2vWquoGKSZ8BEk
b0SzuCqKHTshWiv+8XcTihOIM0BNUSqbi9toP336ZPnBxl7w+jbADCT2F9gJ
FQxewLnto2VpGghToSt84W55wM7I8vLyy7y42khKQgeRFgFavLHgdRuGPWBU
OwqZAcOQDGSgF+TsqOiwsbdvzIoxNg49v0ICxBk7K5G2wcKFoabFDN6+jDws
PtzZvd7uruWEw8PDKleTiDBFwOAH5B4MGY83EhELDTODhPEYipDGqOh7fLoD
5KTT6Wxubh4fH9Oez2KYArd3BQLhJSxFSKuQLBGV44P19rB4NNL+q+3vQiMD
RqxI2Bm43/Uig2gb/27Cazym+LhCGK72KhJmpDsiu5S1W4zV1dVer3d5eQnd
WQdnB8kOZHvMP7kWzCnSnwGU3zhYPxuzYczhzc1NSC3AAHr85AFPAqZXiBm8
8wkTY/GvYWaoGVb7jExVUkZ7XceQ42oHBjItgtbSQnmV8pMxl8h8wVvg/gmL
AkggmjwShCRE7XFbPsP6dlR8Q7SysrKzs1M8CUUjJCD8hMMCBkqSzOCoEDPg
CESfGeSxA4sK5QFGtetkTPYgTQIa1yji3JiuMXajcVhctETJio4K1orvPiXG
LnW+8cwQ6lJpUK7HNjY2to35Zndwz79eip+mKA9Fh0idMXxjQHJ0gHDHkAcq
Tmg1M2DkI5mBkXBegVEVGO3lBxvVx8VTvpubm8Ph8KF2muFEoet5Bsjn29Ub
S0Xrq6Fl127Xum4wGLj86rXLOz7MFGOYAXMQeZbabOp4Dh5CiAln3ZJkN5Ga
HBgI+Ypkqm7mveDpXghj1oqFhI3z0Wg0YRhHsg+OZiTbRuVg2ntj2ifBrrWu
r68/f/68Xfjq8PDXZQSq4fgkQg6L1BjBfOQwi3Iq4GavN5D5XrQ3zpHgQBSZ
QUuU6zdM8tXOqozU36W4v7qM/F6vt2RMryiL1wx+wBgHZDRphF4nCpmhgpIN
7ILqySdLS/a/ljm9L3LHGAu0x1AKJmBISoGz0RwPiULyYa2x7xSNGUieBKWh
Dk4D0cqAQ4lxtwPN4AYktvHCssSVMZ+LBfNPlhgOPbdGwDowGRriSpLfhV6b
VVdlg7W1tWL0T2zwcg0hZDUSMClG5QDJGIoupHle98O5T1IUbTyrlLabiGYW
TlQDzEBSR+3IiwRI+GymXF1d2bXEE0ssLe3s7PxiCTjKMZqAJE3NDJX4tkxo
R2THZUdn2cCO1K4N7KgtGwABjB8uYCwgGS8NwwwYvXBoRYMWTs+o0yTMgGup
nMhCgbzuJOrQGjKC88c2Xw4ODkqWsDvug2I5cVXc7EewBskMaWC57r743nZY
3Exu1wZv3rzZ2NiwbPD9+/dybRDNI9deZGO4WUggHA/Av6gEVyky9oD20SHA
tDCl5TuHGSRZGXUUyQZkrrjhkYKUVMhqPB7bNfbp6enR0VG/uNnPcoXNL1t2
7QLj7Ozs5woc5rJQmumRw7i4WnJ5eWntLF+uuFTch2RtPjLml52yWQu1d+cU
kAOoRuZ1lB+iY3F1ef/EjxcWG/5HZgZSvCAbe4egxQxICV6N0Y74ePMel4dN
9YitxXfFBQq7inipxeVG3S4z7MGLiwubhvf397/uFg7FMZEZ7HZgXDy4dHNz
czW7GPhbYcDu7q41wPKDbTMJSA4FAOwTr2e8mQ4kO3G4BDZwJWNsDtkZGjXJ
GO8QnCNpmQEnGYrNdIDVYSzxhpx3RjA2eGcwFABBM2ZPF3/ZlL05K65n2vR8
ehWVMX8rXuu5bGv3xsbW1la/eH++zeVPxfbEFndbzf9T/itgFyFHBSzDfCpg
q3+/37ebGitheXl5qZBp/7Tyd4uHnb9+/Vq7bOgdO9Kr3o6YNsjProeBhAWy
D5+e0fbREWH+ec3GOYrADAsssMDvAyQzaAG/EuCtGZB1RF21YhekKG/pDC02
4gbAFSsZ8DqjbTD+xKhjK1KRIwzg0PoEXr3knfMFFlhggQUWWGCBBRZYYIEF
FlhggQUWWGCBBRZYYAEU/j80gqIv
     "], {{0, 0}, {350, 350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT9MHc2yZ69WcgQmuYgIoQ3QFzzxHOwDvcAisogsgtX9eMljLa2EiJAj
RAS6wScii8gish0ZOUI3IiSEkJCQkJTwhGebGYPnzHRX/+pP9wy+p+T73cNM
dVV1ddWvqufMmflf/+/j//l//9M593//R/2/x8/jKU1pSlOa0pSmNKUpTWlK
U5rSlKY0pSlNaUpTmtKUpjSlvslNaUpT+lciHBmyIs+UMtHDw8PNzc33798P
Dg62trY2NjZWVlYWFxdfVfS3v/3N/7m+vr5ZkWf4UNHHiv5RkR9Y/7m7u+tP
eZ6a2Y9aXl72EnxszMzMeJmrq6tevuc5Pj7+8uWL1+u1I0b64CocX+U19k71
lMFZDxYZhrlwJlbRQkAVQbbRaHR3d+fcpXMnPot95vq09Tnrc9+ns8/Ws7Oz
i4sLn7CezTOrpjFJHgHu7++vrq4uLy9PT089mHh88Hrn5ubm5+e9JR5YPn36
5LXf3t6C08kaA89pMsAwy0RTZMhHA0OGe5+Gz82AL9+zs7O+cDu37tzHz58/
+7M+W23MUvB7G7wlJycnHhx8R1G3Kx40fNfhGxLfWng8CbYWLItkSzPMMBt3
sriPnmqgyFCGDB1eZu18Bvmy6/sBn1l1fj03A74Wq9oAc2SIM3g7fd9yfn7+
3Fq8fv3aI9v+/r4/CG5AWkoQ8weLA12ikaHARMyR4aU437yZ5PRpvJTyeeRr
rk8i35N7NPD/9VDgj6iMKEAcY2qsODo68k1FjXiHh4fOXTiXwLoCfYWMCmyF
smrn5PtviAzEqXybUGxZH9HAI8AzGvh66o8kuoJB7ZylljwjYbUtIpEwmyEW
mdXnOuj3VubIUJ7MlyA3MsSV/kKD+fn5tbW1Gg1Y3XXU6OEgBoc8StSbjnr3
tLm56f3j3A3rQk2yCuDHh08aywXI0OS0Um1FA19ExLzb21vnPji3uLS0JNhr
q+wo2fXqdD2jhHMrzi3s7e3hX3PETg08eJoE7iCsZvQbIIMhFQauu7s7XwF9
NXy8+ObcnV0S2dinF2iKDM3hHhOOjo48kHrXeR96T7IEDDwOg1Tg2sKktHLf
TdDrwg2iIbcfRHKMq9p3enpabaLnfeG7uroK8Gn2xoPd4lohwyREbG1tzc3N
bWxsnJ2dda/DBP1KL5C54cVIbGeom/pXQYaSixsMPB+0FxcXPozn5+f9ftm5
s+SF97YskLN8HIMarRa141/vWw8L3revXr368OGD/xwTKdtQTJGBHGuGDL2Q
LCRMyNc1H64LCwtra2tfv361uaIooHyicjRbrCFPo+p+7OcGbX+feyFiOFTM
yJii3u906nGZcqv2UVpfRlhcXIxFKUXm9hUAGe5xgYouQ4izeSHi5OSkicbc
rYSGDIt4Jvq9kaHkWiN0d3fnocDvGnZ2duRfxBeYSTHwYSl6bgMsth5XV1f1
LmNvb697r7jhDgzZIxcji+n0jAwmNBxk8KXKo8HMzIz/78QF8yEAVouQ7OvF
kgxW1Rs6jw/tdZk0QUP5fNlESlCFHlazIsNA4q5LOQyrL5LPzs762hSIvdxx
U3KgOZXCKL8uHhn8GsXwoTCBkxYgg1718JEhR8hoZHbH1pjg65HfQTB+22hF
LwsZDNt3KT08PBwdHfm9nu8invHB8AIJTsPB5i6xkKHHHdNwHNg05ubmxmPC
onPHztnftfhCiV6tvpCho240Gp2cnCwsLPgVrO5BlSDD0MqWqRlDR4Yx6au+
3Hh1dbW5ubm8vPz58+eRSas3hAtY/TZ5mSZLrs7TXWdLzm1cXFxwjeqeHfL1
CqYZL+YKJJ06xfx5eXm5urrqMaF9x10ytQXlxzZVlRbmpqzIkGDx6H66tLS0
srJS/fRbYhdeH2jO8l1KRNEUGVCqryd4TPj+/TvbPo2JJt1ILBYH2JD1RB7n
v337VvUP283rkyxkGAMQoekxi+1fXhAyBKlA8FYqHnvOmZmZvb299p35Ggu4
MachQeM7HGQoaIlf3/39/VevXp2cnMgkaFqCXihYXl86MhSg6oGrS+/evQt/
z1UAGUwox5bYipK2FTfVuVvnNnx/6DePXOXm2wHD2SO2Pf2bIkOUPBRsb2/X
lxSgASX3Nlyi9xTmipRDlNmoXoh6nG8Ul5b85mLHOcaX0THltrvJTJuRKTLQ
VF+yrm9vZjx2NRmQxXaJMbZhIoNeggwZAETyq++3kHNzcz4eeCZlbnyUe5bJ
jUMQeQohg5VbWHkgo5ubm5WVlbdv39rfJpcja4r1msWomBmwM29vb9fX19fW
1q6vr0sYpo7zZJvxEpEB3ApZqWvyPzw8/Pd///fCwsKXL18MbFXaFBybVeNA
kAEkq+SBZ+3bBh8bvo0scFebYHKsPiF5aoC7CRNk4Gt8/EZ7eXmZt+7lkYEl
rUCD1SMVR4ZxdWe1jxCPD+ilpwzEKv3BUcjZwSKDyQYK5KkewfjYK/p9BN/e
nuj320SMU2vf5MltA0lXV1erq6t+f9HLLfGsPiE4CuEcIDI8qROuPxcZLi4u
fKtweHhobIeShpOtLFKa/UKQoab6ZxfBe6pF8iTE2iCwZCqRofeNrEbgaDTy
gLC0tPTz4SpBWS8RGXpElRcHaDqDr6+vffxEywqsQZDgLRAVbDfp3mNoyFAM
au7u7nw3OHH/0ouL6rEUzV7ETMsYqdbiNxQbGxt+K4r8AD+WjDmQAZQQ4zHZ
TRiuYZmmIrGDwAVZEdJFE6Nk6gZOg+ovUyTYWbTMsVpJVvNAnhoWMphTy7b2
DkIsSMxDDBQ3TEq9+fhxCZl6bi6PjLniv3bOx9Xe3h5jlEJhd5QgiAj+wV6B
jNjA9l5zyMQOIgecKROcdUrAph+ocRrtnALIgFALbJk59uDchnN+Z9HLo+RA
k8FexRYZiGYpaQlmA7sBe+Zp7yBkWSywUsNPi8qUZZkoqdEk8ZXzQiKYOFUd
9zuLubm55M6iAAXNBKc1KGRoATZLHUH1re8/dxACcNFQVvm5kSETcgp04ZEh
w1IupeRcXV097yzKWJQUzg2KQe0muMiAUPs7CHFBl9nUHdXsVbgCWUP0TVt5
ZKCPxA7iwvM1ii1Fje8sWq8yjo8QKGHIQQJ5sMgwtobQm5ub+l3JBgbZlptY
fCIFRlnuiyU7S2MSGTSYYNgoMjuA+jsLwb21YP6CdoHDMyGDuBoHLWRRcIjf
6M3Pzye2e+XThFaqzHpQTuFZy5ABZ0jGuqE3uOA8Hv/48cO5Oed44KBsjvQD
h4YMAjnBIR4QZmZmAl9NBsuHoUPzjaIlcGuGsjPJhy1WhUFZRMVDnk81eKrH
gs2fn59zBVvlFChK2TP0UmZZ5Fu4paWl8BtmWVGkLM0a4kKWgDOmIni8dcQE
1pUZLSa9Xn4G+g3F3JzvHL4hARVCF62lyWUfl0WG8jBS38gkeX+cvhAbEp22
QY1c+8EQaTEjZoNnEajhEu2EYOIF/cmaSOz45J/V+26WnEtf9ZIpB5nBmpP7
CmRJZHh86q9z/+Zc+6cQsC/ktrLiChFFxx4NGnozMi1bstTq9SLI0FXKMhXX
3pnU/f39mzdvdnZ22JJFpIFePTKUzH1CtYeF9+/fv6vuQ2tzlDfRBBmshOP8
3WJKJ7I55RAblMkFBE2dnvTqw8PDf/7nf/75558Cq4MM4CpxU2EgyKBEaA8L
7ypiPM11yJTEek2gIpx9IUMxKokMneM/q9i7d8SDX0yQoclZHhkQ2wDh8rbH
7x3++OMP8S9Zhk56ZMhKeARPaZK2t7f9zsKDg7IsImwCYBsIMsSkJSV7WEg+
OsOSzOP8pScOXrEMZYI8g6f9/X1f1OibJJVUBhnEq5FpYH2L419//SURLaMh
IEOORBNTjixGdjGCiBdTTi3186ifb5Isk2LYopkhQ5ld6bMo3y1EXz77e1A3
8mXpgO9IxUYWo6BDCisFT8H07ds3Dw71F2rivWO/yEDLF+MGi2o59/f3fhPx
6dMnA4mDpRgyKAXa0gBNKkkm9jt36pzfVsQuSIrhAh/SPWWFDOB2U3a2RaPR
yLsRurZQMvBssU8sNsbf7z4It6p3rKC7MlbQ08MnD+7v79cXJJU2Jm2H14GH
DKBkWTgjozwsrK+vo99ENOVqkAvXpaesyIDUHlCjef8qENsaYqKlPDI80fb2
9tu3b5VirEqwFTKIDWgNoUfVXwR7shdtW6oEsWpuQ1cgCxn6rd0yv2XFnyL0
559/enzA+fP1XMN5PgMyo52dnejtTINa63zIwMpZjU+GiQyDWmUlhYLEx7bf
Uzi3I17hYSKDuMmJcTY/Hx4e+l4ruhErHEt9haimmuPLQ7cNXAMMfYV0Qfm0
I5IFgT45pLr36U3sh1fJNWR5iGAujwysvv75c/3DasYjeWVVG6chtNwtAj2L
xHO/yGDbFCnzlxjCkszRWH/19u3bN5YYwhxWQXj6XHo3AdrZ/HxxcfH8ha9W
jW0uvyxkYLH1QjnwVoMM3YgUQwoT7qqfbM85l37YC6JWALTDuc4wjiBD/XSm
8GNYxvw4H3JeIJTV/t6do1nNHLUA6RPwVo2p1Lkb5+bF72cXIFlfyCBYoqur
q/n5+fZD25B4yG0ZIse2K+ZyCqS9uK7DPBJoFcHjOb3hI39ubq4FDrRC3CWp
s8NChiZPff/zuQClc1iGsBVABiWJLSSEmAzRNOpZKUcrwhHy48eP1lbaFhli
DEPYTQTn4tzIubXPnz/3UKE0waBMvdyTNZQv6FPJQBwoMmQlIHWr/5ysra2B
g6z0DwoZJiFixznmHU2IDnNmemwyI1iqCyeCuTFJZFCSBl7wWgsKNJLzZNqG
c3tB8YYRMemD/pGhoeKnYefn534fAd5DzhOdm4KKrLRbRSzIxoU1mToBMy3k
t0GGCZEPzi3VL0+JIQO4XCA894sMQSP9lmp+fv7q6iqvmvJErJzeQkQCCxnE
aSLOi/JIUoDs7Ly+vp6bm2s+A0rWn8JRMCxkqC4vrP+6vGDSrxpGkUZUSWQo
013YWiJDBjofegeQlnkKe6qhx80LDllpULuJSsuec+/qT2bIYEi9RxpIYP3I
qr37OZ8uAm+LVQqkTVe0dk+z2Tg6OpIbDNOgkOGielGH9vKCeblEVtyExEjI
Ms/K5iFUajrjCpjHRQauzMCZB7+nSLyt1YJ6RIaWA+6dW6ze/2csl8vZDTZ8
xcv38GWQgVWRS1K/BuCrr/dVY/jzBQeBjbSZk2yDQIbH57E4dyJuQWVwTWsJ
lgN8CK4oH1kBV/mBmeTYEsu9SZSmc3jyrN9QgHc4JAtdPGazIwOyqoeHh+/e
veONaXJmguuYW01qLnEcZwhy9lLilZGPCO8doPREpGXMPxHjNzZ+XXBApHJj
sMC7sJMx6zdNS623zsmky3i4TYVhmCmRIeZZpdmyCeJzSQarrWGagSbDg6K6
68VMXb+beP36desOB669RNQUQIaYJTXd398vLi5eFkP17hKAqgVZrKmSCGVy
mkl3geCtGLH1VrFWU4C0rOE0MsTp+vp6YWFB/wq8oEuUyKBE/dFo5Jsi1Rum
ZBZkrYmsIxrKV0NpLyF69U4eCDIkSzmd+Hi8idh87qyvr9O84Dw6x1XXGfDy
28TFZ7Zv376trq4mFZeuLFYkqDUstkzIkCxh+Kqz9LJE5RaCS7OKT2lg+AwK
Pv2pxc4V38tzIOvPvguanwceTIF7fmgoIUAG7kJytbNs0CsCOQWTVbY0vVAe
w5J7CppiMJ/pqfIIbW9vC19gHUODHJ4vHGaGVbXLCcKOFTrhbQ8+66BthZsE
scZskncqYttDKsyNDLEFVAFdvqJmNVas0RAZxGNNkCGZ7wQmJDEtVudiw5N2
0ke6x2URiEtmut3n0dzcnM8pmXVByn0/Q3Oizx9Go9HKysr5ufzplxIjup+T
zHqNtiGk1A5KNnGRTAi3hZANx+1MRg4XbJGzotU/PT19vvdJY2mDPy8yjMPz
Pm2/pcukTgmsETDYqjMZFSupeEFsni3soqBkGfhoyrpMSNdjZVY8ROvr6x4f
YrJpNA0dz7WbiGu8d26+/SzoYEjkRgmauK5kCcHZ8BwRVExC1xCczyq1rLME
p2DiMr9Z49jNzU3w9xQyP5VHhs3Nzf39fYi7QG0iDsqQISgkKZY4yMUWTbx1
x+bDQMSNZeqveZgJykF3vl0hLdeFXOQzy7ltxHPJ6NbvJlh+vby8XFxcDFx4
tKp0IGc+IOqqEJckIja4xsj4e0EGHBNk0C0gLj6LDSCQuflnXEv1xKeF+ifL
9EoOChlGo9Eff/wReEq8gGLoiqCubdggFhaTqYECgcFZ5whOFufHVccUIcMF
NiAQFwSKEP348cNnGaiBNCrXbqJLx8fHjz+oNCl8uDPBgeZUTJFG6QCRgSu8
iQ/KSk2IwpFBYwB9nFisyT/X19d9rin1F0OG+rmv0ZfQdZSpIvbFkXkf9RsQ
azqaziFYmkt6EkQG4njjSPXx1ufa/f29QH/DkardBAldE9T8OTnP1n8FmiJD
i8w78yDPQDxm0kU3Tvn/7O/vb25uCkQWQIbm54uLi+Xl5dFoFB2ZiQay9EHK
bZtePpJBtrPoNvY5SIkM5sBiK6cS5XNtaWmp+UJYWkmoDdFegUR0+Y1P+45H
sTcETWZoE4UKKRCfOLNVZeFKKI8MZYQMBBli8nUDz87Omj/Q5ocPGxm4Kjxw
raysMAak7NAmSCvLuGDaC2Wtob8ZDQTMxQJBLQCbbxuab3RiRXoBZPDA9eXL
F8aA3ERsgaaEUwxyY2dLUqbeIzcyIPI5Hcvp6enGxsZzVWkNpSeX+3cTl9Wz
4pOiX3xuGk6htYqDpUEhQw60L78EODLAfe/CwoJzN0F2WpUGGQjhz6c8YH1O
hvrwsyBJLwsZ9MKtzAMzGohjnknKLaRy+ubD4wJPTk42NzcFAZUVGW5ubh7v
heZAHGjKC0OS3JHGFYjkIyKBazPQwjKQQdMnGCKDQG/BAK5eFDvnM7EkMpDM
j/88WP3111/R04gI7imuiZmEc2UWRgaEWZMdJr41dBrIKct3MNObmKBZbmbu
VB+Ptra2YkOfD3bWELKwGsXAhoo//JtQYkDiCE5IZJZEBppeXAvUJbx84yhk
iP/lkSF2pJWEgjnyq2r1Lpe5u7s7ws3dSRgiQ0vyhw8f2Dc9ikE1FpmtD8HV
IeTItBceHhNFi9UXr6QBOIMsJU3sMR8IDs/k/6iq/d3d3aQ5k0fMdhNN4R6e
5gRvtaaRQVaJ+kKGTOUAlyBDBpOM4BZc2ViZbbKzhY2J8UiNvL+/9w08/kuK
sfV1hmfDdzxImftZ2UhYjQLFipGhcIgGDRjr/IBPhIAyjR/oShEU26PbY8SC
TdL+6uQe61HtOZDh8WeV4vdUBiWWHG6FDDJqrT4Sxngug9pp1UFmGQNuDJcH
ySBDILKloIU6b1cn7+fn54NtfBB1cnw3sb+/L3yRREhraWTokfDukUaGlzVr
DeEzxX3LEqsZkhRlvY4+K4OX/vIhQ1Nm/eYpakdTJm7FWnpMK1b0suRkoiFg
EaiaZaEJMgzPJ76Zf/66sLV0XXZzZDg+Pk40DLk9FkRA7nCrgVxp+jgXNOH6
KeP2mK++YcqLnS9b+hyJkAr+Dx8+nJyctBjzIUOTVlZWnt+VY0PcNDcMRVYC
IuGRHCULzuafJZEBIZMJChQJeGyRAZSTAyfjYi8vL59fWNNln4wjyLBqiEtO
xWPC8vJy1GAZKR3IzZrYWPwUS6BJbCiLviB5sxbE4IqbaCyJgTEGTUAmNQaT
fPLPxcXF1s3SBZBhd3e3/S6JpjeCs8i3Ul0qrLGYrkzIoAFGE2QQNBuIZCu2
4ChiYKqgCzUiljT+9Bn68eNHIi+fRpjtJkaj0c9rj0k8itlfgFgazSF9mCRA
hgL2cLUjWakXZajFkDgo6jN0YWGhyZgbGS4uLn4+XaoX/+RQOpCFzjpKP7YX
ihUakF/ZZQ2NmFatra01HxEZEWmGDFtbW1+/fgWl2Xu49yUr0CXmM+DF4aqy
M+89WgRkZ/Pp6emHDx9S2myQob6NgfFDib72EaxCI5D/QunFIUNQhWZ9rawV
7ERA1Xb+9BsKn60Tz3IPaJMgQ9tG506cYz3fvgfKjQwa6t0M2019X/QbIIN+
14MN2djY8J0DKUaODL8OOLfu3MXFBSiK0DGIeMu2HNBw8zYmKJClBc84pViN
tH4pE7AI/IkNOT8/9+BAChPuJpr66zfTgXLCIsZduOmP9MhAZzotX1PmYi5N
HkzKTJpE6MLt5zIgJuWQHJTWewAzC0Hwd9kNGQbXGY6Pj9u3MWAS2+ljki9K
MlGU7A9z1JfgEWSUXmaMzaS1wInGJRquWbbFJHPxQSlHpujp8+7ubutO6bEp
MoxGo/Yd0YJ1R8IVDzyxIplMlhDDuYCjkGQvXOzKIINAaWt1ZMg2QGToCm+8
IiqoSo8MXn77jmjluuNxmxsZxBOxNYwwqRtLScnB4Ad9Ds6rMM7gxM01llvo
XAaTPQfFVS8uLnZ/5fTEC9kZ46yO7zKe9wgrsxQopmKWIEFFm4RHXRAWQIGd
upNWwaUcaK8RjkjQIINJJaIpLnZ/f9/nb9AiNTKMnIs/jaFkjg8HT8Z8Y/oy
Xpzg+XIfkZys7DJLrECJJSc3MpAyfeY6txCpDKrdhG9FqLfZvkRkMClAweUW
xLw5DWFF6LqpkcwdxUWGID+BDLgHBNaClBrlNxTBO6WVyMD7ViLZcQ2BzFvT
bpx0cSN3P9k1pqvLKhQFw2OWaDJLOQppBpLmce1vBoP5ckRod3fXZ3HIFgky
PNu4vr5+fn6OGtFEBtsS/7KghkCGHOqSnK0VYTU5ShsQw8Z2HuM6J9/SEMhj
CIaASefO/fwhZPuMHBlGo9HMzEz7txLcSqqkgSNDgerWGqIZOzbyZ9b2Q1P6
ibFIk6AcRc8idiS4rFYA4tx99eCV7m8oNLuJi4uLwEWG5JSHnMhd4ruaMVlZ
CJnYyZKjj0MTZMiKsYbyZf0GjQy0itYHpgG+Z+heatAgw9HREXSRITcyZIUa
/foqmWW1zJaUyMAKVI0uq0qKkKydSPKDjoohQ/Bsivb29g4ODjoa5MjgG4Y2
1PTSDyS7FHyglQG5qSQYxsKPK1CzKPlQRQwmTQaT8oEjg/Xq+yzuXmoQI8PD
w8OrV69+XWQITsq8gIJD+kKGXoAxSBpLWiFqPjtunrbiSlkIkGqLyLRCBsOw
lw6vc7l1qUGMDO1fcWqgXsAsHqIkWiNuD6uM4iZZZbGheV1jZMhA8ORABhZp
qnwmjQRbaO71pYbJUBIiw+7u003RwymUQbI1zzZZ9JV9HEGG5KiSlBVnBiJK
rEjWb2iQIXT2+Pj44ODABBl+/b7yXwoZTMgkf5W1ZmjtVpIhR22NnS3pHFmf
KeuagkOqD91LDTJkuL+/9xuTqK6+KJMB5mLzVXZumJmL1VCOLM7aqyuppQWP
igzI4P+/dalBhgzn5+eBpz5aIbA4cbiuBoXbxknWZjiTqUOG3B5RCz+IyMzX
KGJUPbLxsvGnBBl2d3c/f/4MDiuHDEq9uHCWKGXyEvzgKUGsxrpWW1JmVklC
TLV1WixylMETl+DcsXMHjT8lyLCysnJzcyO0LRNlahg0/MhSWjVIxFk8PJqx
XR4TWqd6wQ2NfByNwbAhVg20k4MMrUsNAmSoH1bPsxDWYbMuBQyQZRC3hZA1
DAIzxqmUtLUBxMO+kAFZIxx7ZYtuGBiw05qXGljIUGt4fnwcSymoo2h2azQi
AxVrJOTXSCaQoUyeCmpiDjJBBoHA5CiECGQDpP37v//71dXV0yA2Mnz+/Dn5
6qvgeGH/Y85gIk2zuHpX6BOHlYbN0MoNVobzQo5rZIqpJTD4pwYZ8ONtri3n
zp6Us3cTH6tLFbCtPNt4USrWjksIZhDXhu7A3pFBLC1rNcfxJ5kC4hUHdXHl
46vJ7UDGkSgFtU9wPV6EFCPDZvW0B3AUw7Bg1rCmaeV82kLBcE3BNQxpk6JM
yDckTaKBDErKhwwsvd2DMoafZ3zDsPkUqmxkWFxcvL29BUcljWnzaFI4dzBY
kWBSSihriVKapBxlSznA1rzB6DJgqaoi/lo7d+PcytNnHjKMRqPuz7KGQiUD
tasL1y7IdJOehxhICxwCAsRIsBBDQ4ZMlGweOuTz+hkQuMjguwXfMwitEhMo
bVDIgOQac+EmBoKtqYlPrFKpzALJrO0X/cSrpiwxHfLZfXd3N+YjQ/i+aMQA
TdfHrXT6oiwwJmYDK4UHggy23uO6Tk8CcCiMDPQy5UOGFG1sbNQvtecig/Dl
tmMFMuBZ0B2oMS+2WCzJmZZYA7PIcVs8wY/r45wFsFZKBcT1VRly7qNzT6/B
5SED4xcTVmTrqxypSke4lf1K6IiZRCCDed/FMlJGhphpKyToUpkHTNrCiOTP
zvkcH/ORYW1t7fkuKRNL2H4ooJErJxMyBAMAlEazgW1Y7voFmlFSr1i7FTII
dJkiw+XT6ye4yDA/H3+LpciSPnunLnH7BKLgiiUTQxBkUAZbsRWh55KvZCB6
TXNNu+7izgqJw86fd87VXzGwkGHit1SgJVaUQ3isKBOcCFwLkIFbxM2rLXeU
fjlsJXAhPcdZmWHJxOciAx0kQADXtyWwkMHvI/xuIm1SDsqHDKx0y1TLiFIl
wBmZDSwq1lqAek2AV6y9gEx6CBjGmLrV1VWf6Sxk+PLli+S3VHGJklU2p76C
vEuGlmhyoQDsiEu8LOzNWyyCuhlqjic0MiQHpti2trbOzs5YyHBwcPDp0yeG
wSmJ9shguApEHc9hkrlwlnubB4shg1GNszRMT82wUSKDeQ+JWfL0HGkGMngw
+f79e0J7vzRFBpleFjKYEDdxShKrUUkOF2s3RwbslG8Y/NaAhQwTb8bUND8m
ZCLW0DbZkuECuaAnVp0vVYMzUqahTDV9qoxJfamjtVdvst7Y2GAhw/Ly8q9f
WSJNYCtEBVOODTGp5iyT8PnK5Cc1miCDld9AG+jjOZAhluZWzVUO6teAjvab
m5vV1VUWMjBuZgiuhQAikBgr41gEGcTDlaNwUKLXxYpAZMhBuWeHSEtikWyg
QCxu7cSBO98FsJAh8PYZGSXLhMn0y6MHQUjN6i69Bhm4tiHwolwXHMGSMrlA
zS1GGnBTrmMvyNAw9fFWBveKhQyzs7OoSSzKhPOspdGkgMyk7kFxraHl622T
AaxJOsRk0lYlczMJ1LYBIEB4PYriYzt6fQ/AQobokxky5REonKsdiS6xzHEn
m2g2W9KYPYbzTqaLtoGWJjsL5gKLbGdNHESAWqkxLm1+fp6FDNEbIH8/ZOAS
iAyxITRP0GCZbcQpWhFyRGYDeFaWFOaRKVg1XI5V2IBa4kaurKywkGFjYwM1
KWneS6cykwKRQZN3XbZgwCCqkxCkRDZBjTDHUny4OY4JcCOJPxGZ6+vrLGSA
nuYUGpkrj1gxTzuNa2RWZJDlspVwlitAZIgx690oNkDPlmm4RmzTq2DfEmLw
mc5CBvmPJszbJNaQoKMIZJDlhYA5WYiVRSRZMlgGI/UIFAiGrsAq1liuBE0l
wuVboWVMVHcVOmftkUEzqaxVGFTBXZpMyNAyRmxDEAlxPMmNDDEGJR6yLBnD
fsZVtxITxyIrtMSZu+qqP7e2tgaEDEFR4sjkpiHBYw5ZGoDqngJTPjgEPJsk
OtS5ckwAE1EU+1PPTC8KCOaIOpwnNiQ0O+7vJj5+/MizSrOCZZAhk9uVAgnj
BZWIJV9GVsiA67LCrhgDAZUCZMBjzHxpkhq7BzXIAJYYpJxlmjhIzXUsYAmo
wrxwcIeL7RToZRG3HOCWBNNfYLwSGZTaCUsQ1U+ffaazkOEf//hHQBpHY4Kt
F+oRGVgJmKOmB3mS6nCP5UYGmT+DMmMFVCBWDF9JkxBR3XUkeLr8FcmRIWke
cXxQBMa2OEhA7a1c01QQApC5QESDOS6KawAo0ArMWUiYtApUp5cT46crcncu
odj2md4PMlitaYxkeUQwgMggXnQaGRA7g5y48aBGAbZ0oY81BeKULTKYWKW0
hxWNMntorHj6x0YGq3QeDjIU09uXSbRqbki32OiiQBcvmcEaEpQwUI4VMoCq
cWSQin181lsvyPD7kaym66UlRyXjR7OmuRHeljRdkHKI4fACMqt32Bl8a2lk
zIsJsCAZIoM43cojAy1/IAJ7VGeFRclR1rPgXoH8bZFhULgEQkdW7WKgs+pD
kIPDJ2Qusn2cmAcj7v0M9asw7an3de/RgPLdLCK8m+BgPJv0ITGx+fhLUsyT
epvtnM9FBsvX0DwJzbVXHXITQmTcoAhBhmL2azoZgSIraV05MeFWiSDrSSY5
uciwtbUFGYNTvrh6Kcjw0mkIyGBrgxUyxOTkRoakGbR5FXF/a/nz+QyI61hz
zMcsoBeRtuZVbPhTriloKmi/eZjRxhh6NR9iRMRykeHnM53ETivPLCBxMyaT
36OQ8SQy2OZXpmVKiqVLZElk4I4lViGTz+M+4T7TaXV1laE3N5WpdFyg0DNY
kSARciBDMSRPZla/fVEykIL2N/80CS0snpeXee+b8PwgM5uISSWrgGDFxXEC
rq8JKUXJcjNfj6SRjISHIITEJBCoD1Qi2vE4xMxYXFzs5000IenCZZXlpmG4
BoHCJBQNhdjWHdlYjWrb1NYvU19Qo0cGjLjvm/D8o9EorL33bu2ZCiND9wir
k8ntt1jRyaHXqskxp6wAbkLDaTXH44eHh9nZWd57LZ17CHpYac9wFohFsQBj
TcfQb0kz6PUqGZw5ijV+CoHuFxqTYwPL7+7uuLuJFedule4Kms2dS7+1qQsI
fUURFxlY0oLHwexj5R3LbBkycLUgDAj1Di8iA25vb9fW1ljIsL6+fnV1xVXU
kmJQL2QSWBktjsDfj56XjF47bkabdFz0EBZY5aC+4CXoW3iBLi8vNzY2uHc6
nZ+f84wkbSg0MDa8l/QvEKJK5NTIRJKUq05c31l+0ANUJrKCStjh379/594d
fXBwcHx8zDOSRfrlUAawCZmkmIkBmtRQqjaUk8ljNBQIkkujHWfLH7rOHVX/
GMjw1bkPtlaZL4d5aRNQjpItGzWcwpeJNBO06tKzao8hA6g9mF+pgKmy/AsL
GS6dW5eZhLM9G58sGTmigtarKWTillgpVik/E+VoLRDO7vIhtal7Smx/4dLT
miaGDCsrKzc3NyxkeHh4eP36Nc8k+hSCDAIVSR4ceWJhY44MOWiwBhOoq9QL
rqYSGcR2ipOakIMYhmFC/W9ubs5nOgsZ/H9nZ2f9KLN6nTtfcPRI+r+AJcgo
HDnFSvVjNerw2dFycg+n81G/3AQyxFCOVo0hw71z8/Pz46d8x6x+5FxbW7tS
rh2gyTjscXwYGsX6FrG1NAAOxAlDiC6lWMOOors6+fzj3MXjdYb1MR8ZPnz4
8HUIhR5hayaRftX6Iltr6ar0sjwDUnL1kWJahnLgNrOFcO6zc7tjPjIcHx8f
FG72lPWRGwllKFb3W2FQAIHLe6Ow0mRm5UAGsGyZ6AoK6eI/pmt3d/fTp09j
PjKcn59vDhYZkt7uKxe6VB4ZZHmRQ2lyakjW5C4xAv+zIg0RrgEl6Zo65/P7
fMxHhpubm4xPaVBSMvj7qo9WbDi/plMytBmJ0m4S6ZFBv9AaZLCKN8In2SLZ
uUXn7sZ8ZKg/PP4Wu0yWGfZXhSlYNWIJmw8Z8CjlxjNiuQwZ9ETLTKIQcRzX
zjplC4xSI31eO/fqKQrYyLC4uHh3d9cbMpjgMC5BzIysr0Y+yCBABhYZhoHM
OXSuiZHBirq6uCZlsjAEnn5HsLKy8nSejQwbGxsGv6vqGqlk5lY6gTpB4rNs
YxmTicFkiIxskSGTSRoJOErb2gAL//79+8/nw4uQ4ePHj8a/qyqJDALm4ChW
3eklEljYZWVPMRixtcEW0pvluAsFwdqUqaYg7Ufj4OHh4dHR0dNhNjJ8/vw5
8bKqrO0Qy7G0EIFe1ilci7KyECsu83wwkhFRJhpBaaDbkWixnV0MGQhPxs4q
4Z0prfrx9ecnk9nIcHl5ub6+rrVHQ+XjVjaWG0hijeYVJ7iCtosY1BhLWDxr
uscNcUDpBAEyBPVmW4uVlRXnrsTIcH9/n/5dlS304YpoyTRzDocHhcsiHNdl
yCkgWjhxlosMMgOCPMHVEecjC1IE1hpKblD1xcTjo16fRrORYVx9PXFzc0PZ
UAwZgsSS3DsysOQoecQG4CRGhu5ZQzuDkoMrQtd0UJEtMiTVgWYkJN1Uj3p9
DlgJMuzu7p6enqbNGwiZON8wMQUSBpL1uYnVGwgk00dYw/WcWUXxxzp37Ny+
Ehm+fv2auNQwKEp6iS4ZRH1haSFUizNCGfBJadwhytZIOXDgumJKY6sfCwkT
mztC6qe8KpHh/v5+YWFh4q00HBtUbDmIFc80A3cWdFSM4+EhU4cYkxRLuMsE
GZJWDaQuy0R1FzSJDISTaRVBd4XE+lyen5+vHtiiQoZxdRnz8vISHDl0ZDAh
cd0npI1TyGCoonmQUJrPHtzOHHjIFZgEc3AgAvtBnuRADjL4XH6++/GJS4gM
u7u70P1OWaOIjl5DgVZjcfms6JKJQpAhFpCGM6UlsNIWyTJCkcA87ikuMwEO
pkHuc3l/f3+SS4gMFxcX0KUGmf3KNiMHMphAnBVOamIPz2sNOnFnGov8AsiA
GwP+qSQCqM3lP9Ha2lrrJw9iZLi/v//5o8u4Ojll7TRkVNIkE2QTwCarGTCs
jF2GfgNAjAyGnRJhTNJm5hJXdzLMdl5aK0QGT75n+HWpYWhLqWGzGqtP8OBy
g+suNti2GRCMsi2RiK7uZ3wUcjyHDTEhtPdCp3z/X78vwgoZ/Mbk4OAAHJ6X
bJFBUwJMVpmWxqrsLBXcsRpSti45zECAMbcNYn4wPDoTrP46aF1kGOuQIf0D
ihdKVsiQg8y7Iz3OFOgiTKj3xtKqcaKRgSm2+ivwPaMGGTy9evUKvauhL1Iu
VvkApqkXe0AfDhxIBYmpUaeUma97mVyv+/v7YBYrkWHiUsMwyRYZhgYUVqSP
Q5mEHHVcjAZijb2TDHOqf+fn5xsbG10ZSmR4fMj886UGVvPzQmk4PbCtJcG8
Ni+yhnlKiPqd4g0kVts2udbPNybZIsPEpYYekcFwU5Aj43JIQCqjSRsgFoWn
s2D5DJepWUOLkaAXRYzkz6J+v23IIhUyeJqbm/NbFZlVoGKDYmSLDHiEZ62k
Sb39AiZXeF+13lA7nu+tKk9rb/KYuuju7q5+i2VIpxYZfDdycnJSc/SGDPpR
LH7bGp2jIIIS+krGIJksgUwdnnR0hoo7Aa6pMatAgU8Uuin6WYwWGfyGYm1t
DRRSjsyRIbk6oGQEB8okbOFMtJWcCRnAMCiPqHTit+yHbfNbiaurq66MsQUy
jLuPeHqhhHR0NHNw+Toe7wcHusQKpHxmC+psPsrarWmEKyErdPz6+rr5vrnO
Ohggg29IPn78CMoZHInaMAYyEPy2lMx02maZOpkcQfog8q3aD6VPYm4pFgPI
ced2nTs8PIxLkiBDS0/9IBdQjoo0YcOVaSLcygZciLhmKW1g9bECXRpkoEFM
gAy0oiQa2PYVXXWAH+qnwf787iAs1QAZxtWvOEvc8pQDGcRKDaUVAJ8YNWNJ
Ga6xjOhrdrEWTm+bEmM1rkZwDEiT4FMUJh0j30005ZyeniZeT0PbLCNbD1sx
c0X1AnctLcHc0aSP4XAxD2JDEhWzkqBMxOCOSVtbW859JSLRChl8WzI7O/vw
8JCUol2CVo2jlzsphKUUOSggMGhLRm/QP2XWDtSlX8EubognaDsQlKZg89k6
Pz/ffCBDd1lMrkDWtLGxMfGo+XHI+XrC40oTeLgluQlBhjLooS+vODKAojQE
Qh+iSGBMsdVsubr6fHx8/Pxm2xZXDmQ4Pz9v71xskYGurRoJGs4cxNVOx5LA
b7JTAyRWXmsquNgwAqCSqoMY2x3eSUPn1i4uLmIWPf1phgyeXjt3L4A7kNkc
GbjxbxUkyaUXJyYdKgItYH3HHZuVutay3GVuNguX8CEt5qCE2Ko5d/eIDOE7
oicZLZFh17kTAq/iohnYaLiOXAnFkIFlQzcRlEjb5ZEhA7imAquU1oI2gPCS
lM+SQCY1tfRBjSGlz3dEp1DTEhkuLy+XlpbCpmpIhgx6Blsi1CGlrXsk6BaZ
PVwDQOHJ1LNFhqTwGPM45A0NMgShEpSmR4a4B0aj0fLy8vX1ddIQW2QYV3dK
13r7p8KJn6RMyIBISMqUYUvMmKTYAkuD4IMy/ZPauadstYfC5tK55h3RpAxj
ZPCNyu7uLigTVGzWdZTRRUgjSgloibJPAG1jSU4ag0jLlC9cyC2jvZdorAR+
6NwRHS87xshQP1aOuOsyqSbdMglE/WbIMG7kYw6yFW6LDDLDwNalTOcAAnss
gFkDG3R3d+dzs3XTUdeQTMjgaa8ikLmrJktAZq0OrWwtQ3SoKy3hxm1JEujF
ga73FUSYCUAjMWdnZ6f79PiYITmQob7DKn0/ZG6SBYMm8ArXWWKUeBZc/u4/
rnzucQGZ53vuWgB2OEl7Gn/Wj2+qsxJbLhUyxIT7noH4gWchAgM15kxk0Q0j
RA9QXWniTJeNGiwymMsE1x1X120JWMgAiD06Onru5HtEBg9Qc3NzjLYhE/a2
hHf9TxjAQgaZPTHbuEKCpwxt4xqQlJ9vrZtaxsAqgzzgWTEzDrAi8pnoG4bW
1b+syNDh+aXrv/7rv+qnVYPSzSpm172tOCEqVAF0GofCQFwOrIpLTLIsRxDU
ykoE3gYjjT5CDLclk7APkW8YdnZ2mPJyIcPt7e3CwoLwDVZILndVNo/QCMAS
ZUKEnRrVrKgG5eNgJXCyjAwVETUIj7qkdu4pFsITzCF+n4O+YfD5CBr4xGCJ
DC3a3Nz8+VhpQHo4Rwwrlz6KCDtZhjUZlMhAyIzZE0z8YIKA6goQniOybO0y
IKmqRwY6nIzw0Lfuf/75J1dGVmS4vr5G24ZmuLb8JkMGOvgRohcrCRG2WaOX
hgdhsXzXUwwZWImmUafkAU1SJIXPvuRtyRFvZUSGcfXiy/ZDG0gdgVzWIAN3
FJeHZmMVKRNjlFQMzXJPh7X6mWbNmj5ucKyARvh9076xsYGI78jIiwzt31iV
yQWTgs5dvqQEvUCBapaKvpBBZq2VYeIGQ1N9DNEpPtY3DL5p9zkI1qgmRORG
Bk+rq6s/fvyYsGAMuCIrMiBa8ETWdxesgWAB6BYXmTox/2CRASEcGWSAbzjT
+EL7dr37GFhCuR4ZiKDrHry4uPjjjz8g4zQubR7H3W5iBuJoDQmQIcmWYyCL
oetAW1gAZeqVgsggi09ce+eDbxh83gWf6I7lUHZkGFcvyTo/P08qUKVkyzN6
ZNBHlGBGPRKCPyxTg1BDHGz9U1JMGvGnrQFBe4I2xNiQsy2DG5/Pzs7o10rS
kJZ7N1Hr8rDg4evxSwqxT/AhsujVGyMeS6MTUo8IsdxIa42l+QXCkweTuQxS
rFIkI5B2GjLlfMET80zng8+1paWl7sMeOapKIMO4erL04y2ROdAYUV9Sco6S
Rwd2MGBkyICPjRmTPBUzWKAFsQ10gmzKhOe5dgooPvbo6Oj9+/cIe7w45EWG
Z7q7u5udnfX/TdvUUWzmOpZrxKeSZxFqBlh88cIMYIkMnsXHIvbTZ7nClRCR
NIZlFQjaevP4dHt7OzMzM5Frk6oQ1MyEDEF1Hsd855AOeEQWHdJKUSyZtgOt
tMjSgZUd3HXkjlKmHgh6REiA5hEGIxYSqC6ln/05pjkeQRmRoTXi597HpCrJ
kEFDZZLdipLxRqSJDBmSy4GEY4w/JjNmEm1A1/iYasRC1sCuhcRKCULOuTPn
VlZW6huPYwKQdcj3i6qg3vrGp1/3S7+gdCtvqrJodkXlIyTj6GQEVeDIIGPI
TUpwSwkZObfs3POFR810WcgAgihtz+bmpt9WwAamlLGYXwoK1RRDBn7AGJhh
wqyxnKitMoFKMlFB4KdI9f7+/vb2ttaqn0okyKBZlvpZcN3LI2wyRIZmxuFi
+4KafMgQlGA4TUPLg7UVaV1w1VnBJxlsfPnO3TjXfjwLIjVyULKbUHrl+Pg4
eNOmkHQ9U/hfbr1DIFnBGgjRyBBkYzHkbjKT8oMTjJPfoTu34dwnRG3XCitk
iCnC6Y8//vjnP/8pGakx4kXnQk2aIhjk7HH6uVsUUOO4UyBym0Ebk+QMhfG3
6sIjVzaJqf0gw+Xl5cLCQunnS3O7ggGSSXusiX/DHhtBhjKLJQiMHnvLjsAH
5xada/5EgqvTHBk0tL29HXz6fXbSl93BYguYtjFkQOZFp3OmLCjj7WLIYD2j
vb295wuP4jXs8PSGDPf393Nzc78eTzecdGtaQiRCJmtLhlwQGQTz0nsDaXXo
s0kJtt0RwqAfCNhw41zzOe04MqQwvjdkGLd+P14SGfRLk69FxHNEaUMMFrKu
Au1P2gk0SoPIYJqVlr5qTYS29un4yLn1xy8Nv1jBeXlkiE1xdXX1pHydYo3N
BwKxg91Qz5G2QfmgtSZKibM4MoxJ47kGsMhcFIJyk6qPj4/fvn2bA857R4bH
l2pVHRFaKInjmeqdWGyyxtEDu5nLNQZMQ42pvz0JIlOjBV+yp8v4zVuDTC3q
GRnG1UOflpx7AP1fZqUEFEOq2EErtMnnkJL+zFP2DGQWDiq4p7p3bnl5ufUE
hlZwaWzv9zrDM+3t7f3973+v1YB91OCI1QAnJeDSQI8hZtj6lgWAVqqtEkNp
gBVbZGx9V1Psq70mPhCLQMPIQJDB05s3bx5fW5MjOOkjtvI1KmTIAIodODJo
VASV6pslq6ZOwxYZe/J41fEtLZtGhu7ZISBD0NT6Ld43NzdyEV0vEMhg0pzY
IoPMBo2opLt6JLH/wbFJsTEJBYoLSZfVfU3ORX95lKwwCE8v1xli1v5wbsk5
6MbIICayoF6ADKxFNDFGUAFZyVISCri6ytgmaA9MlqPLgC2cz476l9bdbBJH
3BCQIRHpzu05130HX0BQVyjLgqA0QlGSmVCHM4N/Jgcqy6hhSiL1oLBJXbFZ
IYgbnKSEkXPvH7uFvW49pGUEVXXTaJKt6G4iuRSj0ejnBQdaBFdlTPcQoqLL
zIU7ZJQVMrCS3Sr10kUlNRYRmzUYaHuwlD5x7u0jMowiuQxNAtSvQYZMjuRd
cEgSWFU1OSVzBI1R4hTAgzwWW/ioYsjQksblTwId4bpY/IhnlHR7xJJL5+ad
q+9eCBYEW+zMgQzE1MGk/PHjx9LSUq5fYiJGxOJfDPiIGUgMg2I1yGAyFzGB
USWbYPcUmKfNzzEviZ0AIIPPheXl5eDrnPTQq0cGVmwGj+Ae3dvbS1xw4BqR
PJVEAFosy5igR0yQQUyywmNbqMDjtEYlaIhHCc5iZvgt9vv3731GwCMYGuL+
tkcGE0pfcGiRoKbQEgyJi5V6+UoheJDjowghXMKRQZxI5vCC1IKIdp8Fb9++
lT0OGkSGrkXDudOpo87/u5ubmwt0UAr4ZakfkBxafslmg1DHPc5VKpBWEhlA
XQimNT5cONf6cQQxVFwPcyCDbNlBKLu5uQlcjSzQu4hXWRYtYsPMS1uSXxx8
XDLpTEwsaY5N5nXSTs5cPCzMOPfrGSapqmi4OJmQAfQiQpeXl69fv058VSFe
cWXmJpFBQ0hrJDAAie1MpV9gjF6OWGZwLOg9GiWSmVwdv76+9mWx9Zr7oBUt
eUhEACbwrjPAzAkvIsOf6du3b76hoh6X3Rcy5KDuMptXfFkyDhYZ8HwwoSRy
xoyJAUVI1F31U8rglxG0gGD4dJUDJsiRoaTvT09P37x5I/wes0z6J6t5YTnl
hROKBGxcZOgewVEu+CfXMDuNvgguLS19+sR7RHzwbBer4JWR7yZMVhUfuL+/
D4FDX+Ujd9KxAlKTmLbZCpYoWwIqohwZaBUyzzc0Vm+OeOPcIVeGCWdjiPY6
A20JYlIzdmj+7e3td+/eobpzEJj+AozmqqaP437Hj49F8wquq8wnLIThquAi
mC0yPJGHBR/h9S8jZLJZ8yaX2rhnEIQAa03ev38/8ea+WIegz0dieqxpizNX
bCTIrLRBM5weSyedbTxpRll7oL6jybl3SdRBwBuJ34EjQ0RdeGB9B9TOzk6U
LysyjCOu56J5zGyuSSbIoFkzpUkmEpICcYasc08J39vbqxqGXz+Yos1MIiiB
DABoMJBBsGJKZAiOfXh48OBwfHwskcu1QMPA4kfOiheABvEcyIAL0WWThKyQ
gRiOVM1JOjw8/I//+I/q8QtRGeBCgaHU4iyMDJhkxgTrg/XF22/fvtlbQ9vE
GijIZdliJwXiVlmtcdYUs9UllgO6MZnh1f3PPp5bv6MExkmINq3BJt9NWBFS
1rpHbm5uXr9+/f379wCf3oNDQwblqG6dwD3eC+m7DhxSkDzB9cZUxOPzn//8
Z/D+Z6T02xo7abLxdQaxSfjyNsFhbm7usXMIel4Q5APJC5oIuKRbDroCmc/d
qm3IN1wWJEEVMfemQtF3Cx4Wkvc/E7aDfcXvhAyxeG/+6V3q27DjF4QMehWE
BM2Uk/CCqwD9n2TTYJfSS4gTmsbjKdqgw8PD500EPg4BpOTA2KnGB8jVLAzB
CYxBmu3+/v6NcztBZJAp1hA32q00Gg7nuo4olyCbABnAzAWn0D1lEppxGo1G
+/v7//Zv/5b8ESWh3HDgy0IGnOpvK7bxEhM8xapQsbMCZFAyc52YCZrM7Uyq
S/pfoC5r1j39+fig1/fv3717F7yh19BzYjeMYWRocoK6cIDHKQjV9efHu0Sq
e0R+eRssKzErkQjEPyOzitkQY6YPIuq4YxGZOWxujQKXNUMtS+gFTo2qKPWw
0HwSi8B/uFGgtE5cDBQZ6GiKCd+u7jh/QPS1QggE/CRPjmkjGvFgYgGggJLG
BDWyJi6AQfG6mCLM4873zZv6uW1N8SVhjEaGhpPYyMDVKGPm+uonv3P7zv1R
/YiVIZeOUhBkZXbLKIlFwYwgLOQCID42ZhIOZQJTCe1iCRqqhNzd3S0tLR0e
HhoK5luBhob4TidCrCbKMEsSoX16erqwsBB+2AuS9SxkkNU+JcV8ndWeJBzh
ppovvxVlA6ib6nkLf/31V1eA1YSSApsBGwzeSWYzZOhamIkQ+T9+/Jibm0u/
tEJva1ICDT5iA2JLS0u2SsnyBY8wJodYwbLGh1xcXMzPz7cew5IbGegAsUUG
jdktw4hTVo6ql8P/lz3SNuoKIwOoF1dhyGmbAxpRSZQTyI8M8RE4MzMTi8N8
EJtMf1r1YJHBxGP1A2YZj6ZPmiij3MufScjQkIEFp6m4l/c/MP/IuVPnlpaW
Yr1rLM4LlCZgVAlkECS7INaCQ+7u7t68efP3v//957eZ+ZKUoKz5qx8uO1We
WAjWNxqPRqO/O/e/n943R0tqfdDYrof5J36IuxIrsVXWBuD8XWTojvJrtLe3
t1RdBZIYAXLiJCtYyqCRVo6JUQIhBbCF1Ut0R2Wg6+vr5eXlnZ2d+qaFpGaT
bogOEK6TyiCDbJRJLD/Tj+qFoeyXXiXxV2AoFxlkSDKW+hFsIcBQUyYgC5oQ
ZhmMwOSh4PT0dHZ29uevgHmXKiGSdQWteSc5+/oVdoFK0qV6Z/Hnn39Sj5nt
Rg69tPqZJCWAqRo7a4gMQbamCrGpoDH6riBn5Pm4qh7X9ra+oablfjEmaXwQ
HEUIbNjMQwYrv/aCDOPnncXzRSFi2TIXl18kkF/MNpBwZEAQNcek6EJrofHy
8tLvIHx0xR7X1i8ygPIbRv5rIUNNP378+PmdxdBSrKZkrArMztQ5sEiDDBr8
JIZ3cxg0skG+3PhYat2xEFzDfOljInly6va7CQSGYzzK9cdPQTuL3JQMV1AC
zQmWRXFl0q8ZPoUYf+wIgq6x49gqPO0g3vkdRMxqEJ8Q62J2gYtM0xCQoWvJ
mJMQhBDOqcmdRT7CA0IgFokhHGQEVgkWQIYMBL8steiMBfzQ2EFIgpBrPrjg
oNKUBHtkYBmQPGiupXXq184iHynjBhfbjXaBcMNlQOqlOXFxBhnSoXoH4WGh
fiNtmcnhWsQtRF/IoMc0mTr6oN9ZrK6urq2tCR6woyVbR+iRISsslESGnLpu
b2/X19ffvXuH3MXEJW76m4gKjS2BDCxA4HaaAgOCAk9PT33z8Hh3ihhwDUmv
vZeGIdYk0M2xOWVbO98q+Ah5/fr1ly9fuCaAiaxEBqs2LTcyCJJMjwzEotD2
PDi35dySc2dWQVugciBDmtPOVGbEK03wg9IKYHilwqNBfWdjsrcEm9UYQ7KS
JpdaT2WQQUMCCAWLVUzE9fX10tLSxsaGweaiZONhggxdfpZ22/kOBhlunduo
HrBQX1XIbVFyubLO+ElvP1cgcTJsrnCq73H1m4ujo6Pgre8GOsCBgvjQZ6hJ
mguwqPsZV5SH6oc8z87Ofv78mWsRF1ZbnzUuoSXTzDJkYAkPmjcOzb1YaWXF
qe8ZNjc3ff+QeMhDLA5AZyGSQWQIFpuSfUvMGJC5+5lmtvJw1+aKzs7O/Opv
b2/Hukdi2VngkJw9IYp2RussHUeTZvSGDE02rifFFEumcXx1PCykNxfJ5ZTN
jesUJDhMDMMtESCDoXApMtze3vqi4LcPdFHIgQyENHpsjJOQQJ4yRgZYGg8Y
8xESZb6lPDw89C2l31zwhBJHkLNcObR8AhlsXR/ThVtI8BhSSGB9o8LMzMzx
8XF3I0mUPI3teOInR+HIkAIc++sMWRPcpATJLPQ9g+8clp37nox5rpVJZODG
B9cePMQRRQJkQMwQiKIXaJLB48D37999f/j+/fvn/pCAAtrelnh9QNL+AFeY
rg+T/D0jA7demSMDNw8unFuuLlOf6REwhuZdQ/UolDTDRCC3MhHqgsdx20DH
VlRfcPZrurKy8vxchZYMrpO4gZ2UrMeWcQgfYqb2/t2E2IGIWFvOJvnt5/r6
uo+lZiAJSYNToNheDAAtoWuhhhngqTHB9wlra2utZzuPScfk8BMtWQyxNHNM
bO/IAGsvkTFcLdfX1/WXFz660l9u4saZTFXWXekSTULdKbNMQlqLEM/IuZOq
9/M7xKurK6699ClZkio5wbPBhqHLaYsM3JDJUdmTnDgygLX09vZ2a2trbm4u
eM2KTYaFARkrEChwcdLptlMmh/g1OnZu0blt5wQ/sy2PDFyGYNw+u7n7ryvK
ChlkDiH4EUzjykTOjkOeTA6sT9X48OrVq/39/fv7e8gXObIy01jW8K7jxDNF
QgSmu7s7vzqPv45x7vZpOJFWhCpxzNNiQc4kFATjFgGHxrwskcGKNMiAS6YZ
8IietNZH3AePDzutd2vS4ZWJWPKTs016xGqORODiYicZPG7v7OzMzMx0f/UQ
TI2m5t6RITaWMAyRnHKw8XUGWX1ICmwJL5ZkXLE1v489H4Gzs7P+v+0HTmZV
3xwV9BSBuQIcjOnFjaRPaaQ9HfH+972cx4S9vT3wl1AIMoFTiXHK4kqsF5fZ
ODt0ZAgKJ6BSH1Nce2L08PBwVP1yc3l5+fDwkPH7rFhc0n92h9PHU5GBpgQu
E5GfTEvEM9XG4fj4eLmin/s72KgkfIJTSU4uySlQIaMQsjKQoUy6cQUG19HK
VG32VBx+i/Hhw4e5ubn16vfd6E+0xMgQO8taFS4ydJdBpo5GBtoz1VObT05O
1tfXFxcXfZMAfulQMrBBCWDAN4+ALgf9qkEG4s+OFkYIc2EZKCBhfpZtLMwJ
usIDwln1/IdXr155oDg7O6MsFiRX0giahz6YVGSLDEm2SfK+vbi48L6ddW5z
c3PCt4AYTfzYUsyXXYbYKNByW2QIimod6fIETwXZYnIA22yQgXCvGBm6f9Z3
16ysrCwtLfm6dnt7G5UuS1L6M2Fo7CBhhnmG4P6t2Lz3PMz6DmFtbe3r16/g
k8CTE9Ijg2wlQWTgGtNiRkiJDIYEBmlWMi8HtCgf1YeHhx4f/F7Yb4ofL0Qo
dctSmBvlzYOsRI6FOBdtq+99jp3z6Opd59y+368lhsNkhYJijGethqZ00AzD
uQcyGT4FtJvrjWVP60h9L8T8/LwP9f39fd8Y29xRSagET8kEBjkbMZeoixEh
I+cuLy8PDg58e+B99XwZASnxemKh4Fiav4JuhCUfNGA8JGR40pIXHGLSzJUG
AyMYNs/k0cDH/oFz69W1iPX1dd9IPD5eTGCNZgI54LjrDkyF94n3wHHDJx45
m49cS3YuQVgSz4CrrnkQ1yKzjctAH8z03YSGZF4F5w4ig5KIPiG5gjWTz4jz
83NfH30X8arKC48S0Vt5BVWEVcHxwAKJHPuIBtVmweOA7w0e0cAjpnPBawix
VI3Nj5goMqEkMuCiWAOV8SlYQDEyJGGTe6rLwPJGCgADYomDYITIjMGpHvKI
Es4dVNtqXzc3NzfbKCEW3fpHMyMHQb0d8t3STYV+fnaPu6rq2oHHxuQVxVjA
BFeZtoUAcz0K0jYkrQ2ayjKJVtEVmOMKJHIK8UCmeOS6iBAiS0cJ/9On+/t7
ny+7u7s+d3wvseac/+wT6rzKrLQmbvLIKBUBHutub2/Pzs685R8+fPBdwevq
J05+p/D9+/dnNEja1VoF22Rpyk9iCG4krQJcEENk6Brw9E+IDEoSL6gmEgiB
iCgr3O6OQvK4e+6+6rFPTk4+fvy4UT1PxncUi4uLm1WD8TnYgXPRlpsSoRl6
NLu8vPQ48NG5zeqO0NrOjY0Nb/nnzz8tJYTFLEKWAJmcbJagwbh8LjIoiQA9
DTIY1hmxKEFuEkK4cpJhgOe7OERb5Gux32WcV5v0D9XVidevX9db9bq1+Pbt
m09SX6/Bu4Xbk4zPzav2Mm+du6p2Ab+agdev//a3v/kPW1tbx9UtoF57/c1L
q0gRDun+mTQ59idxUDOkyaNhA5EwuA7caIlJEyMDmEomK5gcKM5oPXGRH48Z
W/IJe3V15UvzwcGBT8/6UVQ+W/2CzszM+Nq9urrqy7ff4Ptc9niy69zHiv7h
3PM/P7Y+6BGmZvPV349aWVnxErwc3wZ4mf7PGgT8vsC5L74ZIC4UEIEUi/9k
7IFJR4dQDmQIBkN3OiAyBDXGxtJBGANe5hXIKU1pSv8qBCKDOcmahDFQOHAV
dM0qT/pOzHBUDqGskqrWNhQajvGDivYpTWlKU5rSlKY0pSlNaUpTmtKUpjSl
KU1pSlOa0pSmNCWa/j9d+thO
     "], {{0, 0}, {350, 350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT1MJMmybj09aSwYnEVYLfQMNMZR3zHuAR1jhTVqa4XxdJbrXB7SlRAW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     "], {{0, 0}, {350, 
     350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT9MHMvSbz89iQhMchARQi9AJ7jiOvg+0AuONrKILIJP17zk+Vn6JESE
HCFHoBscEVlEiMh2ZOQI3WhDQggJCQk3JdxwXzNjltnp7ur62zM+d0s+R+xM
dVV1ddWvqmdnZ/7Xf3/8r//+n865//c/6v+e/p7MaU5zmtOc5jSnOc1pTnOa
05zmNKc5zWlOc5rTnOY0pzl1TW5Oc5rTvxPhkcEUeX5p8r4p6R6SusfHx7u7
u+/fv3/69Glvb29nZ2dzc3NtbW2hot9++81/HAwGuxV5hg8VfazonxX5gfXH
g4MDf8rz1Mx+1MbGhpfgY2NxcdHL3Nra8vI9z+np6ZcvX7xer93SE78GhetV
OGAYVB4Zmj6J+qf/TguJarNwjqnh4/H44eHh+vr67OzMZ7HPXJ+2Pmd97vt0
9tl6eXk5HA7vnHtwzjPraK3II8BoNLq5ufHaLy4uPJh4fPB6l5eXV1ZWnBs4
9/Hz589e+/39vYZCKZUMMyNkAITI5fcfGeqPBfJuqqhAwEy1kNS1mH0m+jSc
NgO+fC8tLfnC7QHB1/fz83N/1vPkBfHUo896G5y7du7MW+U7irpd8aDhuw7f
kPjWwuNJtLUwWgvFhVa3UBIPbDkJCWrIwDYGE3EMZKA2JCWRAWNPgvnRl13f
D/jMqvNr2gz4WkxuAxSJMhNvp99oXF1dTVsL5145t3F0dOQPUjcg1IVjwHKK
s1tkMKX+IEN2rErnkO1Yekg+j3z190lU9eQLviXwUOCPkAVZb954zq04/ebG
ubuTkxPfVNSId3x87NzQH0eqZcxDjgxa/J1QriL34gokCRm03G69fBL5NRp4
BPA44NHAY4Kvp74nH0uE9hgZmsxqSFicmhgFz75Yd0rtnxtZZo4MeCfosvHG
GiUKRn4TDVZWVra3tz0a+CN+B/EyJBzfSX3SLaLps94n9aaj3j05t+vcqd+J
EM3lm8YQhS9z3SIDwD8pjgzcAFEjBjLo2hzlv7+/99vttbW19fV18l5b12tG
6KxhpEcJ566ce0KJ1dXVw8ND5+7lOwgV/7H3Mp1sOnDYJUIGrQAxrdTCYFBB
hhZb/fHh4cF3CD7ONzaeLr75j1ib5BYI2aikJfZZjsfSk5MT59ad2/A+rL6G
TbKHntcldo7PkQEh3AQZUq1U+TLb5Klq30W1iV5x7vDm5iY/Bo5vgJNkpR2Z
BYqHiL29PeeWndu5vLysrmS22csgQ0kyraTPx/V3E3izrV1aZsmQWjwgDIdD
H8YrKyu7u7thGLfFIZGhFf3dIoAWEWfhfev9WUHEgnMf/N92ptUEA7D1ClCL
EYYtCLHeIUN/gEWL6ssIfmu8vb399evXl2sI1PkL/WVKdn0YJSCeurGLi+kG
rXW/ZZFSS9NihyTUVjmoMOZXIEPt8Cl8+5d1abc9gy9k9WWEtbW1MEpnRgLx
0f9+YGq8kW2sUlFfiFhfX/cQ4dyZc48kSSrm4KWRBLL5SfnSQ2TAD5GoY1OY
BzFwfnDuyO8a9vf341/ER+EPaAl0QZBaTqjSogwdYdrNzY1zT7uMw8PD+L3i
RMInmhEJkQRZee2QIRt9+N5AhbTkNzM1FOhLlUcD5xad23+g4iAMjgxkyKJt
mSin2m9gTL2hW1hY8KvT/A4oBfIYE3QBrxjO/HLIIJFsNwovsL5IvrS05GvT
z9jrtFa+GIBhCNMjCn92Tmz9YeM0vy4eGfwaTfGBgQwqGAZkByxT7h7k8M7v
jmZMkzSEVEt5VGOCr0dHR0ftfrVkYwToyjYPzY9IZJAvQ/S4KZxWkh8fH09O
Tvxez3cRyHtISPPG9xuM4Qz38GLQGhmyiYmESoYWpAFUgU26u7vzmLC2tnZ6
eoq6a1Ex5oGqE34kIQPbgD4zB3A3Ho/Pzs5WV1f9Ck4vDqv4SYgMeB7S1KkC
yyADxrFGyMAbmxV4c3Oz69yGc+fn54TfPpsiA8zJq/VUvdRglROyiCY84Nfu
4uJifX19Z2en+mknTRh7Hip9RSu55EjSOTLwyGgVqLF8fX29tbW1sbGRuFGJ
aIpijiCVUqFQXi/DIEDWZoBa+SDDvRofqnutN2t8QNpVYPWiFJ0xaaEQKjq+
zoAnfPCSzlK039ePTvr+/TtbhIlxPEImFJzseEXCMpniROYDQrLHh2/fvvn+
4f37963rD5jyTbJai9hJgZCsgAzwyosRHWMbrY8imVExP9WUxcXFw8PDp70D
bxodgkDUAEkhNM0HkmFI4Wg23wceHR0tLCycnZ0hbJ0jQ6+RIUsyZLj2feab
N29e6kiqYKkbymAAODFh1FxIrSaH2i1kI0mCabABzxLu7+93dnZ8f1g9H4Mf
PFmFvaU+PO0Np12tK8iC/PSshwLfWD5dUkj9Qkc9TVSQAUZqWGyYoXh4wVso
HGWHDLNUX5x0bt+5EcjI0V++qhCl0ZChq/RXR4acqKftQ317M/arB6RrCpSK
FDIo4pgwPXpeLxvkV99vIZeXl308ZJklDZ2ceoUMutkgLKdsamZS9e9u07k/
nKM9SqUr6/GkaIMwB4rBI/VUkv1+MBhsb2/f3t7SBUTUWncXGhaKdhPRJhTW
iDQsPC6MJqCENuQ/Ovd/nVv90pNWj21GmQamz+0BgEjEburpTMVQfbO5Wm0u
HqPsWTTioYEFMkQzVxEZUpbo5oFKcMHhUH+jvbGx4bcPP+9m/LWqPH4BhDFn
JEpFAlsFOpEqTNhfXV2NXnrC9yn4zGWcxVC2phvdz0C1vNss9LuGp17R7yJa
cV6g7PIIU/VMcdZCrESC3SrEJN/c3GxtbfmY4b00JyEVrx+CZDw65VToIwO1
cZpoLywJn4fDoW8Vjo+PaRWQtMbqBQAzQ8Yy/LrEWAWkf9I89c8ufPywTcCw
Tc2UdyNZZJjVa4sM5Qtv6MaUcL+D8ICwvr6efMsJUIiJ+MtHBjwIYCQzzCNR
mapAwvCUIglyPg+8vb2tvtY8RiYvOx3wM5ZknBwZ2KthNAQYnpJW7yBm7l9K
ySLFoXqZxpcEjAR1ZGi6KFveouqKIQNGJkbaLJvfUDi349w28MAoXbDEWyoZ
LkcG61SwkPZzB8GLZIniTihcLcUZ4QEhOkSF4BJLsgePDO0DMzsLthX4gUJk
QLBJdxO8Re4qb2Z2EKmQUAnd/iBDk0hTkxd3pCXq9Y+Xk9yCV/PWO4vDw0OS
FVHlMCfyOFVOwEZGBuE6lBzSImgHkUIGOTRb9CRRKGPYpsImIYaTJRPXlRzw
+J3Fzs7O9vZ2aouayh0MvKUCCrBU4h4JMuBjn2KPyTQnze8gtAxiSIhK6xAZ
GO6OxmUBDMkaRhqusqYJOWdnZ8vLy62dRXMc0ihJkyBfFsluwqLuR2NWuJL1
re8zOwiMfRYghdcul4YczkOGlpeEq6ULv/DZbMLgEy9NNzc3rZ0FWxWVk8cf
kyC9zkBUx3GFBDzbOwhYLl6rRYlUX/5ofWersxMbHUKSowL4DL1pyu4sUqrk
zlChX+iZTiFl3XV3d+d3EKenp+TxFg2DBZHKn4rlMJyqi+2Pq5E0a3N9N5SP
Q66AlyOFa1FPkMEiuPxGb2VlJbrdK2RQATKtgLzqxdNoVCmnSZXFT+H+Is38
48eP5eXlKThotVQqBMA8CRmsLRRiY3OsB4TFxcXkzY1IKfKBnSOMJJFTpxTz
iGcYzBDuHeClCXmyvRZxjj4OfZG6urrCyO6WukKG5gqkFkRelHwLt76+HnnD
LN5ErYEWjaCuQAwydBLNKsiAH94qTtro53sG3zl8+/ZNLElE+JVEIkMlQe0K
ZAoZmjwYIdGwrW9koj10xZSMkIEkk9fPpFzMI0YiS/RixgLBZ5CxvlT5yGxd
9dKdPRVNgbpMRYb+ND/hGo7H46Ojo7/97W+RR7naqS8wSi6Hhwy6hEEGxeaE
hwzGNBqNnHvt3D7GBAtkyI6lIsOUU+hLu6XwsPD27ds3b97M/GTeogRguk14
bA+pc8MkXqVqwZyiVl+CCY/O/e93796lxBRwQ6gudpyGDEZmiMWOnfOo8Cb5
NFekYnmhUVRkTUCx7tYYRYH4zUJQMo2QYZKqYqDhVMJL6BYZTOPO7x2c+925
2fvNtGq6St/OZlPXmx2imBHyRlmlOWacKkLv379//fo19alQSJKHQ3lk0O7r
H9bX1yO/hmCroXaVEtISrtiAWiADG2/NWkyF5lCDjo6Ofv/99/qymFBbFuap
C1v+TidSFOc69zvnNv78808FTeGoAommFZ8FKx2H5KVfLgevBT6Il4YbfnFx
Ud8kGU6UpF+ODC22Tu6BVEEGj7SZl89KErxMy6GY9ey63DcCHBhtQoDOBCMf
OIgcm7IZ7f9v3755cJh+odYcjY8dakuQZevJ3dFUGo1GfhPx+fPnpw+p2OCl
hrzAKTpKgqG6zQ9er5ZAQDIeGVpnhQ5BIgPMHCPfOfhtRX3NAQl1JERkTPpX
RIbxeOzd+HJtIbXoXSGDIsnnRUo0oPEgJQWGARP3qURmAKYiTlKrL47z6Oio
dUESn/K/NDJopamHhcFg0P7lu3VlxJCdDULEyyYFDxmiVuFxTFIReR4gMTSP
qFQcWHUl8P3793/88Qd1HLwsArv4yMCrXSRqjaq/CPZkokxIcqVGZrPLenYI
BhlS/HJ7SGyKyIA3hj7w3bt3Hh8yQ2KyYShlUOFnOglpf38fdTuTehBakDrc
86ozTy+mAwkPShaF7S6qqSTS7W2q2uf3FD7O2YZoUT+vM0SneVy9nxq6M4QR
A3aFHpmPiivaIcoBpAV3cE/CUxRtDEhyDHzuI9yDQ/JxQ5Y06w+rngGJ8ciD
Tz+sdu6BvQqKdTPVxvEE8kILaYO6RqpS3VaBgQz4GOUhgw3VX72FP9muyc7A
zpEhuiAADYfDpy98TZeMFOfWkUPFMVNkSBVrqseQzEh7kFRmvUKNE66fn+n+
/n55ebl+2AvIaEU9v9Np8vx0ppnHsMh8zjdF2B7gqRVd3ZYwFQMUZ6G4+kLJ
sBB24Xymu7u7lZUVxmPilObRx+sMU7q5ufHOaT+0rStkQMpXz4LynhcqRYQ9
f2plmmlrwunykT99hiQ+iksiQ6VL02kY4+v7n6MNlVRZ5xuTnqtQR4bwbAoZ
sqp/9bUj0o8fP5r3TofEg9jsKCEysB2ZHTgej7e3t8/Pz6WaUrqn0lJ/K5Ld
dqMM6S4zHJSmoGQ93IbOzs58LqTOSjovOTKkOO0cub+/P3NHkzoyhB9DZ2lt
7XoZb3Hi1XGSNFigdWrDEyzcXqLJuZ32E0j0VbRiv8R1Bmq4+R2E30cYPdQi
aQcvKsLGuB+xxKTOjQ892fIw0kISKNkhlZLA6hlx684NqUCbOpstgz1EBr+l
WllZubm5wQ4QEj79kae6avVTltjZk22xogz4rgyJDLp9DjBWBUBIhjWYb29v
nVv2EMGwC4MMAUO/vpuofzD1cnlh1oJyGYcMYDxY2yVpKmXCnMLYyVOdkhNN
ajwy8MxAnmIIBECpSNk6PT11bpukR7C2JsiQCsmsnYeHh2/evMErQgllDAlX
nFGYyiADrB2jDj8LiSUMttCBVHusHa6LuoiFqC44nDCEIb3bOGtyBTLMg2j1
aNFwOFxfX48/Fh60TIQMyLxgIEPnhJ9mVoik0JOQIWWzYnXWbSRIp2C4RoSi
z47l5WXM21r7iQxZ1eHA0Wi0trYmvakpS7CDLDTyiNRgGOFnODZMXi3zssLZ
CRUykOxRMaDFKYO429tbDw7AE+lJRqW8rrWbEOZTfXnh7OyMNozhZFIUsdNT
q64hUb4YmjFggSqccRa5plT8TCFDtrggSeBJv6FwLnKHA0NkD5GhOeT4+Jh8
eWFCRwZesSuMDMgUsO4TTGWaToTRdSDHNoON2iQg6xFu9as/d05OUBcckDYG
B3WQgaq3eXzm8oJKDDD4E94pVItDpciqhKmzpiWeqiIcUgwZJBTtH/CWKyLD
M4PPl1evXmEuOGR1Js6ifFgJUUaGmtqXFzqJAXkGsYdHcwSfPviQY9gJoyUG
GVIToU6nE4ieJFYnepYnkzGwMfz29nZ1dZV3Q2A25Lv6RVVN4/F4x7ljTOHL
GUfgZ6iwUBoO1JKJVMdjJpV7DDKoAKA6AZarSIaPIAdW2/DBYMC2Qo4MJE48
ffv2bQthoggZWjWOrUXIzyCgvPbQWlhvtq+wNkBlYBa4eDku88DW1lbq6U8k
K4KzBGTQRXTfBTUfTCEl5KrBbJ2kT4owyIDMOHjusAESStlZzNWwo7LxoKJF
zg9Sa0+h5WkJMgjn9/79+/ZrIyQkaMkip/qDEqRWJzWFJjLgp6aIDMDfWXUq
gBbVHnpDNWfzFvK0BKP2K4rKZlc8KjJEDWQYILl4UoJ+FWRAMluDXlZmKz4s
kAGfbgCnirftBiaG1zdG+pyKcpVEBnY5qhnG4/Hm5qbCw5p4VCbr+4MtBSib
YtbewAcfSSCPp4ulv7i4AJ7uMiX8QvGuQJKaxNAMPwv8W7r0KUQx9nyiknlj
S5KibbzskOSdukCggeG1H9RqjTceZBsMBj6zqKp0kYGkukWj0WhlZeXlWdDA
uqAt43VLtsgg4dHSlR0rN1jufGsetjFAMoYOlIQxBrIQyHB3d5f6PQXehA6R
YXd39+joKDOgADLAchTRXjIEYE5hvboxig1GSjhbBXu4cFJlhlN7j8nEZxby
tZihHgkyyGPk+vp6bW2NBmsqKUBVhAy5kEE3ZvDSFHPcFAqiuowSDY+rhYmq
Hemi6pFwq6ur7R8sp3UC7mcgA29ak+qOx99///3nhUd2zLfQrUBFEw6RNAm6
s8OjB7FU9ZR+dfubhF67Hz9++CwDBIQFMCGMvJugIvT0+KlzbzA2kRgKrH6H
nafi7BgNAzKGSPILUH8sUSTKpAaDAfDCXHQgqF1ngDU+PffVuXuAA1Muy2fK
RJAg+BotMS9LDAhNdT7A1MqgNIZ6YoYW0V19f3+/srIyGo1kamnIwPb6zg74
c3JkXJVBBiAFspsFCTJQxyKJISoLy9FZ82wWOvAvTyxXHx0d7e7uytTqI0PI
MxwONzY2xuMxdoywwFFJEpwFUhgJYkj5KggsWS+8qD4jg65t+CXGAYXPtfX1
9eilSLRF5CuQoXUBZ/us3/jQ7njsBBmyhdKIJOBjhAxIUYrUKxAoD57ZJYar
Ruzs5eUl7wfaz4LVkCFloweuzc1NhmWlQ0UdGZA9QIdJ0Z98tLCELVMXPFUA
OSUEFOvbhukbnai9mPoVyHAGHri+fPmC1NL2J5IZT0a5QEKVrvIx9C27kKmY
kdKipbcn/keqw6AH0VcXFxfV+ynajJ0gQ+vv+tamrOj2SCTG9hwZig2nakEC
wq+ODCnVuvJ1cQyuL3RfObfqHPQIlDR8kpGBhMQ7OzvxV9FFR7b+kDcP6mFg
RPg5AsHDnmYqVa1dZ40AwHHGHLMxxpiLvPzlJJydncFfUqggA9UHd3d3kXuh
gfFZzEwNESIDO0RJKCmkYsiQPZ46S7LBDrQxkhWRAXNWdxSFxuPx8vJy6slp
YC5yrkBG5YenPFj9+eefBGtwdsQLHEMyEB5IUTxE+iXamBRlnQYsUFRO9iDb
QvaQ8gvEDl3EqZOTk729vSxv4APOdYaoI1uS7upXeqd+PMXGasWM0xJFDfKu
6kuZvMMEBzCwE8xURwbFUKTyB6fqJz49PDyQRKogQ5Q+VG/YwtoBKpbmkXW8
tcqokS6gWKcOts7CEuyI14AJjZR3DpIhdh0Ri46Ojg4ODkhDJN9NABP1AMV+
iARgASGwSyJDSykywtlWsZFBrppqVXmB+CAJGVLArttbdoEPo9HI5yPplxRG
yLC/vz/zeBYSZVNJ7l7T1eEhQ3cFRYfUGxJ5rwgchEEgyqxFduAAItih/3d4
iNds8Saap59VrqzwG4YmtKoX3OjwPmSlog3dTkcr8gsgg6JeEpEaWkoyA5Ma
Oeezsnq4C1KYPjL4bmHmRRKSJZYvE0YCRlEf0CM0I/qx88ae0ZZr2dNtx6Ki
iNRzou2sGA/hi3+z/MrIUL95amZHUzinUo6FgbrnyBCdRfZjOJA3BcZAXWQo
3+PBKkwNQC4xBxke6i8MU7Jn+ZWR4fT0FPvmKSP3whib4kmlnopq+RB2lQSQ
wcL/cjeaNhtCM7JnTV2qoeLDhw9nZ2cYYVpXIKd/b25utt6VA0hUcyOy4uPZ
eBaykaEwHMEDJdlthAzlibco+BgjCdSj6+trzAtrJhrI0AwEjwkbGxsUS5Uo
G5BUZJCEt2LngLQEaIEYelNK5SDGs0eRX90YvOd5QQUWdd4Sr62tYV4zLdxN
BAX2gP9lJSwdyakSKkIhFr0QCRnw4EYqcAxkkGd6NjUAkyxwo+VYdoiyKw41
1AM2n6HOfURgns51hkr/eKX6cgQpEKOSv7Km1aTnFKaz0XASsPDIAhmATgk/
oxRmItsMOTJwaTQaVT/NzmrT6RmqP4YD04JCor8GMigFg1WhL+PkVt7JHSJB
BoyFKvaomJSg7e3t7CMiee/Cjurf29v7+vUrUlp7MG+IRWRmi1QBRS0elUTA
l34tGNFyVwoZ1MGhDIXGR/uQCW71w7OIURcXFx8+fMiZyUSGluan2xjw91dR
CXYdPIStS1FmAWmAzObBaMxILCG5C6kIrqHNvy3MtibA8uzyYYYgpla/dbr1
LPcgt5i7iZacp0fH2Hlb3l10ZUZhydk4gZEBAF65hfjyh0wcC/AvQCo9T1NU
+DeCdnZ2fOeQEjbRuwI5GAyGwyHeMB0qXDUUV9MoyHlluiQyhEeiKkjq8M5M
ZWVJrEAiAwZFBQt0dXXlwQFQqIIM9U+oWtwlXE0NicmsSzGFSZFaquHwQBqp
hTAkkqTtJLYWPBUpOZgwYKgLNZoSJjxk1PpdtgUynJ6etm9j6ASWScjAEKJo
nhYymJKKdrtIEKIBwyQMpCsSaVIYb8wePzg4aN4pHfBKkWE8HkfuiA59WNKl
JOrEJLZSubXULBDKzPYMihQVWEaLCrNEIIAMCYfDr4iSI4OXH7kjOoWufzFk
QAa54qwLI4OuzBZz+ZwVamQMLznHlGPTQ9bW1py7TSCNDBmcO3Au/pLrTjAh
VemMtDOQgWoJrjMsp5fKbwFE8FhSAyNRZE3sJYArcuPv6k7pAwtkGDv3dEd0
9PlyrZ7hl0CGApEjz7hoM5Ydm5KjYm3LHsa6S+LErgbhAV8ujcSfFYVDBuBO
aSEy3N7eZt5mWxhmSRRGIzLjsgLDg8XClSqHFGBZtuZkeUZ2VdajlsNwSs1c
RZDUCye/oYjeKS1Ehsi3EsEwzTDWpegSqCtSRwaGzBSn0WRNBbKzFaMo61Vq
drMtURQO8h8cHPgsjg0iIEPIOxgMrq6uIDPUq5KQ+tzDTOjde7Yw4TGkn55R
QQbS1PrphyZRcR6ckXNXzg1ix/nIMB6PFxcXCa+tjLIVXgiGulSuWZDce2Ga
CPsKNnUCRwAyIIuUPEIKDIxKoBbln1wjn9jT31A0Iou/mxgOh5mLDE1lLZ+z
ZpEUrkjZImWKDEhC4qpu4FFHqSODcDrIlVWRjOQxXSB0bPjOf3qpQQUZTk5O
Xi4yAMEQRQbMLBRDq8PSaaS0TN+SzSa8bfI0hA1jUMm11oU13rok+A8PDz99
+hRo4CODbxhermriy0TCPPJZEnVb5bPaGcClVe+yxoT5mF2yKIOuwX3AUqM2
AKNLEbGrmxV92yBHhlrC4+PjwsKC9M2V6hWfyowcxQA9kknyloZ6HK+LVKmF
jhJSsUIDCOy2BsHUWtDnP+pcDh7XwESG8FecSUuQBmvJUYHT6Ed8gqgTWzvA
rIhXJSm1vtbo3RWpd4MBMlR/+p7hepaXuZs4ODiI3xQdWoI3WEiYuqkCVtnW
DikHPwQ/BbwzC1dYLfkAMnRiT1amMDaKQJZzp859mj3CRAbojTNa6aBFYVoV
6yoZ9V1onqKEfiKDihatvgujJQXpPA+EFV/Dk/Wlhlk9BGSY8o5GI78xAVh7
15iptw1ZZiE8YoYb+Znhq95SKhmtkSGqSKVi2iBDJWbBuXHjIwcZrq6udnd3
5caYEFDB5XJUmFUE8so6FcFUAEriHElWalkSzW74IF6RxP8qUfcspHWpgbeb
ODg4OD8/l5pkRFog0C0yGGmM1lBht8NGBsxxXWSQU2FksBs7aax+9e/09PTT
p0+Nkxxk2NzcxLwaj2CeHbGr3l8SGTBCymQWoKi8M6NUJmcZYKJFs8hw7ZuG
xqUGBjLUD6tXNi/1ETlKhVNroAr1JDuaZIdFvSJ8qjJCdzYZaeosaFZ7864G
BjLAj48TUbS5BTjtSC5fXnH6kEGkxr6kMXYSeEUHXrJW+iPXl8opYajo73//
+83NzfMIMjKcn59nX33FpM5jb0pyJKcuKCMHqbbx+C1WhBftcpiyGwXz4HOc
NyrKE3UXKHNvb+/y8vJ5BBkZPn78GH3UQ3Z8fIJasRft0FQE2oEVMtRT86Jm
CmkupnNnTDYrQddavG+zWTmJxVIBZAMMS8hpXoRkIMPu7m77aS1yO+VkhAyp
j+rDqckiNC9LppBooVe39OBHYZABLx+WRopwejr4hmF6NwIDGdbW1u5107n5
t7BMZPOL3QlYIwNVaVeZy6AypmZzrT8eoy4rr0GiR/vd3d30EiIVGcbj8dMF
TIuIzU5EHRl6EicA6RppN2UMpCOrIUYgLJ/XPJSMCokWUjdCnJTP7sYPJ2nI
cH9/73sGrGE8KpMOPBy2o3BBSSbhi4gF8bRH05mRoVFUoU5WrrcMZeMWZsgN
99n98PAwoSOD8n3RWr2HihxSPurm7CS3fFparJlJEoAuIlvc2UpTnPDq4w9a
k7Ci5Ybv7OzUL7WnIgP0GHk2UEePdIjekgpobZsKYepjdCF4cym/OgyBYdMS
PatOpIqfHU46G6OPHz/Wr8GlIgP0iwlesKV4qCRcOyD+kbFhXejlFI15gK0n
VTJK2ViSVBbYS6ZAZ4oMiEj22e1zfEJHhu3t7eldUjQjJzhkwMixGJUFK4uW
QF6OGeqQyMAzCYkn8tKQMlJivK6FckUpZmH1BJdj+qAGKjKsrKzE32KpSCrV
mRpgbNKKE3VkyIaQip8xQ1KVS0tpOFxeWZAQlzprFMPN1GZ0Cwjmh4eH+isG
EjJEfkvVtLBA1Wsqhc8WM0aR5LkclZbNQbh5MIIsOwKSQohInSPDBLFq0bEU
n9e/qyIhg99H+N1ExAAJMqiXD8VR+OVjh2LIzEYG6hRIMVYAaY1UkBJ2glgF
pEa8nJ5Vsa2tLZ/pJGT48uXLz99SwUHFKG3IU3Y+jK5jSWSQT40hAR/AeOHs
iRRTgURCNlHXNMumGCQI7fXvqkjI8OnTp8+fP+dNtc5fki7S6hTOzVZxiY41
hUct77X48VDPI1NkkBO+HFAFWoRocKT+XRUJGTyYfP/+XWSYFuF9pRsJmHJD
lQZjAhIZkI0K3iqeKF3/KBIyJXntE7Xb6dwPIPmGwW8NSMjQfDNmx0RC0QKZ
QlLRYqbKtEMGUtzqsmFIIsoCGYA/kBJ6ScPhcGdnh4QMGxsb9/f3plYB6vMZ
EX7ES2YzMKqARWCoyGRjUVamSqHMNleFKds84P2Jd5E6+ASwdnd3t7W1RUKG
l5sZqCApJ12/CYdoDVfpQORmsIUzwMGCTGHHQma/keHh4cH3ACRk+Pn2meYU
5CUbobiDotBUp5W/2RLTPGjagcgtZ6smUYFFx9e4rBOQ64vRhSHeIiIsrJ+0
QEKGpaWljEls9wJnC2NCqDQFTVr5xWPj8WNgtkDcNs2QhJOc8NoZyMBQiidq
xaTEMBUZMk9mwJvHO8sborVenQCUOmFm0QkyKLpXq+Oy7txIlEpqmzqysrJC
Qob2DZC6FJ2pPPEtkFwrDMqjDdW9wNjWQWFn1UNkUOeRENyxAEvDWvHNzU0S
Muzs7KCsxVNTghwZ1Fcn20CSTqWY7SIqm6f9QQYGsylJ4gr2AyOokBpTZqRW
PI0qg8GAhAztpznJiyzPG6nZCcNSxTzqTJHQJ3cUj0E+RAKVWdihmoEXIgE0
EjJQDUMag8mItF6f6SRkSL6AxiICSdIscBipGmkb2xLdsJGTKTJMZtMKgwyk
TFdPQ5INUc7QHpVyJpumFTIYVaLC+INUkZq7URCSbLMYkh0oL8qh0/DqsjWi
/Lq0bMiCG8+wEE6znGna29vTQQa6as4QC2SAMz2LA4DS8rGHrDuM8oSftUQm
cFZSlFMMcCpZrB0+ebMSSKfonNTfTXz8+JFmQ/8pFfOpFaT6X6UcYBRhDrZO
yQtxSbKzIQqVplO2wz2AnzJWDRlUKj7OCFGjNQkS1q5e8JBBve3h6YoaLySh
NEXXqVReRdJSGq5a8whlTX2mY5HBPdE///lPyCT4ON28pEA5cmazSW5qSjLV
VIZYraTGYw6GUzHphHjOraS9IyBoU2ypmjj7sSgywMaTCF5ZnnAGMiBVU+fb
Wju8b/Fn2SRBBry07FnT+FEh3qpRJUukgcjgM520m0giQ0pdATKtTXLVGBiH
xWIwKhzbk1LYQ3BjSGZYoogMqXjgGYAbwkcG0sQLR6miOrwojEOaa4pP9ihz
Vl2B4MdYQppmh6SLUaRlzY7ilRUZMlCf9pZHhuhZ08AwrZJ44Zj4ZyMDYJgW
pxEyCIXziOFYXQt1kYGkQu72ahThOkOFDD+/m8iJFfmZKqEnyMBmplpCJV1k
EASbiJOURL9El1ITu7Jjgo0XhzxkUA/4cAiMDKRehWGbSkQBU9BKcGoiI/sZ
RYFISs0LjgpeeHRLWvGA9JjEKvr9DAfybkfCCTBjOo1iyACIIlkoLAeTRNhI
5siOw2wuY+bOxjet6bMpG5xaKpSIigzYu6MnZshgKqRz4jUGQi2KzBI5QlTH
DMeUDyPC6FUt+kKiIsPe3h7Mwelz7FbKugGQ8BduYNhEbU66MgOPDFoaqYS0
UFcshiFG1N9atp/PANuAbGX7hgzRNcK0qSTV6sjQbeulFZ8F8rEnWBfqsugo
uAOpyNB+phPDjOxKdVgoGQ1nAWuR/gktpzqWXbYwJMxHrZIKu0iFYI2YIdGz
RkuTEEt9ptPW1hZPEYGETUWrUQmbFkBygX4mZRKgKMUZHYJBBl6fU8A5AGml
BtvteLEMZGAIDOXzJpI4S33fhOdHsjK9qiiNgQxZBkXck0vGDEmlM2MWPGQo
iR4YwttDmq96QQS06yJDgtbW1vhvogEM0EUGHlmIlcSVXJ0KehROVVbBIsNX
mDXdrj5DGr5Ihc6hjkUQ9X0Tnn88HueRASfONkQl8uVjJdio2Ff0nAojg50D
5aBNLTqMXGsNTMt5fHxcWlqivtfSjyKYlLU29TF7XFG1XCm7X4oO+eshwEQ8
KUY6MGxgq+h8BTEao0bGRj08PFB3E5ubm1bvws6WD0m6AQunsoh4gaYdaZ+p
ADJoQQe72ZNbUmAgopvyOb69vU1ChsFgcHNzo2Ynic2ojkvEUnUh1QlX+d+B
og5XB3lAJrtghZK16pQk6WZtuK7uT6De6XR1dWVrZIoNgXVWBoSWZA9KSBLq
/w5Y0XK4LjJMcKlKikZYi1afoNVWOfe9+h0ECRk+ffp0enrKV6pOwoVTbxh0
idE8/JWQwagcZAdqyVFkRkpQQYbJ5KQiEjJ8/fqV/5oqxVE80mrbALG6zEY2
9ISQYSzsKhUtURQY8ghXkOQBkK06+eHLly8kZLi+vh4MBkh+yJjOa5yFXnw7
J1ctEWJRrdSFUPslZIOhVb/gIwwt+OFRTr3yVJ3cvLu7IyHD4+Pjq1evOKp1
EZKqfaKXklm9KRVyMGzKl/izDDJQU1txOJA7Kg4ElKogDywqiyHi9V1eXvaZ
TkIG//+lpaX8LQ1a5YA3pCtkgEmOjchoUSSJWCEySIYwmgctBzaTOlwv5PKl
kCHEBANkGI1GKysrk+d8x1DNub29jfriEhSkGQkl8z2ryzQdWmOzWMd2Wqqw
4hmQxB5useiKxlCRAWlJU6CkRQGVDofD+ooBFRk+fPjw9etXpJYSpIv2yCNU
uNZ1iBEy4PMdDx0w/VWRQS4zJQdedwluPDOfn58fHBxM6Mhwenr66dMn7ETQ
9jAPpgSSamIqyLMrTnc7jSRxxRhrUIA6M4CqVFJ/mwOFU0hZku09WgORABIj
DwufP3+e0JHh6uoq82QnEpkiAyAnRAYGWUeyim1UIUaTwogVZiiPtJBBxfiU
KDiYJ8SUAY2c3s1IRYa7uzvsUxo6pyy0Rnkk8uWEl4lc918IGRQ5y7cfDI3w
EBIyqNhT0dra2sPDw4SODPUfT7/FBlnjqSdfL6H/Qw93VaFgBqQQekUQMVsI
lMyCkReK8+0kmKnCiSp8Xv98BgsLGaaokrEK/jv8mJIjTOSoBIsShmFWyWh2
RKWaKKFYnm1CfOMFRq+QoYBeopF+R7C5ufk8lIwMOzs7TzuRAphJBz011SlO
2KTpKTmCAUIUkUFFLI+E6gr0fvgV4QnkSdMF8Flp379/n15FJCND9Q67p99V
2aVtTHc3+BySHTKEo8rPWtK39GeNMISxVjLHKGfn6xuqnrXh+Pj45OTkmYWM
DOfTl1X1EBkwaStUoUikhgRgoxov70a6QgZ5tjb/4bXI7QQY1F3Hrdo+r8/P
z59lEJCh5uX/rgpPFg0znE19QAakGTAykCT8EnUfnh0e5QBMCFVY+6FXyPDM
vLm5Ob3DmYoM/t9oNEL9rkpCFsigpUJdiK52POKVRIapZIYKnlWs1OCrE5JW
1yfQ7tzYuZcHvTKQYVJ9PXF3d4dXyjwrH2W9yp3AC5xlEmQgESP1gFrGyE0G
2mC88ddDBlwb+fS7a7fZOEC8zlDRwcHBxcWFglX4VhB/lsepRex8MVKB0c7T
hT/VgoUocMHIkDqCyWUk5rCRoSTA2qlw7tS5o6OjxgEOMnz9+lXtUgO18OHB
xAJAsloMwJw2L1LBxYhixG0KGVKnJAKRzJiBeKKiTfQ4ry6YUesprzxkGI1G
q6urmTsh0XLzoWKHDNTVkeBPipkU51mNcO0jVUaLuJUIZE8NmcgMS+BTGGTQ
1c4ln8utt8nwkGFSXca8vr5WsAlZREghzdbOYLNGBsxYFX6SXqEZeOH4pM62
ChjVvJxN6TLKfcVceJ7sdfU2mdljTGQ4ODiYeY407FJ2QLacIFw1NhmgtI4N
SIdLABCT9UJkwA/HLwQJc/D28HSltAgF6iFD8yKDEBmGzg3CJUuFCsMP4Rrx
/BCO0pJDZVAhXswgox3GGS1PhmMV8x3PGRYdC12phbDGaiJtb2+3XiXDRoZR
9S3mz0sNISCQ1t0up4QrThqlMk07X8mzmFFMjezBy8ckEQkZhKlKnXUKjTEA
jjbVZ3H1itvHWUuZyOBpMBj8vNQAz7dMMY3q0lXNxmp8zS3pK1hjFNt5hb4l
0xRbwnzX9Secd4oqGJGGR4bZHBlWL6YMDvORwW9M8k9+UyRM1vcKGbJRVB4H
8DZkQYCRI2HcSqZPtapYMAiH2AFaFC2d+zR7J8PzYT4ylPgBxawFkXC1a1fk
q8OWUBIx5A7kRbJF/LeEZw8WRmY8lpIMw3gSSBbnNquXTAWH+cjgaWFhIXJX
g8XEJwkPdB5dFhqN6hEjGZE9mK7BckQlVecChHSjRDh3XUbOLcSe0iZEhpdL
DSl72PkVrnLhBoBneVddihYyaPVg2VgFq9gv0GuRKAuDeNDmVdU0XV1d7ezs
xIaKkKH9kHnFmm6BqwUMkJttUUxVtJNsQFax8rlMqkoFiIQMVBjJigpvTHo5
L0KG9qUGFZt7TtaxTUIGSRHnxZjKfDsMEnVkkLc9jEWUl+Bn/s3NzejvpoXI
MKnejzkajZgWRrOMGq5CFBWmRk+QgVHrW95uyTFFgNZ6FevokGN7iwxZIURR
Dw8P9VssY/KkyOC7kbOzM8z4vAOjsYqUzI603jY5pLoA5yBGUUlkSClFDsmG
h+Rsn0kR0ypOv48Iv698Ps9BhqZ+v6HY3t5GWoLUBfFj8sV66RkZypAcxj8D
8TBJB6ebHcxS1eFLRtZvPQEHraRgcFYMzce7BeelyDAhPeIJoYaMinZ5mpJW
BhmE0lp5lKrRIT9sEkYpm+DcZwu3QAa2rzBYLSeE5NvbW+B9c/LdxKS6GfLj
x49IOVk1CouISWEV2ySjypStqCuQqosBYOt4H1aNJxZjPGmOlkFycHBwfHyc
1qyADPWDXMIBmdVHK+YjA4lfvgSkOqJYAeWcIXPoE8ViVwYVU7qolZ2qSzHl
LaCyovpRLTPfHbQ1KyCDP7cd3mBJQgbJ3IEAJkmQhzq7w5RrieqShB9+jXi5
UBIcWhrZyFDY5ua6MCpd9I9nGg6H8E8btJDhYvp6GthU4Kw6MnRbmCzEZh0l
qXRsNh7+KHYgSGPkWjB5alEIeAOjf7yc3/v69SsoQwMZqg3F0tLSIyN41FsI
WLKW8AkutlVakb8GlWyrTEmCDMXMAxU5N3JupfVAhoBHBxkm1ZtwLxgT54UK
tU4xxiKFA8d5mN85Gij2byoyJTYU0yvsuxT1ZpGherabc7swoyIyXF1dmTxq
XlhlEg0VRxQsH68RKbAwRISARtLeGtUabofPsCV9QwZTvWh02n5ChmEuLdSQ
wdOrV6+Aq51MKlbieQbYdY8M9JNwZnMZIxkfpdaphG8X8T6xIEUVOFEPDw/V
ViK7PprIELlTukD71Dyeim2LDAXkm9Z9Sf2Fx2LkAFPrqm7ClJ2gFjLwakT2
OLvzSYw6PX16UDSip9NEhuvr6/X19bh5pKhj8NghA8YSLWTgeYAadVEeZASa
gp4KZYPeSB0PGQBmRWR4/ns8Hm9sbNze3qa0NQ4qIENT7Nra2ovecIL4uaDN
Ioc0noeN82zSiwGyNCQz7HCJB7QwB7/QKohhEdjqRe1ZiK/d4R3RUcerI8PR
0ZHfU0ROGFGfkYE9fUmOlCmRfUMGBqxlhyjifJlFQTB8+PABvCNaGRmaNBqN
FhYW9K9DRqkA8kioE2RQJHnuaEFllqjIgBmrtXx4OXhmqmMrhgfnfG42X14J
DFVHBk+HFaXMSx5n+ESxuOADpufEC63oqeyiZJ1pgQwkIYxGUUWjLjLAwQk7
uWHDfvX0eOSaWCCDbxha79XNGsFHSyoxkEFeO6wpjBNJOuCRgSFcTkDuhAb3
DYt4KESSmfhYP77JZyUae/SRYVK1DfHtjEXMSGRi0j97Co82RpQqE/gh0VPF
7JdTChkk0ixItz+h0MnJSbyTT6g1Qga/o1l2jtA2SChV7oEGTMsexWgEjGF0
U8jpw3J6ggx2C2dx1kKOWJfPRPg31zF5Jsjguf9P9ZQ5wpDngWqYTy2jbEta
qZQdRUUAFZTTimckwTAFqAtxKbWUEvhS6amEWuRyQicnBPqGYX9/H6XrRbYm
MjRNu7+/X11djbzBCi8CZiCFBCN+2EOoyCBR1IeaHiVFZIjyY4RLUq+Ab/Gh
knVFiq06Uj+kxbl75II889CQAWPmlHZ3d1GPlUZbkCkWpqtpVJvYkqkDqVpM
ewzFlQLCoHxxJ0mjxkZqpgB6VAd96/7u3bssbzCUgAwgMkWO397ectqGlNDs
lKJuVAkPpDdJMiWihMmIqbOKfiMNoVKBAmGEDNZmVOSzr3lbMgghrSNkZIid
SkbTYDC4uLhAqojIQiKDdeFACikW8MJYBYJDOAWMIiHJl4nB3DdCG++b9uhr
K7PyJNcZMGgd+Y0VwD0B4x9Idq1ooQ6xSwTduMVIayIDFVRJioSifjlk0G05
Qp50yviGwblV54J3UiPUypEhu4BbW1s/fvzIm4Jn4AUAPotV2gwGkfLXjkKI
aJ2yU9qVLlO96sgARPLsKd+uOzeAy29aKh8ZYLumfw+Hw99//x2pxYSicY7x
TgGC3Zc6wquM+IxIaekqW1s8KbRX0aU1R8ZiwcZgZt045RsGn3fNJ7qT3Gb0
rWVL9ebm5tXVFWqkBfUBGVKS4eP4vE7JbAqhIgOPGGORQ0JsLI/kALWsEsJ4
eIQo7fLysvVaSaItmsiQssHDgoevMQ7ruiHSOioGP4BXGCjD6NItglps8JDU
ETmeF2BmI1g2SND2+IZhfX3dt+tY4yM6Ccggia+dnZ1TdmxTiZEa/YwuvJwC
0GqngoQMEsPkRZxHJeO5OntycvL27VuJURbIENX48PCwtLTk/88XgacoegOS
8SFnjTl41Spa5KQb89aUjQQVyRbDw5BOc947t7i4mM01OOotdhMpjR7HMF+t
MqVHT0UTOfStOjJ0lachUS0huZchnzHcqMozQF5FL294Cxlax2fHPvXnjJ8s
zcqz+kVVjOR7n9qO5IKy3QvzMxadB1+KWcyzBOBv+YHkQCEZIUOLnwHy2VO6
MmFFz3R5ebm5uYm58RgukiWRYfJ84xP2fmmtgsKOTzYypFRHpZkig3w4EEBZ
5zBSQ0jqPuw5MsxS/WhoZPHN2VgUGSbVz6z8tgKpUid+FFMbOI4pwYrtB16U
YmvRAjEebMKjLBZLi1RgRzEGAjo6Onr//r2KRXa/wk5R/Sw47KVIDEVD10I4
fNwoLDtBBlipbh9FOiuRLCcV+RbIUDHc3d1lH8/SWjpgMXm/wob1Zun09FTt
DZgTY2TgmaEiR56DchsYZ5HCVeqv0ahfjpwbO7ezs+PcZ1IRAHs3TWTAknO/
O/evf/1LLGhGJgoK+08tZJgQ81Q+6zKVl4cMZn04WY6pl1KlPa3627dvzm1S
nRQuRSPoSl9nqGVdO7e6uhp5UCRFSDIjrDteOT9pCJz7iLDRNEwdiPCWWOhC
yqTCNUNFOCTVOgYCfR6tra1VWYVavVBwAWTAu+H9+/dHR0dI7ShNin2CKTII
gQtfv4C6w6YOkcFiuOJCpzxsP4vDw0P4wuMkhgNwRKg8uSU0AEOj0Wi5+XA6
KpkiA0adqSjFLMbEQW9JYnPJ+SIquxHd3d0tLy9n2286BCojA07UTznxX49T
pQBHFKnwosPqMC1jllN3Fi0I0hJYbJXVK3sRZBiPx4OBz6Ev2UU2RQaC3LiE
iJFbW1v5p8j2rdhl7TFKutaRlBZkT9sHZGAAF1I+Bjy7KPFYwi3i6enpH3/8
gfEi1W1G1xmQsTl5fqmW74gg7r6tWpbKGAyAA5tTTjBqRZntzIDPCsGHrR1g
hjN59uB19Sg3zVuDlJABsJ3kmOFwuL6+3t4oWUcyw9BekTABTSf+Szt2orSz
yOJS9CNa9Wg02nBuaOZk6yfEIunw8PAf//gHZySbdJEBL8dUYwEzMHU2dCwp
U351gktmigEYG9B4PN7Z2Zl+tWfhv/J3R6fo9evXmq+tQZIWupVHhgLCSeAj
yX12780jjATdtke7QfWZ8scff7TES0yLHS93BRKm5AWHFImBVzRWl02LCiBD
58TqvWf4MYgHJ3IoRwX6cOhxfX29tramdXmh/8jg6cePH5ELDikyQgYkIUun
iiVwJPekXSFR1nvI2VELMSZmSB0FG6NgsWny2QH8zlq1zTFEBoadh4eH7969
U9DB9pEQcCyyL1XOqD2qsKFV767DI630xBisNSMGMrB1Mdiq4+Px+O3btz5H
8KMFedAvZBg799q5yAUHao2m6sYM7LDmRqEgajOmyEoM0KLUwgE86lRyQTWQ
ob68UD/4iCGPNN3+IMNPZucenItccJA4FlN9wmrFmIMRZZuEAgari+UEh5l8
6tguoqL6wdTLg03wJmT7r0TS9AsZan7aBQe8aDy2dIIMqb4FtqcP2BUlxe6F
tIIM+dSx7MjmmudzwbkN515e54T3Lr4qzh5UQAZMY4hT8TKwfcGhfPwzorE5
kK2RKqErZMBEG4YBnzKJCO4mMPCnorWGYnb28gJsCMltDet6hAxN8t54uuDQ
Se0WauxtEW+R0E44vEkdWksgCR6NvJ2dGhum6E6bXl5QnGsZZDCiB+eWff8E
vxDTjtg9A1WFrhy8TLl22EXUNOEhgxHhGx5FI2PShsPh6upqfXkB9o22LQRk
KN/N1Q+9zN/+1FoppJVwQkWlydpCk+4qahVGuxZJkCHk70nHhUGGLJtERUUe
FhYXF8OnmGBiXOjIrpAB79rr6+tXr15lwIGBDOEQGAeaQ0IJSLIvMfras1Cj
WOX70ydIJqWEKre3t74s+vjnQS/e8ETG6OwmqHhFcvy3b998QwU/LptMLQsw
ad6TcjalFNxhOCcB0OG1hBKAtZQjp7Xb2fbzvIqbjt8+bGxsRLfSWkgcypmF
RjIyYPwXRV8JXVxcvHbuEekRo1iiBglPpsR4C2TISuMlAgaKMRLkBAc0YGf0
uIZVvgiur69//vwZby+DYNu1kAE4pQVxR9XtkU83OSCRoUAWk2QiS1KZEsnA
EOTHrDSMGRhC+hN/NsrZtDOctcFiPX0r9/r18fExb7geboh2EyrVA0/v379/
8+YNSugs/BGstCNdvamIFY4CsgCWGWUr72q7EGx5xgYZPCz4CCf9MiJlYJZy
eE9ABhJCMwIWM+rt27fvgaxnH+mEtAKVXf1VDMMvXlQ+Mpp7AjI8z+BO1Xc0
tWtf2lvCimeKDHi9wMEJIsynVN8BtS+sCz1pGySQleXk4adNKYQmrosM8KxJ
JHcC4MzYQd8qeFgI3xSfch7PQGTQlX92NAyimMk+Pj76jdjp6anQHj6xY4aU
zvBZYfFiIIMkU+RjkVapIIMuMOKkHR8f/+d//ifwW6FsgjCwMzzSgB1az4C3
Cg1NmSoapfri7bdv3wBzRcAKE0OmihmKBTElPCXWqJcIVcCqdfGKaomcOUFn
Z2c+nuHHNCGRQWhLeWSAl51Bd3d3r169+v79e8Yg02DGE953ZQxGAnfrLA/u
2SbZjVIksQH/+te/pvc/C5UrOkNxN4GJLPbwKNXv7frZOUjiysK4lAQ2huoS
FRnwciaBV8snb7HuIqsit7i+W/CwcH9/z1Ni52NTZBA2ZVEPtMi71LdhT9cc
dJFBPVvxyKBCnVTSlNMwxuANRsJ4ys+SiMyeClWAH4+Pj7ObiKh4JOxhMiit
y/AKpDA8kfMajUavX7/eR8Yh0qY+ZJZQDuw7IGIZGREq5dlM5QSmFrI1DwrB
CoMMoK7xeHx0dPS3v/0NgAV5DcGsavo45zqDYgmVUyXq6duKny8KV0EGLUIW
OCQzSWkoFkgWZNYA1vJSm3qWx5zCCoZkvPEtfzZGTe9bgJ9apphuGC3B8b8G
MuS8zdDHiw0qM7swMfRKymg0sxgFLDuwJHQD4JZ1Pml1GhOvHsDyxv8L71tA
moknoCYgxna2myDhPZJ82+Cbh8hvKxjFTgUZJMSIPapw/Ch8zYXN1vKe0AlR
Y0iVj4UMI+d8fDp3qB75sITs0oX+0PrWEjaMcZbKNuU+cu736gHU2NAVRqwk
iqg8ABvP14wEz/KoIycylEmq4UVXnEJDkY/J9fV1545JNmqxYYSYIoP6dKjI
4P9dOLe6ukp4ER5ZDXFgJ44TjlK0uckstyRb/xjEtio7qeezd85tbGz8+eef
GHZr23FilXcTwLohl1Rlpj9+/FheXqaBQ0q3keuRZIWhxUnYm7XkaLFFmfGo
iJvU0LmVxhNNQ/bpEd3Vlji75HWGkt3RpHqG3srKSuoNgHFlcmRQT0980JRE
BiMIFUrQaifgsUTJ9bMc4Tgs2dOh09AEGeyClCS5fsDszLvweGhFtc9i/qbI
QB0LxJw8tTFg2CGGAyV/9uN4PL648Fvbdb+ZIGk2xfg5MtT08PDw+vXrf/zj
Hz+/zdRt10hjkaAhjFjecK1irdU2MJCBAQtRfnTmJPuT6qOHBR91//Ef/1Ff
DidpKNn9pW2gXYFEMyuHJ7XUNxn8Gh0eHq6vr2MvO2jV/ajR2YBk6AWitAyp
tBwqNmTFZheXgQzBqdvqeuP+/n70poV+JH42gzpDBhLqS5Ch/vyjepHuGc8y
jEpYDtJiSbcgYbMLVi1naukyTsunHYRzS0/J8vIrYLxOrd6NxzkbsDq7CXbe
IOsnFQpCZPD/nnYWzr2rHzNLpQJrZl36iyFDhxMRMsuM8XH19u3bP/74o7WD
6CEyZIdTvosUIUO0iUMiA2ZUlCdkw+4sVMJJIsQ6nqk2lElGdvNjh2xZFc/H
r6+v/Q7CRxf+tmchwZMWowQTGRiRAjQJmOGYj8hY/vHjR/s7C1glj9jZhG+V
TA1DejO1HgzjrSFFIi2twkOBjyUfUYXfwZpdE0mjwt5NkPDKNM84la3q9l6/
fv3u3bvIzqJMSGMArjwyKE7EIgh4JikaEAipdxBv3rzhPZQpKj4so1TbSWMT
GnWuMwCGwbaxOdk8U76fO4vqzlWWFPSQklkvlFzYKiP0iIo1QIbpDkJiXXhK
jgxIdVGlzwdNkAFP7NDQCqIf1Z2rtjuLptN5641HHpLYzolnuaSCwsfR5afe
QXhY8OBAtQJpjsUy4jFSggxGAI/k1MrXSXU31NbW1vb2drwh1K01EmSQtFNI
84oRpoUgjVWxIZWcs6t279xgMAh3ECT8ZpjDExsyZzFqwkWGaPuRtYd3lseZ
4gfy8uLiYmVlpX13Sn/qLzAZnpG6OCvRjj8lUcHAosDDPjZ8hLx69erLly8h
o7oXjZABM1aCDHir5JHbPCJBEnjs4+Pj3t7e+vr65eUlUyXJGjx/ywY89Gfl
l8EESfhqyZEgQ0UeDeo7G8PeMuVLC+8yZGaHxCwXIQPDBrx5KVFsFciBt7e3
Hhx2dnZeAqAnyNA6RY1zFat4o7S6GklVYHA+n7q/v/fxAFxVSIF0FNGFZIoM
jT/41xmiSuXIIE98ed7Uv5Lzm4uTkxO1G1d0V5Q6Q12c1cUljG12WATGXP2Q
56WlpfPzc4w2uG1oqrJoJ2C9pFGKyNBcZDk+SAYKDZiS7xl2d3fXnRtS002L
FOtNuDDRpUJqkYzNyslKwyjSQAa/qfTd4/v37+vuURLbsaIMyZFHljhepMjQ
siRECQtSWSMkDasf2D9tLjD1IFSg5QUVOXDRovqUBCPUgUhkIAEIPMHGKb99
8EXBbx+aT1zRjTprZBCS7v0M2ZzQzRKeOoYNvqU8Pj5ecu4E0GeNDFRK6QXS
quVTO0yjFnQeAwsZ6hsVFhcXT09PhRtJie26RHLS83FNZEAI0UlVpHAMLOO1
+5ayvgz18zW72eKrTiTM4dVlC2SQEGbKeLeA8/U44FfWbx/evn1LulEBaTub
gao6G4+YRe78HsiJcQBmw4Sq3beXGxW1v9lEapVQqsRjdPUhzeVkgwz1BecN
5zadi75dneQ8TLNGEkUdqNKr9AEZAkWaIWzU0Xl8GAwGL/2DXCKeQsT/90EG
RaoxoXoHge8Ttre3r5RclEUGAN4wkCI0E92o/MWRQUiwMbe3t09fXqyv+4rz
sieVTwDT6GQPIkVZk6SgYxjgfJvEgLQijwlnzvk+Yefp+Us3UQG6K5mytNkY
YBb2L4kMvcp6DGHi+v7+fm9vb3l5OXLNijfhMCC06k3qFJx0sJ0wlUcGQKP7
uXfwK7W2tubc+/qHtinXyos1w0PhKZJStpHB3E2QARPXWbf3EEZSsTmpfmXj
8WFhYeHo6Gg0GkEDYHHRU6beScUfxngqHCGNkfCnJTw8PPjVqX8d4/Gcraqf
sTpdEB5al0cGZNxRva27OryxL1N7/stH24cPHxac268eO5kRDQAlgx8fGQzV
sIToKUbBYxiD4/c44NFgcXEx+qsHqip87LErA1ILstS2VgMXa+a7CV04Ja0O
KUsw6Zs59fz5oUKGpaUlH4d3JCN4PK1M1FInHM5ABswUiGLv7u58L+cx4fDw
EMaErNRs+uMzFz9R6hFANWk1TN+FHUhQgAhqsvOyBIBiPD0+Pp6cnKyvr29U
7z/OtxBssgBfSbUroDqn3Xv7tLrAuLGxMbO/yynPng1tRNbiaKoWIyo4KCID
G3IxY6kkTG0SOGfpaYvh3PLy8mAwuKy+KWMKkhDe+9EYKhDHEhXPY+tvHLyf
19bWDp27CQTim53UwZZ72FYXRoaWUkS20nYT7OxmnNWKTaNeJSU2PZfx5eVl
fZXyw4cPLzdKaZkIE+BNjKORFmLKUkqdwAnj6ldv3rdLzu06V/uWPY9secXU
Hfi4xqRphFz/hmFqyEAyDMMcGixpA1SoaRhy6ZsHa6rvuNvc3PQbDb/5vb+/
72BuQNowliqUQB3CoGqg956HWd8hbG9vf/361e/gtJIOgwxAjhshAwmhQ6VZ
Zh4yYBBYJa6z89LKHqr9+NTBFCwf1cfHx08XIjY2Tk9PHxiJqUsM1UbW5sTW
lxE2ny8jPKFrYmhqiRUDNStQoitaH6nhx1pYE2RASsWkT4oNL5a0ZNSKR7In
Nba+V2qlCnUf58PhUOFxMRYYXYxier1Prq+vP3365NuDlZUV327d3NxgxPCQ
ARmcqYMkBuRYSb/RmjLCZtpuAm8DnjPVIeg6U4vs6uo08geDwcLCgv+/byTw
Dy1HaRWCrHwgLDA4W/vE+2HqE4+cUZ9Ewx6ZRBIQYFdneYkh1TVTZDCaMrAE
DFRkGMMDYR7hUcK5K+c+bW5uTlEi8y5OWAfGoVpwPEkkalZFdbaJBr43mKJB
9D3F0bWDU4aUUPAswyN4RMymOSCEirtZxGia8Xy8e2TQEoWZfupUtsRIwmky
u/pUN/7ECL/XqFBid3f3J0qkglIOkQw2JDIkyKOBn9Fp9c2CRwM/U48GV1dX
NRrAAU9FdUX8ww/BRCDD98jpWyMDkpNNipASlYzPGF1koGICMH7kUeLq6uDg
4AklnNt2zv/tgcIfxN5sSVWasAQ1PEEeB+7v7y8vL73lHz58GDj3yrm1tTWP
Bt+/fw97A0wptAueLLGzUq4riwxs7erIIAdkSeFSkUxVJGfgmTIajXyPfXZ2
9vHjx/phU76j8Pnlm4pPnz6dn5+nOvC8/JS/grqCmXltp8cBb2f9cEXnPKqt
ObfjjzzZ6dwj3UHCfATiASgWWtmnCBdAzZLUIztk4BVZCTKk4BSvnWePMGAU
g6TuyX3/8LMWDwavXr2qt+p1a/Ht2zefpL5ex+8WziJDy9wGm1ftZXrJNzc3
LwZUzcBvv/3mDdjb2/MHPT5UP3Icy7OMgQxR20ljqcUoa4lw9QH8pgoP8oWG
DJKFU0wBjEZFZKCeajHAQSV3CyzBJ6zPVl+afSOx59ygugfAZ6tf0MXFRd9j
bG1t+ZbDV/MPFXkM+VjRP517+leRH1sf9GdrNs/vR21WtX/RNwELC79V37rW
IOD3BV++fCE3LXpXlqI8DDDBsDFyXxcZMAepoohXIOc0pzn9uxAZXDolKh6q
lAn1sabUW8NKUjEnzL09pznNaU5zmtOc5jSnOc1pTnOa05zmNKc5zWlOc5rT
nOZkRP8f9Odgeg==
     "], {{0, 0}, {350, 350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT1MJEuybj49aSxmcBZhIfQMNMaqd4y9oGsctTVqa4TxtIfr3HlIV0JY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     "], {{0, 0}, {350, 350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}], ",", 
   GraphicsBox[RasterBox[CompressedData["
1:eJztfT9MHEuzbz89yRGY5ENEK/QCdIJPXAf3gm5gEVkbWQRPx3zJx0O6EiJC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     "], {{0, 0}, {350, 350}}, {0, 255},
     ColorFunction->RGBColor],
    ImageSize->{350, 350},
    PlotRange->{{0, 350}, {0, 350}}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5682227748596163`*^9, {3.568222812586335*^9, 3.56822283571494*^9}, {
   3.568222865915091*^9, 3.568222872377781*^9}, {3.568223153139267*^9, 
   3.568223160925169*^9}, {3.568223201646405*^9, 3.56822322924225*^9}, {
   3.568223259944537*^9, 3.5682233095609493`*^9}, {3.568223397536696*^9, 
   3.5682234334634447`*^9}, {3.568223467418758*^9, 3.568223478691163*^9}, {
   3.5682235135128403`*^9, 3.5682236090051403`*^9}, {3.5682236462940283`*^9, 
   3.568223754941224*^9}, {3.5682237992053537`*^9, 3.5682238448626833`*^9}, {
   3.56822409564288*^9, 3.568224124200225*^9}, 3.56822433054215*^9, {
   3.568224379811761*^9, 3.5682243901756477`*^9}, 3.5682246831915483`*^9, 
   3.568224774630949*^9, 3.5682249374917297`*^9, {3.568225034585578*^9, 
   3.568225061053981*^9}, 3.568437810982418*^9, {3.568437846379903*^9, 
   3.568437872928976*^9}, {3.568437910860815*^9, 3.568437984196555*^9}, {
   3.568438029856536*^9, 3.5684380548638067`*^9}, 3.5684383892552547`*^9, {
   3.570863316376687*^9, 3.57086337857907*^9}, 3.570863459175129*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"\"\<plotHitsSample\>\"", "<>", 
       RowBox[{"ToString", "[", "#", "]"}], "<>", "\"\<.pdf\>\""}], ",", 
      RowBox[{"plotHitsSample", "[", "#", "]"}]}], "]"}], "&"}], ",", 
   RowBox[{"Range", "[", "7", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.568224205888627*^9, 3.56822423595781*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"plotHitsSample1.pdf\"\>", ",", "\<\"plotHitsSample2.pdf\"\>", 
   ",", "\<\"plotHitsSample3.pdf\"\>", ",", "\<\"plotHitsSample4.pdf\"\>", 
   ",", "\<\"plotHitsSample5.pdf\"\>", ",", "\<\"plotHitsSample6.pdf\"\>", 
   ",", "\<\"plotHitsSample7.pdf\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.568224243388783*^9, 3.568224405599596*^9, 
  3.568224692687207*^9, 3.568224776480101*^9, 3.568224939329184*^9, 
  3.568224988960669*^9, 3.568225062858611*^9, 3.5684380583864183`*^9, 
  3.5684384072869797`*^9, 3.570863322394391*^9, 3.570863385661757*^9, 
  3.570863463339231*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1615, 1026},
WindowMargins->{{-7, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 118, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[700, 26, 53, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[778, 31, 641, 14, 23, "Print"],
Cell[1422, 47, 281, 4, 23, "Print"],
Cell[1706, 53, 715, 10, 43, "Print"],
Cell[2424, 65, 761, 12, 43, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3234, 83, 225, 4, 32, "Input"],
Cell[3462, 89, 341, 5, 32, "Output"]
}, Open  ]],
Cell[3818, 97, 2495, 67, 209, "Input"],
Cell[6316, 166, 684, 22, 55, "Input"],
Cell[7003, 190, 851, 25, 99, "Input"],
Cell[CellGroupData[{
Cell[7879, 219, 1371, 37, 77, "Input"],
Cell[9253, 258, 837, 21, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10127, 284, 212, 5, 32, "Input"],
Cell[10342, 291, 444, 8, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10823, 304, 491, 12, 32, "Input"],
Cell[CellGroupData[{
Cell[11339, 320, 225, 3, 23, "Print"],
Cell[11567, 325, 223, 3, 23, "Print"],
Cell[11793, 330, 225, 3, 23, "Print"],
Cell[12021, 335, 223, 3, 23, "Print"],
Cell[12247, 340, 223, 3, 23, "Print"],
Cell[12473, 345, 225, 3, 23, "Print"],
Cell[12701, 350, 225, 3, 23, "Print"]
}, Open  ]],
Cell[12941, 356, 532, 9, 32, "Output"]
}, Open  ]],
Cell[13488, 368, 983, 25, 99, "Input"],
Cell[CellGroupData[{
Cell[14496, 397, 2220, 54, 77, "Input"],
Cell[16719, 453, 1674, 41, 239, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18430, 499, 2355, 62, 121, "Input"],
Cell[20788, 563, 1745, 41, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22570, 609, 866, 20, 77, "Input"],
Cell[23439, 631, 18247, 441, 255, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41723, 1077, 320, 7, 32, "Input"],
Cell[42046, 1086, 121, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42204, 1092, 111, 1, 31, "Subsubtitle"],
Cell[42318, 1095, 140, 3, 32, "Input"],
Cell[42461, 1100, 5934, 145, 429, "Input"],
Cell[CellGroupData[{
Cell[48420, 1249, 1044, 20, 32, "Input"],
Cell[CellGroupData[{
Cell[49489, 1273, 628, 9, 23, "Print"],
Cell[50120, 1284, 628, 9, 23, "Print"],
Cell[50751, 1295, 628, 9, 23, "Print"],
Cell[51382, 1306, 628, 9, 23, "Print"],
Cell[52013, 1317, 630, 9, 23, "Print"],
Cell[52646, 1328, 628, 9, 23, "Print"],
Cell[53277, 1339, 628, 9, 23, "Print"]
}, Open  ]],
Cell[53920, 1351, 175837, 2900, 751, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229794, 4256, 413, 10, 32, "Input"],
Cell[230210, 4268, 617, 10, 65, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
